@@ -126,8 +126,8 @@ int kdemain(int argc, char **argv)
     KConfig artsKCMConfig( "kcmartsrc" );
     artsKCMConfig.setGroup( "Arts" );
     bool useArts = artsKCMConfig.readBoolEntry( "StartServer", true );
-    if ( useArts )
-        useArts = config.readBoolEntry( "Use Arts", true );
+    if (useArts)
+        useArts = config.readBoolEntry( "Use Arts", useArts );
     bool ok = config.readBoolEntry( "Arts Init", true );
 
     if ( useArts && !ok )
@@ -223,11 +223,8 @@ KNotify::KNotify( bool useArts )
     d->audioManager = 0;
     if( useArts )
     {
-        restartedArtsd(); //started allready need to initialize d->audioManager
-        // FIXME: Under certain circumstances the restartedServer() signal is
-        //        emitted in the restartedArtsd() slot. This can lead to
-        //        infinite looping.
         connect( soundServer, SIGNAL( restartedServer() ), this, SLOT( restartedArtsd() ) );
+        restartedArtsd(); //started allready need to initialize d->audioManager
     }
 
     d->volume = 100;
