@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
@@ -26,6 +26,7 @@
 #include <soundserver.h>
 
 class KNotifyPrivate;
+class KProcess;
 
 class KNotify : public QObject, public DCOPObject
 {
@@ -33,37 +34,62 @@ Q_OBJECT
 K_DCOP
 
 public:
-	KNotify();
+	KNotify( bool useArts );
 	~KNotify();
 
-	static void crashHandler(int);
+    enum PlayingFinishedStatus
+    {
+        PlayedOK = 0,        // success, all following mean failure
+        NoSoundFile,
+        FileAlreadyPlaying,
+        NoSoundSupport,
+        PlayerBusy,
+        Aborted,
+        Unknown = 5000
+    };
 
 protected:
 k_dcop:
+	// deprecated
 	void notify(const QString &event, const QString &fromApp,
                          const QString &text, QString sound, QString file,
                          int present, int level);
 
+	// deprecated
 	void notify(const QString &event, const QString &fromApp,
                          const QString &text, QString sound, QString file,
                          int present, int level, int winId);
 
+	void notify(const QString &event, const QString &fromApp,
+                         const QString &text, QString sound, QString file,
+                         int present, int level, int winId, int eventId);
+
+
 	void reconfigure();
 	void setVolume( int volume );
 
-protected:
-	bool notifyBySound(const QString &sound, const QString &appname);
-	bool notifyByMessagebox(const QString &text, int level);
+private:
+	bool notifyBySound(const QString &sound, const QString &appname, int eventId);
+	bool notifyByMessagebox(const QString &text, int level, WId winId);
 	bool notifyByLogfile(const QString &text, const QString &file);
 	bool notifyByStderr(const QString &text);
 	bool notifyByPassivePopup(const QString &text, const QString &appName,
-                                  int winId = 0 );
-	bool notifyByExecute(const QString &command);
+                                  WId winId );
+	bool notifyByExecute(const QString &command, 
+                             const QString& event, 
+                             const QString& fromApp, 
+                             const QString& text,
+                             int winId,
+                             int eventId );
+    bool notifyByTaskbar( WId winId );
 	
-	void connectSoundServer();
 	bool isPlaying( const QString& soundFile ) const;
+
+    void soundFinished( int eventId, PlayingFinishedStatus reason );
+    void abortFirstPlayObject();
 	
-public:
+        WId checkWinId( const QString& appName, WId senderWinId );
+
 	/**
 	 * checks if eventname is a global event (exists in config/eventsrc)
 	 **/
@@ -71,6 +97,8 @@ public:
 
 private slots:
     void playTimeout();
+    void slotPlayerProcessExited( KProcess *proc );
+    void restartedArtsd();
 
 private:
     KNotifyPrivate* d;
