@@ -20,23 +20,27 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 ******************************************************************/
 
+// putenv() is not available on all platforms, so make sure the emulation
+// wrapper is available in those cases by loading config.h!
+#include <config.h>
+
+#include <sys/types.h>
+#include <pwd.h>
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <qbuffer.h>
 #include <qcolor.h>
 #include <qdir.h>
 #include <qfile.h>
 #include <qfileinfo.h>
+#include <qimage.h>
 #include <qmap.h>
 #include <qstringlist.h>
 #include <qtextstream.h>
 #include <qvariant.h>
 
-// putenv() is not available on all platforms, so make sure the emulation
-// wrapper is available in those cases by loading config.h!
-#include <config.h>
-
 #include "../dcopclient.h"
 #include "../dcopref.h"
 #include "../kdatastream.h"
@@ -186,8 +190,11 @@ int callFunction( const char* app, const char* obj, const char* func, const QCSt
 
 	    if ( l > 0 && (*it).mid( s, l - s ) == func ) {
 		realfunc = (*it).mid( s );
-		uint a = (*it).contains(',');
-		if ( ( a == 0 && args.isEmpty() ) || ( a > 0 && a + 1 == args.count() ) )
+		const QString arguments = (*it).mid(l+1,(*it).find( ')' )-l-1);
+		uint a = arguments.contains(',');
+		if ( (a==0 && !arguments.isEmpty()) || a>0)
+		    a++;
+		if ( a == args.count()  )
 		    break;
 	    }
 	}
@@ -366,20 +373,9 @@ static UserList userList()
 {
     UserList result;
 
-    QFile f( "/etc/passwd" );
-
-    if( !f.open( IO_ReadOnly ) )
+    while( passwd* pstruct = getpwent() )
     {
-	cerr_ << "Can't open /etc/passwd for reading!" << endl;
-	return result;
-    }
-
-    QStringList l( QStringList::split( '\n', f.readAll() ) );
-
-    for( QStringList::ConstIterator it( l.begin() ); it != l.end(); ++it )
-    {
-	QStringList userInfo( QStringList::split( ':', *it, true ) );
-	result[ userInfo[ 0 ] ] = userInfo[ 5 ];
+        result[ QString::fromLocal8Bit(pstruct->pw_name) ] = QFile::decodeName(pstruct->pw_dir);
     }
 
     return result;
