@@ -32,14 +32,28 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 bool DCOPReply::typeCheck( const char* t )
 {
-    if ( type == t )
-	return TRUE;
-    qWarning( "DCOPReply<%s>: cast to '%s' error",
-	     STR( type ), t );
-    return FALSE;
+    return typeCheck( t, true );
 }
 
+bool DCOPReply::typeCheck( const char* t, bool warn )
+{
+    if ( type == t )
+	return true;
+    if( warn
+	|| strcmp( t, "<unknown>" )) // type not listed in dcoptypes.h
+	qWarning( "DCOPReply<%s>: cast to '%s' error",
+	         STR( type ), t );
+    return false;
+}
+
+// this has to stay BC too even if private, because it's called from inlines
 DCOPReply DCOPRef::callInternal( const QCString& fun, const QCString& args, const QByteArray& data )
+{
+    return callInternal( fun, args, data, NoEventLoop, -1 );
+}
+
+DCOPReply DCOPRef::callInternal( const QCString& fun, const QCString& args, const QByteArray& data,
+				 EventLoopFlag useEventLoop, int timeout )
 {
     DCOPReply reply;
     if ( isNull() ) {
@@ -60,7 +74,7 @@ DCOPReply DCOPRef::callInternal( const QCString& fun, const QCString& args, cons
 	qWarning( "DCOPRef::call():  no DCOP client or client not attached error" );
 	return reply;
     }
-    dc->call( m_app, m_obj, sig, data, reply.type, reply.data );
+    dc->call( m_app, m_obj, sig, data, reply.type, reply.data, useEventLoop == UseEventLoop, timeout );
     return reply;
 }
 
@@ -69,7 +83,7 @@ bool DCOPRef::sendInternal( const QCString& fun, const QCString& args, const QBy
     if ( isNull() ) {
 	qWarning( "DCOPRef: send '%s' on null reference error",
 		  STR( fun ) );
-	return FALSE;
+	return false;
     }
     Q_UNUSED( data );
     QCString sig = fun;
