@@ -35,7 +35,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <sys/param.h>
 #endif
 #include <sys/resource.h>
-                   
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <signal.h>
@@ -53,12 +53,19 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qptrstack.h>
 #include <qtimer.h>
 
-#include <dcopserver.h>
+#include "dcopserver.h"
+
 #include <dcopsignals.h>
 #include <dcopclient.h>
 #include <dcopglobal.h>
 #include "dcop-path.h"
 
+#ifdef DCOP_LOG
+#undef Unsorted
+#include <qdir.h>
+#include <string.h>
+#endif
+
 // #define DCOP_DEBUG
 
 DCOPServer* the_server;
@@ -443,35 +450,78 @@ write_iceauth (FILE *addfp, IceAuthDataEntry *entry)
     fprintf (addfp, "\n");
 }
 
+#ifndef HAVE_MKSTEMPS
+#include <string.h>
+#include <strings.h>
 
-#ifndef HAVE_MKSTEMP
-static char *unique_filename (const char *path, const char *prefix)
-#else
-static char *unique_filename (const char *path, const char *prefix, int *pFd)
-#endif
+/* this is based on code taken from the GNU libc, distributed under the LGPL license */
+
+/* Generate a unique temporary file name from TEMPLATE.
+
+   TEMPLATE has the form:
+
+   <path>/ccXXXXXX<suffix>
+
+   SUFFIX_LEN tells us how long <suffix> is (it can be zero length).
+
+   The last six characters of TEMPLATE before <suffix> must be "XXXXXX";
+   they are replaced with a string that makes the filename unique.
+
+   Returns a file descriptor open on the file for reading and writing.  */
+
+int mkstemps (char* _template, int suffix_len)
 {
-#ifndef HAVE_MKSTEMP
-#ifndef X_NOT_POSIX
-    return ((char *) tempnam (path, prefix));
-#else
-    char tempFile[PATH_MAX];
-    char *tmp;
+  static const char letters[] = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
+  char *XXXXXX;
+  int len;
+  int count;
+  int value;
+
+  len = strlen (_template);
+
+  if ((int) len < 6 + suffix_len || strncmp (&_template[len - 6 - suffix_len], "XXXXXX", 6))
+      return -1;
+
+  XXXXXX = &_template[len - 6 - suffix_len];
+
+  value = rand();
+  for (count = 0; count < 256; ++count)
+  {
+      int v = value;
+      int fd;
+
+      /* Fill in the random bits.  */
+      XXXXXX[0] = letters[v % 62];
+      v /= 62;
+      XXXXXX[1] = letters[v % 62];
+      v /= 62;
+      XXXXXX[2] = letters[v % 62];
+      v /= 62;
+      XXXXXX[3] = letters[v % 62];
+      v /= 62;
+      XXXXXX[4] = letters[v % 62];
+      v /= 62;
+      XXXXXX[5] = letters[v % 62];
+
+      fd = open (_template, O_RDWR|O_CREAT|O_EXCL, 0600);
+      if (fd >= 0)
+	/* The file does not exist.  */
+	return fd;
+
+      /* This is a random value.  It is only necessary that the next
+	 TMP_MAX values generated by adding 7777 to VALUE are different
+	 with (module 2^32).  */
+      value += 7777;
+    }
+  /* We return the null string if we can't find a unique file name.  */
+  _template[0] = '\0';
+  return -1;
+}
 
-    snprintf (tempFile, PATH_MAX, "%s/%sXXXXXX", path, prefix);
-    tmp = (char *) mktemp (tempFile);
-    if (tmp)
-	{
-	    char *ptr = (char *) malloc (strlen (tmp) + 1);
-        if (ptr != NULL)
-        {
-	        strcpy (ptr, tmp);
-        }
-	    return (ptr);
-	}
-    else
-	return (NULL);
 #endif
-#else
+
+static char *unique_filename (const char *path, const char *prefix, int *pFd)
+{
     char tempFile[PATH_MAX];
     char *ptr;
 
@@ -480,44 +530,11 @@ static char *unique_filename (const char *path, const char *prefix, int *pFd)
     if (ptr != NULL)
 	{
 	    strcpy(ptr, tempFile);
-	    *pFd =  mkstemp(ptr);
+	    *pFd =  mkstemps(ptr, 0);
 	}
     return ptr;
-#endif
 }
 
-#if 0
-Status SetAuthentication_local (int count, IceListenObj *listenObjs)
-{
-    int i;
-    for (i = 0; i < count; i ++) {
-	char *prot = IceGetListenConnectionString(listenObjs[i]);
-	if (!prot) continue;
-	char *host = strchr(prot, '/');
-	char *sock = 0;
-	if (host) {
-	    *host=0;
-	    host++;
-	    sock = strchr(host, ':');
-	    if (sock) {
-		*sock = 0;
-		sock++;
-	    }
-	}
-#ifndef NDEBUG
-	qDebug("DCOPServer: SetAProc_loc: conn %d, prot=%s, file=%s",
-		(unsigned)i, prot, sock);
-#endif
-	if (sock && !strcmp(prot, "local")) {
-	    chmod(sock, 0700);
-	}
-	IceSetHostBasedAuthProc (listenObjs[i], HostBasedAuthProc);
-	free(prot);
-    }
-    return 1;
-}
-#endif
-
 #define MAGIC_COOKIE_LEN 16
 
 Status
@@ -528,29 +545,19 @@ SetAuthentication (int count, IceListenObj *_listenObjs,
     const char  *path;
     int         original_umask;
     int         i;
-    QCString command;    
-#ifdef HAVE_MKSTEMP
+    QCString command;
     int         fd;
-#endif
 
     original_umask = umask (0077);      /* disallow non-owner access */
 
     path = getenv ("DCOP_SAVE_DIR");
     if (!path)
 	path = "/tmp";
-#ifndef HAVE_MKSTEMP
-    if ((addAuthFile = unique_filename (path, "dcop")) == NULL)
-	goto bad;
-
-    if (!(addfp = fopen (addAuthFile, "w")))
-	goto bad;
-#else
     if ((addAuthFile = unique_filename (path, "dcop", &fd)) == NULL)
 	goto bad;
 
     if (!(addfp = fdopen(fd, "wb")))
 	goto bad;
-#endif
 
     if ((*_authDataEntries = static_cast<IceAuthDataEntry *>(malloc (count * 2 * sizeof (IceAuthDataEntry)))) == NULL)
 	goto bad;
@@ -587,13 +594,13 @@ SetAuthentication (int count, IceListenObj *_listenObjs,
     umask (original_umask);
 
     command = DCOPClient::iceauthPath();
-    
+
     if (command.isEmpty())
     {
        fprintf( stderr, "dcopserver: 'iceauth' not found in path, aborting.\n" );
        exit(1);
     }
-    
+
     command += " source ";
     command += addAuthFile;
     system (command);
@@ -873,37 +880,12 @@ static const IcePoVersionRec DUMMYVersions[] = {
     { DCOPVersionMajor, DCOPVersionMinor, 0 }
 };
 
-typedef struct DCOPServerConnStruct *DCOPServerConn;
-
-struct DCOPServerConnStruct
-{
-    /*
-     * We use ICE to esablish a connection with the client.
-   */
-
-    IceConn		iceConn;
-
-
-    /*
-   * Major and minor versions of the XSMP.
-   */
-
-    int			proto_major_version;
-    int			proto_minor_version;
-
-
-    QCString clientId;
-};
-
-
-static Status DCOPServerProtocolSetupProc ( IceConn iceConn,
+static Status DCOPServerProtocolSetupProc ( IceConn /*iceConn*/,
 					    int majorVersion, int minorVersion,
 					    char* vendor, char* release,
 					    IcePointer *clientDataRet,
 					    char **/*failureReasonRet*/)
 {
-    DCOPServerConn serverConn;
-
     /*
      * vendor/release are undefined for ProtocolSetup in DCOP
      */
@@ -913,22 +895,9 @@ static Status DCOPServerProtocolSetupProc ( IceConn iceConn,
     if (release)
 	free (release);
 
+    *clientDataRet = 0;
 
-    /*
-     * Allocate new DCOPServerConn.
-     */
-
-    serverConn = new DCOPServerConnStruct;
-
-    serverConn->iceConn = iceConn;
-    serverConn->proto_major_version = majorVersion;
-    serverConn->proto_minor_version = minorVersion;
-    //serverConn->clientId already initialized
-
-    *clientDataRet = static_cast<IcePointer>(serverConn);
-
-
-    return 1;
+    return (majorVersion == DCOPVersionMajor && minorVersion == DCOPVersionMinor);
 }
 
 static int pipeOfDeath[2];
@@ -1039,6 +1008,17 @@ DCOPServer::DCOPServer(bool _suicide)
     connect( m_timer, SIGNAL(timeout()), this, SLOT(slotTerminate()) );
     m_deadConnectionTimer = new QTimer(this);
     connect( m_deadConnectionTimer, SIGNAL(timeout()), this, SLOT(slotCleanDeadConnections()) );
+
+#ifdef DCOP_LOG
+    char hostname_buffer[256];
+    memset( hostname_buffer, 0, sizeof( hostname_buffer ) );
+    if ( gethostname( hostname_buffer, 255 ) < 0 )
+      hostname_buffer[0] = '\0';
+    m_logger = new QFile( QString( "%1/.dcop-%2.log" ).arg( QDir::homeDirPath() ).arg( hostname_buffer ) );
+    if ( m_logger->open( IO_WriteOnly ) ) {
+        m_stream = new QTextStream( m_logger );
+    }
+#endif
 }
 
 DCOPServer::~DCOPServer()
@@ -1047,6 +1027,11 @@ DCOPServer::~DCOPServer()
     IceFreeListenObjs(numTransports, listenObjs);
     FreeAuthenticationData(numTransports, authDataEntries);
     delete dcopSignals;
+#ifdef DCOP_LOG
+    delete m_stream;
+    m_logger->close();
+    delete m_logger;
+#endif
 }
 
 
@@ -1252,6 +1237,16 @@ bool DCOPServer::receive(const QCString &/*app*/, const QCString &obj,
 			 QCString& replyType, QByteArray &replyData,
 			 IceConn iceConn)
 {
+#ifdef DCOP_LOG
+    (*m_stream) << "Received a message: obj =\""
+                << obj << "\", fun =\""
+                << fun << "\", replyType =\""
+                << replyType << "\", data.size() =\""
+                << data.size() << "\", replyData.size() ="
+                << replyData.size() << "\n";
+    m_logger->flush();
+#endif
+
     if ( obj == "emit")
     {
         DCOPConnection* conn = clients.find( iceConn );
@@ -1458,13 +1453,13 @@ void DCOPServer::broadcastApplicationRegistration( DCOPConnection* conn, const Q
         ++it;
         if ( c->notifyRegister && (c != conn) ) {
             IceGetHeader( c->iceConn, majorOpcode, DCOPSend,
-	      sizeof(DCOPMsg), DCOPMsg, pMsg );
+                          sizeof(DCOPMsg), DCOPMsg, pMsg );
             pMsg->key = 1;
 	    pMsg->length += datalen;
             _DCOPIceSendBegin(c->iceConn);
 	    DCOPIceSendData( c->iceConn, ba );
             _DCOPIceSendEnd();
-	    }
+        }
     }
 }
 
@@ -1483,6 +1478,17 @@ DCOPServer::sendMessage(DCOPConnection *conn, const QCString &sApp,
                  sizeof(DCOPMsg), DCOPMsg, pMsg );
    pMsg->length += datalen;
    pMsg->key = 1; // important!
+
+#ifdef DCOP_LOG
+   (*m_stream) << "Sending a message: sApp =\""
+               << sApp << "\", rApp =\""
+               << rApp << "\", rObj =\""
+               << rObj << "\", rFun =\""
+               << rFun << "\", datalen ="
+               << datalen << "\n";
+   m_logger->flush();
+#endif
+
    _DCOPIceSendBegin( conn->iceConn );
    DCOPIceSendData(conn->iceConn, ba);
    _DCOPIceSendEnd();
@@ -1585,15 +1591,15 @@ extern "C" int kdemain( int argc, char* argv[] )
        return 0;
     }
 
-    struct rlimit limits; 
-     
-    int retcode = getrlimit(RLIMIT_NOFILE, &limits); 
-    if (!retcode) { 
+    struct rlimit limits;
+
+    int retcode = getrlimit(RLIMIT_NOFILE, &limits);
+    if (!retcode) {
        if (limits.rlim_max > 512 && limits.rlim_cur < 512)
        {
           int cur_limit = limits.rlim_cur;
-          limits.rlim_cur = 512; 
-          retcode = setrlimit(RLIMIT_NOFILE, &limits); 
+          limits.rlim_cur = 512;
+          retcode = setrlimit(RLIMIT_NOFILE, &limits);
 
           if (retcode != 0)
           {
@@ -1642,10 +1648,10 @@ extern "C" int kdemain( int argc, char* argv[] )
     putenv(strdup("SESSION_MANAGER="));
 
     QApplication a( argc, argv, false );
-    
+
     QSocketNotifier DEATH(pipeOfDeath[0], QSocketNotifier::Read, 0, 0);
     a.connect(&DEATH, SIGNAL(activated(int)), SLOT(quit()));
-    
+
     IceSetIOErrorHandler (IoErrorHandler );
     DCOPServer *server = new DCOPServer(suicide); // this sets the_server
 
