@@ -88,7 +88,7 @@ void KScriptManager::runScript( const QString &scriptName, QObject *context, con
         kdDebug()<<"running script, type = '"<<scriptType<<"'"<<endl;
 	if (newScript)
 	{
-		// See if the script is allready cached...
+		// See if the script is already cached...
 		if ( !m_scriptCache[scriptName] )
 		{
 			// via some magic we will let the old script engine go away after
@@ -103,7 +103,7 @@ void KScriptManager::runScript( const QString &scriptName, QObject *context, con
                         }
                         else
                         {
-                          KMessageBox::sorry(0, i18n("Unable to get KScript Runner for type ") + newScript->scriptType, i18n("KScript error"));
+                          KMessageBox::sorry(0, i18n("Unable to get KScript Runner for type <b>%1</b>.").arg(newScript->scriptType), i18n("KScript Error"));
                           return;
                         }
 		}
@@ -112,7 +112,7 @@ void KScriptManager::runScript( const QString &scriptName, QObject *context, con
 		if ( m_scriptCache[m_currentScript] )
 		{
 			m_scriptCache[m_currentScript]->ScriptClientInterface = this;
-			if (newScript->scriptMethod != "")
+			if (!newScript->scriptMethod.isEmpty())
 				m_scriptCache[m_currentScript]->setScript( newScript->scriptFile, newScript->scriptMethod );
 			else
 				m_scriptCache[m_currentScript]->setScript( newScript->scriptFile );
