@@ -16,7 +16,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: configinterfaceextension.cpp,v 1.9.2.1 2003/07/15 10:42:14 mueller Exp $
+// $Id: configinterfaceextension.cpp,v 1.10 2003/05/17 22:12:53 mueller Exp $
 
 #include "configinterfaceextension.h"
 #include "configinterfaceextension.moc"
@@ -38,9 +38,9 @@ class PrivateConfigInterfaceExtension
 
 using namespace KTextEditor;
 
-ConfigPage::ConfigPage ( QWidget *parent, const char *name ) : QWidget (parent, name) { }
+ConfigPage::ConfigPage ( QWidget *parent, const char *name ) : QWidget (parent, name) { ; }
  
-ConfigPage::~ConfigPage () { }
+ConfigPage::~ConfigPage () { ; }
 
 unsigned int ConfigInterfaceExtension::globalConfigInterfaceExtensionNumber = 0;
 
