@@ -39,7 +39,7 @@ class ConfigPage : public QWidget
   //
   public:
     /**
-      Applies the changes to the document
+      Applies the changes to all documents
     */
     virtual void apply () = 0;
     
@@ -52,10 +52,17 @@ class ConfigPage : public QWidget
       Sets default options
     */
     virtual void defaults () = 0;
+
+  signals:
+    /**
+      Emitted when something changes
+    */
+    void changed();
 };
 
-/*
-*  This is an interface for the KTextEditor::Document/Plugin/ViewPlugin classes !!!
+/**
+* This is an interface to extend the configuration of the
+* Document, Plugin and PluginViewInterface classes.
 */
 class ConfigInterfaceExtension
 {
