@@ -16,7 +16,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: markinterface.cpp,v 1.6.2.1 2003/07/15 10:42:14 mueller Exp $
+// $Id: markinterface.cpp,v 1.9 2004/05/15 20:22:30 dhaumann Exp $
 
 #include "markinterface.h"
 #include "document.h"
@@ -67,3 +67,8 @@ MarkInterface *KTextEditor::markInterface (Document *doc)
 
   return static_cast<MarkInterface*>(doc->qt_cast("KTextEditor::MarkInterface"));
 }
+
+int MarkInterface::reservedMarkersCount()
+{
+    return 7;
+}
