@@ -20,12 +20,13 @@
 #define __ktexteditor_popupmenuinterface_h__
 
 class QCString;
+class QPopupMenu;
 
 namespace KTextEditor
 {
 
-/*
-*  This is an interface for the KTextEditor::View class !!!
+/**
+*  This is an interface to provide custom popup menus for a View.
 */
 class PopupMenuInterface
 {
@@ -48,7 +49,7 @@ class PopupMenuInterface
       Install a Popup Menu. The Popup Menu will be activated on
       a right mouse button press event.
     */
-    virtual void installPopup (class QPopupMenu *rmb_Menu) = 0;
+    virtual void installPopup (QPopupMenu *rmb_Menu) = 0;
 
   private:
     class PrivatePopupMenuInterface *d;    
@@ -58,6 +59,6 @@ class PopupMenuInterface
 
 PopupMenuInterface *popupMenuInterface (class View *view);
 
-};
+}
 
 #endif
