@@ -12,7 +12,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kabapi.h,v 1.18 2002/03/05 23:13:26 rich Exp $
+   $Id: kabapi.h,v 1.21 2003/08/21 09:04:38 coolo Exp $
 */
 #ifndef KABAPI_H
 #define KABAPI_H
@@ -34,7 +34,7 @@ class KListBox;
   * can be used as a KDE dialog where the user may select a person
   * out of the entries in his personal database.
   * The following code may be used to let the user select an address:
-  * <pre>
+  * \code
   * KabAPI kabapi(this);
   * if(dialog.init()!=KabAPI::NoError)
   *   {
@@ -51,7 +51,7 @@ class KListBox;
   *       }
   *   }
   * ...
-  * </pre>
+  * \endcode
   * Some methods declared here return keys of entries. The keys are of the
   * datatype KabKey. Every key
   * is (of course) unique and identifying. If you store it, you can access
@@ -61,8 +61,8 @@ class KListBox;
   * long the kab API is not completely finished.</tt>
   * @short The class KabAPI defines the API to access user address databases.
   * @author Mirko Boehm <mirko@kde.org>
-  * @version $Id: kabapi.h,v 1.18 2002/03/05 23:13:26 rich Exp $
-  * @see #AddressBook #KDialogBase
+  * @version $Id: kabapi.h,v 1.21 2003/08/21 09:04:38 coolo Exp $
+  * @see AddressBook #KDialogBase
   */
 
 class KabAPI : public KDialogBase
@@ -74,7 +74,7 @@ public:
   /**
    * The constructor creates a KabAPI object, but it does not load the
    * database itselfes, as you could not query if this could be done
-   * without failures. Thus you have to call @ref #init before you can
+   * without failures. Thus you have to call init before you can
    * use the database.
    * @param parent The QWidget pointer to the parent widget.
    */
@@ -84,7 +84,7 @@ public:
    * database file (usually $HOME/.kde/share/apps/kab/addressbook.database)
    * and loads its contents.
    * @return NoError if all succeeded or a valid ErrorCode.
-   * @see #AddressBook::ErrorCode
+   * @see AddressBook::ErrorCode
    */
   AddressBook::ErrorCode init();
   /**
@@ -107,7 +107,7 @@ public:
   /**
    * The method getEntry returns the selected entry.
    * @return NoError if all succeeded or a valid ErrorCode.
-   * @see #AddressBook::ErrorCode
+   * @see AddressBook::ErrorCode
    * @param entry Reference to an AddressBook::Entry -object.
    * @param key Reference to a KabKey where the key of the entry is stored.
    */
@@ -121,7 +121,7 @@ public:
    * she can retrieve the whole database in one operation.
    * It is required that the referenced list is empty.
    * Note that the function returns NoEntry if the database is empty.
-   * @see #AddressBook::ErrorCode
+   * @see AddressBook::ErrorCode
    * @short Retrieves all entries out of the database.
    * @param entries Reference to a list of entries.
    * @return NoError or a valid error code.
