@@ -14,17 +14,18 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: qconfigDB.h,v 1.9.4.1 2003/07/15 00:40:50 mueller Exp $	 
+   $Id: qconfigDB.h,v 1.11 2003/05/17 22:12:55 mueller Exp $	 
 */
 
+namespace std { }
+using namespace std;
+
 #include <list>
 #include <map>
 #include <qwidget.h>
 #include <qcstring.h>
 #include <qstrlist.h>
 
-using namespace std;
-
 class QTimer;
 class QDate;
 class QString;
@@ -36,33 +37,6 @@ extern "C" {
 
 class QTextStream;
 
-// some support functions:
-
-/**
- * Read a line, ignore comments.
- */
-QCString ReadLineFromStream(QTextStream&);
-
-/**
- * Find out wether a line is a comment or not (comments start with #).
- */
-bool isComment(QCString);
-
-/**
- * Parse the string and replace all non-standard characters with its
- * HTML equivalents.
- */
-bool htmlizeString(const QCString& orig, QCString& target);
-
-/**
- * tokenize partens the given string text into its tokens at every 
- * occurence of the designator c and delivers the result in the list
- * reference. If strict is true, the last token is only added if there
- * are characters after the last designator.
- */
-void tokenize(list<QCString>& res, const QCString& text, 
-	      char c, bool strict=false);
-
 /**
  * This is some STL interna, a function object for use with STL
  * container classes. Its only element function is the function
@@ -680,7 +654,7 @@ public:
   /**
    * Return a string describing the version.
    */
-  static const char* version() { return "2.0 $Revision: 1.9.4.1 $"; }
+  static const char* version() { return "2.0 $Revision: 1.11 $"; }
   /**
    * Check wether the given file is locked.
    * The method returns zero if not, a number > zero is the pid of the process
