@@ -96,13 +96,19 @@ ResourceFile::~ResourceFile()
 {
   delete mFormat;
   mFormat = 0;
+  delete mLocalTempFile;
+  mLocalTempFile = 0;
 }
 
 void ResourceFile::writeConfig( KConfig *config )
 {
   Resource::writeConfig( config );
 
-  config->writePathEntry( "FileName", mFileName );
+  if ( mFileName == StdAddressBook::fileName() )
+    config->deleteEntry( "FileName" );
+  else
+    config->writePathEntry( "FileName", mFileName );
+
   config->writeEntry( "FileFormat", mFormatName );
 }
 
@@ -188,12 +194,12 @@ bool ResourceFile::asyncLoad()
   mAsynchronous = true;
 
   if ( mLocalTempFile ) {
-    kdDebug(5700) << "stale temp file dedected " << mLocalTempFile->name() << endl;
-    mLocalTempFile->setAutoDelete( true );
+    kdDebug(5700) << "stale temp file detected " << mLocalTempFile->name() << endl;
     delete mLocalTempFile;
   }
 
   mLocalTempFile = new KTempFile();
+  mLocalTempFile->setAutoDelete( true );
   mTempFile = mLocalTempFile->name();
 
   KURL dest, src;
@@ -217,6 +223,7 @@ bool ResourceFile::save( Ticket * )
   (void) KSaveFile::backupFile( mFileName, QString::null /*directory*/,
                                 extension );
 
+  mDirWatch.stopScan();
   KSaveFile saveFile( mFileName );
   bool ok = false;
   if ( saveFile.status() == 0 && saveFile.file() )
@@ -227,6 +234,7 @@ bool ResourceFile::save( Ticket * )
 
   if ( !ok )
     addressBook()->error( i18n( "Unable to save file '%1'." ).arg( mFileName ) );
+  mDirWatch.startScan();
 
   return ok;
 }
@@ -240,6 +248,7 @@ bool ResourceFile::asyncSave( Ticket * )
     return false;
   }
 
+  mDirWatch.stopScan();
   mFormat->saveAll( addressBook(), this, &file );
   file.close();
 
@@ -296,6 +305,7 @@ void ResourceFile::fileChanged()
     asyncLoad();
   else {
     load();
+    kdDebug() << "addressBookChanged() " << endl;
     addressBook()->emitAddressBookChanged();
   }
 }
@@ -332,6 +342,7 @@ void ResourceFile::uploadFinished( KIO::Job *job )
     emit savingError( this, job->errorString() );
   else
     emit savingFinished( this );
+  mDirWatch.startScan();
 }
 
 #include "resourcefile.moc"
