@@ -20,12 +20,14 @@
 
 #include <qmap.h>
 #include <qregexp.h>
+#include <kmdcodec.h>
 
 #include "vcard21parser.h"
+#include "vcardconverter.h"
 
 using namespace KABC;
 
-bool VCardLine::isValid() const
+bool VCardLineX::isValid() const
 {
   // Invalid: if it is "begin:vcard" or "end:vcard"
   if ( name == VCARD_BEGIN_N || name == VCARD_END_N )
@@ -35,7 +37,7 @@ bool VCardLine::isValid() const
     return true;
 
   // This is long but it makes it a bit faster (and saves me from using
-  // a trie which is probably the ideal situation, but a bit memory heavy)
+  // a tree which is probably the ideal situation, but a bit memory heavy)
   switch( name[0] ) {
     case 'a':
       if ( name == VCARD_ADR && qualified &&
@@ -189,27 +191,6 @@ bool VCardLine::isValid() const
 }
 
 
-void VCardLine::qpDecode( QString& x )
-{
-  QString y = x;
-  int c;
-
-  x = "";
-  c = y.length();
-
-  for (int i = 0; i < c; i++) {
-    if (y[i] == '=') {
-      char p = y[++i].latin1();
-      char q = y[++i].latin1();
-      x += (char) ((p <= '9' ? p - '0': p - 'A' + 10)*16 +
-                  (q <= '9' ? q - '0': q - 'A' + 10));
-    } else {
-      x += y[i];
-    }
-  }
-}
-
-
 VCard21Parser::VCard21Parser()
 {
 }
@@ -235,7 +216,7 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
   {
      kdDebug() << "Parsing failed" << endl;
      return addressee;
-  }         
+  }
   //set the addressees name and formated name
   QStringList tmpList = mVCard->getValues(VCARD_N);
   QString formattedName = "";
@@ -257,7 +238,7 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
   //set the addressee's nick name
   tmpStr = mVCard->getValue(VCARD_NICKNAME);
   addressee.setNickName(tmpStr);
-  //set the addressee's organisation
+  //set the addressee's organization
   tmpStr = mVCard->getValue(VCARD_ORG);
   addressee.setOrganization(tmpStr);
   //set the addressee's title
@@ -270,18 +251,18 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
   addressee.insertEmail(tmpStr, true);
   //set the addressee's url
   tmpStr = mVCard->getValue(VCARD_URL);
-
+  if (tmpStr.isEmpty()) tmpStr = mVCard->getValue(VCARD_URL, VCARD_ADR_WORK);
+  if (tmpStr.isEmpty()) tmpStr = mVCard->getValue(VCARD_URL, VCARD_ADR_HOME);
   if (!tmpStr.isEmpty()) {
-    KURL url(tmpStr);
-    addressee.setUrl(url);
+    addressee.setUrl(KURL(tmpStr));
   }
 
   //set the addressee's birthday
   tmpStr = mVCard->getValue(VCARD_BDAY);
-  addressee.setBirthday(QDateTime::fromString(tmpStr,Qt::ISODate));
+  addressee.setBirthday(VCardStringToDate(tmpStr));
 
   //set the addressee's phone numbers
-  for ( QValueListIterator<VCardLine> i = mVCard->_vcdata->begin();i != mVCard->_vcdata->end(); ++i ) {
+  for ( QValueListIterator<VCardLineX> i = mVCard->_vcdata->begin();i != mVCard->_vcdata->end(); ++i ) {
     if ( (*i).name == VCARD_TEL ) {
       int type = 0;
       if ( (*i).qualified ) {
@@ -291,8 +272,8 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
           type |= PhoneNumber::Work;
         if ( (*i).qualifiers.contains( VCARD_TEL_PREF ) )
           type |= PhoneNumber::Pref;
-        if ( (*i).qualifiers.contains( VCARD_TEL_VOICE ) )
-          type |= PhoneNumber::Voice;
+        // if ( (*i).qualifiers.contains( VCARD_TEL_VOICE ) )
+        //  type |= PhoneNumber::Voice;
         if ( (*i).qualifiers.contains( VCARD_TEL_FAX ) )
           type |= PhoneNumber::Fax;
         if ( (*i).qualifiers.contains( VCARD_TEL_MSG ) )
@@ -319,7 +300,7 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
   }
 
   //set the addressee's addresses
-  for ( QValueListIterator<VCardLine> i = mVCard->_vcdata->begin();i != mVCard->_vcdata->end(); ++i ) {
+  for ( QValueListIterator<VCardLineX> i = mVCard->_vcdata->begin();i != mVCard->_vcdata->end(); ++i ) {
     if ( (*i).name == VCARD_ADR ) {
       int type = 0;
       if ( (*i).qualified ) {
@@ -345,7 +326,7 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
   //set the addressee's delivery label
   tmpStr = mVCard->getValue(VCARD_LABEL);
   if (!tmpStr.isEmpty()) {
-    tmpStr.replace(QRegExp("\\r\\n"),"\n");
+    tmpStr.replace("\r\n","\n");
     Address tmpAddress;
     tmpAddress.setLabel(tmpStr);
     addressee.insertAddress(tmpAddress);
@@ -353,7 +334,7 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
 
   //set the addressee's notes
   tmpStr = mVCard->getValue(VCARD_NOTE);
-  tmpStr.replace(QRegExp("\\r\\n"),"\n");
+  tmpStr.replace("\r\n","\n");
   addressee.setNote(tmpStr);
 
   //set the addressee's timezone
@@ -375,7 +356,7 @@ KABC::Addressee VCard21Parser::readFromString( const QString &data)
 
   //set the last revision date
   tmpStr = mVCard->getValue(VCARD_REV);
-  addressee.setRevision(QDateTime::fromString(tmpStr,Qt::ISODate));
+  addressee.setRevision(VCardStringToDate(tmpStr));
 
   //set the role of the addressee
   tmpStr = mVCard->getValue(VCARD_ROLE);
@@ -410,21 +391,21 @@ KABC::Address VCard21Parser::readAddressFromQStringList ( const QStringList &dat
 }
 
 
-VCard21ParserImpl *VCard21ParserImpl::parseVCard( const QString& vc, int *err ) 
+VCard21ParserImpl *VCard21ParserImpl::parseVCard( const QString& vc, int *err )
 {
   int _err = 0;
   int _state = VC_STATE_BEGIN;
 
-  QValueList<VCardLine> *_vcdata;
+  QValueList<VCardLineX> *_vcdata;
   QValueList<QString> lines;
 
-  _vcdata = new QValueList<VCardLine>;
+  _vcdata = new QValueList<VCardLineX>;
 
   lines = QStringList::split( QRegExp( "[\x0d\x0a]" ), vc );
-  
+
   // for each line in the vCard
   for ( QStringList::Iterator j = lines.begin(); j != lines.end(); ++j ) {
-    VCardLine _vcl;
+    VCardLineX _vcl;
 
     // take spaces off the end - ugly but necessary hack
     for ( int g = (*j).length()-1; g > 0 && (*j)[g].isSpace(); --g )
@@ -458,7 +439,7 @@ VCard21ParserImpl *VCard21ParserImpl::parseVCard( const QString& vc, int *err )
 
       // check for qualifiers and
       // set name, qualified, qualifier(s)
-      QStringList keyTokens = QStringList::split( QRegExp(";"), key );
+      QStringList keyTokens = QStringList::split( ';', key );
       bool qp = false, first_pass = true;
       bool b64 = false;
 
@@ -506,10 +487,10 @@ VCard21ParserImpl *VCard21ParserImpl::parseVCard( const QString& vc, int *err )
             value.append(*( ++j ));
           }
         }
-        _vcl.parameters = QStringList::split( QRegExp(";"), value, true );
+        _vcl.parameters = QStringList::split( ';', value, true );
         if ( qp ) { // decode the quoted printable
           for ( QStringList::Iterator z = _vcl.parameters.begin(); z != _vcl.parameters.end(); ++z )
-            _vcl.qpDecode( *z );
+            *z = KCodecs::quotedPrintableDecode( (*z).latin1() );
         }
       }
     } else {
@@ -517,7 +498,7 @@ VCard21ParserImpl *VCard21ParserImpl::parseVCard( const QString& vc, int *err )
       break;
     }
 
-    // validate VCardLine
+    // validate VCardLineX
     if ( !_vcl.isValid() ) {
       _err = VC_ERR_INVALID_LINE;
       break;
@@ -550,18 +531,18 @@ VCard21ParserImpl *VCard21ParserImpl::parseVCard( const QString& vc, int *err )
   return new VCard21ParserImpl( _vcdata );
 }
 
-VCard21ParserImpl::VCard21ParserImpl(QValueList<VCardLine> *_vcd) : _vcdata(_vcd)
+VCard21ParserImpl::VCard21ParserImpl(QValueList<VCardLineX> *_vcd) : _vcdata(_vcd)
 {
 }
 
 
 QString VCard21ParserImpl::getValue(const QString& name, const QString& qualifier)
 {
-  QString failed = "";
+  QString failed;
   const QString lowname = name.lower();
   const QString lowqualifier = qualifier.lower();
 
-  for (QValueListIterator<VCardLine> i = _vcdata->begin();i != _vcdata->end();++i) {
+  for (QValueListIterator<VCardLineX> i = _vcdata->begin();i != _vcdata->end();++i) {
    if ((*i).name == lowname && (*i).qualified && (*i).qualifiers.contains(lowqualifier)) {
     if ((*i).parameters.count() > 0)
      return (*i).parameters[0];
@@ -574,10 +555,10 @@ QString VCard21ParserImpl::getValue(const QString& name, const QString& qualifie
 
 QString VCard21ParserImpl::getValue(const QString& name)
 {
-  QString failed = "";
+  QString failed;
   const QString lowname = name.lower();
 
-  for (QValueListIterator<VCardLine> i = _vcdata->begin();i != _vcdata->end();++i) {
+  for (QValueListIterator<VCardLineX> i = _vcdata->begin();i != _vcdata->end();++i) {
     if ((*i).name == lowname && !(*i).qualified) {
       if ((*i).parameters.count() > 0)
         return (*i).parameters[0];
@@ -590,27 +571,25 @@ QString VCard21ParserImpl::getValue(const QString& name)
 
 QStringList VCard21ParserImpl::getValues(const QString& name)
 {
-  //QString failedstr = "";
-  QStringList failed;
   const QString lowname = name.lower();
-  for (QValueListIterator<VCardLine> i = _vcdata->begin();i != _vcdata->end();++i) {
+  for (QValueListIterator<VCardLineX> i = _vcdata->begin();i != _vcdata->end();++i) {
     if ((*i).name == lowname && !(*i).qualified)
       return (*i).parameters;
   }
-  //failed.append(failedstr);
-  return failed;
+  // failed.
+  return QStringList();
 }
 
 QStringList VCard21ParserImpl::getValues(const QString& name, const QString& qualifier)
 {
-  //QString failedstr = "";
-  QStringList failed;
   const QString lowname = name.lower();
   const QString lowqualifier = qualifier.lower();
-  for (QValueListIterator<VCardLine> i = _vcdata->begin();i != _vcdata->end();++i) {
+  for (QValueListIterator<VCardLineX> i = _vcdata->begin();i != _vcdata->end();++i) {
     if ((*i).name == lowname && (*i).qualified && (*i).qualifiers.contains(lowqualifier))
        return (*i).parameters;
   }
-  //failed.append(failedstr);
-  return failed;
+  // failed.
+  return QStringList();
 }
+
+
