@@ -42,11 +42,12 @@ class KateArgHint;
 class KateCCListBox;
 
 class QLayout;
+class QVBox;
 
 class KateCodeCompletionCommentLabel : public QLabel
 {
   Q_OBJECT
-  
+
   public:
     KateCodeCompletionCommentLabel( QWidget* parent, const QString& text) : QLabel( parent, "toolTipTip",
              WStyle_StaysOnTop | WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WX11BypassWM )
@@ -67,37 +68,42 @@ class KateCodeCompletion : public QObject
 {
   Q_OBJECT
 
+  friend class KateViewInternal;
+
   public:
     KateCodeCompletion(KateView *view);
-  
+
     bool codeCompletionVisible ();
-  
+
     void showArgHint(
         QStringList functionList, const QString& strWrapping, const QString& strDelimiter );
     void showCompletionBox(
         QValueList<KTextEditor::CompletionEntry> entries, int offset = 0, bool casesensitive = true );
     bool eventFilter( QObject* o, QEvent* e );
-  
+
+    void handleKey (QKeyEvent *e);
+
   public slots:
     void slotCursorPosChanged();
     void showComment();
-  
+    void updateBox () { updateBox(false); }
+
   signals:
     void completionAborted();
     void completionDone();
     void argHintHidden();
     void completionDone(KTextEditor::CompletionEntry);
     void filterInsertString(KTextEditor::CompletionEntry*,QString *);
-  
+
   private:
     void doComplete();
     void abortCompletion();
     void complete( KTextEditor::CompletionEntry );
-    void updateBox( bool newCoordinate = false );
-  
+    void updateBox( bool newCoordinate );
+
     KateArgHint*    m_pArgHint;
     KateView*       m_view;
-    class QVBox*          m_completionPopup;
+    QVBox*          m_completionPopup;
     KateCCListBox*       m_completionListBox;
     QValueList<KTextEditor::CompletionEntry> m_complList;
     uint            m_lineCursor;
@@ -110,35 +116,35 @@ class KateCodeCompletion : public QObject
 class KateArgHint: public QFrame
 {
   Q_OBJECT
-  
+
   public:
       KateArgHint( KateView* =0, const char* =0 );
       virtual ~KateArgHint();
-  
+
       virtual void setCurrentFunction( int );
       virtual int currentFunction() const { return m_currentFunction; }
-  
+
       void setArgMarkInfos( const QString&, const QString& );
-  
+
       virtual void addFunction( int, const QString& );
       QString functionAt( int id ) const { return m_functionMap[ id ]; }
-  
+
       virtual void show();
       virtual void adjustSize();
       virtual bool eventFilter( QObject*, QEvent* );
-  
+
   signals:
       void argHintHidden();
       void argHintCompleted();
       void argHintAborted();
-  
+
   public slots:
       virtual void reset( int, int );
       virtual void cursorPositionChanged( KateView*, int, int );
-  
+
   private slots:
       void slotDone(bool completed);
-  
+
   private:
       QMap<int, QString> m_functionMap;
       int m_currentFunction;
@@ -153,3 +159,5 @@ class KateArgHint: public QFrame
 };
 
 #endif
+
+// kate: space-indent on; indent-width 2; replace-tabs on;
