@@ -19,6 +19,8 @@
 #include "katecodefoldinghelpers.h"
 #include "katecodefoldinghelpers.moc"
 
+#include "katebuffer.h"
+
 #include <kdebug.h>
 
 #include <qstring.h>
@@ -63,7 +65,7 @@ KateCodeFoldingNode::~KateCodeFoldingNode()
 }
 
 
-KateCodeFoldingTree::KateCodeFoldingTree(QObject *par): QObject(par), KateCodeFoldingNode()
+KateCodeFoldingTree::KateCodeFoldingTree(KateBuffer *buffer): QObject(buffer), KateCodeFoldingNode(), m_buffer (buffer)
 {
   clear();
 }
@@ -216,9 +218,9 @@ void KateCodeFoldingTree::debugDump()
 void KateCodeFoldingTree::dumpNode(KateCodeFoldingNode *node,QString prefix)
 {
   //output node properties
-  kdDebug(13000)<<prefix<<QString("Type: %1, startLineValid %2, startLineRel %3, endLineValid %4, endLineRel %5").
+  kdDebug(13000)<<prefix<<QString("Type: %1, startLineValid %2, startLineRel %3, endLineValid %4, endLineRel %5, visible %6").
       arg(node->type).arg(node->startLineValid).arg(node->startLineRel).arg(node->endLineValid).
-      arg(node->endLineRel)<<endl;
+      arg(node->endLineRel).arg(node->visible)<<endl;
 
   //output child node properties recursive
   if (node->hasChildNodes())
@@ -258,7 +260,8 @@ void KateCodeFoldingTree::updateLine(unsigned int line,
   }
   else
   {
-    for (unsigned int i=0;i<regionChanges->size() / 2;i++) {
+    for (unsigned int i=0;i<regionChanges->size() / 2;i++)
+    {
         signed char tmp=(*regionChanges)[regionChanges->size()-1-i];
         (*regionChanges)[regionChanges->size()-1-i]=(*regionChanges)[i];
         (*regionChanges)[i]=tmp;
@@ -420,7 +423,7 @@ bool KateCodeFoldingTree::removeEnding(KateCodeFoldingNode *node,unsigned int /*
 
   if (!parent)
     return false;
-  
+
   if (node->type == 0)
     return false;
 
@@ -887,7 +890,7 @@ void KateCodeFoldingTree::lineHasBeenRemoved(unsigned int line)
   if (node->parentNode)
     decrementBy1(node->parentNode, node);
 
-  for (QValueList<hiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
+  for (QValueList<KateHiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
   {
     if ((*it).start > line)
       (*it).start--;
@@ -947,7 +950,7 @@ void KateCodeFoldingTree::lineHasBeenInserted(unsigned int line)
   if (node->parentNode)
     incrementBy1(node->parentNode, node);
 
-  for (QValueList<hiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
+  for (QValueList<KateHiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
   {
     if ((*it).start > line)
       (*it).start++;
@@ -1144,6 +1147,9 @@ void KateCodeFoldingTree::dontDeleteOpening(KateCodeFoldingNode* node)
 
 void KateCodeFoldingTree::toggleRegionVisibility(unsigned int line)
 {
+  // hl whole file
+  m_buffer->line (m_buffer->count()-1);
+
   lineMapping.clear();
   hiddenLinesCountCacheValid = false;
   kdDebug(13000)<<QString("KateCodeFoldingTree::toggleRegionVisibility() %1").arg(line)<<endl;
@@ -1151,7 +1157,8 @@ void KateCodeFoldingTree::toggleRegionVisibility(unsigned int line)
   findAllNodesOpenedOrClosedAt(line);
   for (int i=0; i<(int)nodesForLine.count(); i++)
   {
-    if (getStartLine(nodesForLine.at(i)) != line)
+    KateCodeFoldingNode *node=nodesForLine.at(i);
+    if ( (!node->startLineValid) || (getStartLine(node) != line) )
     {
       nodesForLine.remove(i);
       i--;
@@ -1176,7 +1183,7 @@ void KateCodeFoldingTree::toggleRegionVisibility(unsigned int line)
     addHiddenLineBlock(nodesForLine.at(0),line);
   else
   {
-    for (QValueList<hiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end();++it)
+    for (QValueList<KateHiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end();++it)
       if ((*it).start == line+1)
       {
         hiddenLines.remove(it);
@@ -1205,12 +1212,12 @@ void KateCodeFoldingTree::updateHiddenSubNodes(KateCodeFoldingNode *node)
 
 void KateCodeFoldingTree::addHiddenLineBlock(KateCodeFoldingNode *node,unsigned int line)
 {
-  struct hiddenLineBlock data;
+  struct KateHiddenLineBlock data;
   data.start = line+1;
   data.length = node->endLineRel-(existsOpeningAtLineAfter(line+node->endLineRel,node)?1:0); // without -1;
   bool inserted = false;
 
-  for (QValueList<hiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
+  for (QValueList<KateHiddenLineBlock>::Iterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
   {
     if (((*it).start>=data.start) && ((*it).start<=data.start+data.length-1)) // another hidden block starting at the within this block already exits -> adapt new block
     {
@@ -1273,7 +1280,7 @@ unsigned int KateCodeFoldingTree::getRealLine(unsigned int virtualLine)
     return (*real);
 
   unsigned int tmp = virtualLine;
-  for (QValueList<hiddenLineBlock>::ConstIterator it=hiddenLines.begin();it!=hiddenLines.end();++it)
+  for (QValueList<KateHiddenLineBlock>::ConstIterator it=hiddenLines.begin();it!=hiddenLines.end();++it)
   {
     if ((*it).start<=virtualLine)
       virtualLine += (*it).length;
@@ -1298,7 +1305,7 @@ unsigned int KateCodeFoldingTree::getVirtualLine(unsigned int realLine)
 
   // kdDebug(13000)<<QString("RealLine--> %1").arg(realLine)<<endl;
 
-  for (QValueList<hiddenLineBlock>::ConstIterator it=hiddenLines.fromLast(); it!=hiddenLines.end(); --it)
+  for (QValueList<KateHiddenLineBlock>::ConstIterator it=hiddenLines.fromLast(); it!=hiddenLines.end(); --it)
   {
     if ((*it).start <= realLine)
       realLine -= (*it).length;
@@ -1326,7 +1333,7 @@ unsigned int KateCodeFoldingTree::getHiddenLinesCount(unsigned int doclen)
   hiddenLinesCountCacheValid = true;
   hiddenLinesCountCache = 0;
 
-  for (QValueList<hiddenLineBlock>::ConstIterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
+  for (QValueList<KateHiddenLineBlock>::ConstIterator it=hiddenLines.begin(); it!=hiddenLines.end(); ++it)
   {
     if ((*it).start+(*it).length<=doclen)
       hiddenLinesCountCache += (*it).length;
@@ -1340,9 +1347,11 @@ unsigned int KateCodeFoldingTree::getHiddenLinesCount(unsigned int doclen)
   return hiddenLinesCountCache;
 }
 
-
 void KateCodeFoldingTree::collapseToplevelNodes()
 {
+  // hl whole file
+  m_buffer->line (m_buffer->count()-1);
+
   if( !hasChildNodes ())
     return;
 
@@ -1362,6 +1371,9 @@ void KateCodeFoldingTree::collapseToplevelNodes()
 
 void KateCodeFoldingTree::expandToplevelNodes(int numLines)
 {
+  // hl whole file
+  m_buffer->line (m_buffer->count()-1);
+
   KateLineInfo line;
   for (int i = 0; i < numLines; i++) {
     getLineInfo(&line, i);
@@ -1373,6 +1385,9 @@ void KateCodeFoldingTree::expandToplevelNodes(int numLines)
 
 int KateCodeFoldingTree::collapseOne(int realLine)
 {
+  // hl whole file
+  m_buffer->line (m_buffer->count()-1);
+
   KateLineInfo line;
   int unrelatedBlocks = 0;
   for (int i = realLine; i >= 0; i--) {
@@ -1382,7 +1397,7 @@ int KateCodeFoldingTree::collapseOne(int realLine)
       // optimisation
       break;
 
-    if (line.endsBlock  && i != realLine) {
+    if (line.endsBlock  && ( line.invalidBlockEnd ) && (i != realLine)) {
       unrelatedBlocks++;
     }
 
@@ -1399,6 +1414,9 @@ int KateCodeFoldingTree::collapseOne(int realLine)
 
 void KateCodeFoldingTree::expandOne(int realLine, int numLines)
 {
+  // hl whole file
+  m_buffer->line (m_buffer->count()-1);
+
   KateLineInfo line;
   int blockTrack = 0;
   for (int i = realLine; i >= 0; i--) {
@@ -1451,7 +1469,7 @@ void KateCodeFoldingTree::ensureVisible( uint line )
 {
   // first have a look, if the line is really hidden
   bool found=false;
-  for (QValueList<hiddenLineBlock>::ConstIterator it=hiddenLines.begin();it!=hiddenLines.end();++it)
+  for (QValueList<KateHiddenLineBlock>::ConstIterator it=hiddenLines.begin();it!=hiddenLines.end();++it)
   {
     if ( ((*it).start<=line)  && ((*it).start+(*it).length>line) )
     {
