@@ -25,11 +25,14 @@
 #include <qobject.h>
 #include <qintdict.h>
 
+class KateBuffer;
+
 class QString;
 //END
 
-struct hiddenLineBlock
+class KateHiddenLineBlock
 {
+  public:
     unsigned int start;
     unsigned int length;
 };
@@ -93,7 +96,7 @@ class KateCodeFoldingTree : public QObject, public KateCodeFoldingNode
   Q_OBJECT
 
   public:
-    KateCodeFoldingTree (QObject *);
+    KateCodeFoldingTree (KateBuffer *buffer);
     ~KateCodeFoldingTree ();
 
     KateCodeFoldingNode *findNodeForLine (unsigned int line);
@@ -109,16 +112,20 @@ class KateCodeFoldingTree : public QObject, public KateCodeFoldingNode
     void debugDump ();
     void getLineInfo (KateLineInfo *info,unsigned int line);
 
+    unsigned int getStartLine (KateCodeFoldingNode *node);
+
     void fixRoot (int endLRel);
     void clear ();
 
   private:
+    KateBuffer *m_buffer;
+
     QIntDict<unsigned int> lineMapping;
     QIntDict<bool>         dontIgnoreUnchangedLines;
 
     QPtrList<KateCodeFoldingNode> markedForDeleting;
     QPtrList<KateCodeFoldingNode> nodesForLine;
-    QValueList<hiddenLineBlock>   hiddenLines;
+    QValueList<KateHiddenLineBlock>   hiddenLines;
 
     unsigned int hiddenLinesCountCache;
     bool         something_changed;
@@ -128,8 +135,6 @@ class KateCodeFoldingTree : public QObject, public KateCodeFoldingNode
 
     KateCodeFoldingNode *findNodeForLineDescending (KateCodeFoldingNode *, unsigned int, unsigned int, bool oneStepOnly=false);
 
-    unsigned int getStartLine (KateCodeFoldingNode *node);
-
     bool correctEndings (signed char data, KateCodeFoldingNode *node, unsigned int line, int insertPos);
 
     void dumpNode    (KateCodeFoldingNode *node,QString prefix);
@@ -186,3 +191,5 @@ class KateCodeFoldingTree : public QObject, public KateCodeFoldingNode
 };
 
 #endif
+
+// kate: space-indent on; indent-width 2; replace-tabs on;
