@@ -25,6 +25,8 @@
 #include "katefont.h"
 #include "kateschema.h"
 
+#include <math.h>
+
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kglobalsettings.h>
@@ -34,9 +36,7 @@
 #include <kreplacedialog.h>
 #include <kinstance.h>
 #include <kstaticdeleter.h>
-#include <ktexteditor/markinterface.h>
 
-#include <qcolor.h>
 #include <qtextcodec.h>
 
 //BEGIN KateConfig
@@ -97,14 +97,16 @@ KateDocumentConfig::KateDocumentConfig ()
    m_encodingSet (true),
    m_eolSet (true),
    m_backupFlagsSet (true),
+   m_backupPrefixSet (true),
    m_backupSuffixSet (true),
-   m_pluginsSet (true),
+   m_pluginsSet (m_plugins.size()),
    m_doc (0)
 {
   s_global = this;
   
   // init plugin array
   m_plugins.fill (false);
+  m_pluginsSet.fill (true);
 
   // init with defaults from config or really hardcoded ones
   KConfig *config = kapp->config();
@@ -126,12 +128,14 @@ KateDocumentConfig::KateDocumentConfig (KateDocument *doc)
    m_encodingSet (false),
    m_eolSet (false),
    m_backupFlagsSet (false),
+   m_backupPrefixSet (false),
    m_backupSuffixSet (false),
-   m_pluginsSet (false),
+   m_pluginsSet (m_plugins.size()),
    m_doc (doc)
 {  
   // init plugin array
   m_plugins.fill (false);
+  m_pluginsSet.fill (false);
 }
 
 KateDocumentConfig::~KateDocumentConfig ()
@@ -166,6 +170,8 @@ void KateDocumentConfig::readConfig (KConfig *config)
 
   setBackupFlags (config->readNumEntry("Backup Config Flags", 1));
 
+  setBackupPrefix (config->readEntry("Backup Prefix", QString ("")));
+  
   setBackupSuffix (config->readEntry("Backup Suffix", QString ("~")));
 
   // plugins
@@ -197,6 +203,8 @@ void KateDocumentConfig::writeConfig (KConfig *config)
 
   config->writeEntry("Backup Config Flags", backupFlags());
 
+  config->writeEntry("Backup Prefix", backupPrefix());
+  
   config->writeEntry("Backup Suffix", backupSuffix());
   
   // plugins
@@ -471,6 +479,14 @@ void KateDocumentConfig::setBackupFlags (uint flags)
   configEnd ();
 }
 
+const QString &KateDocumentConfig::backupPrefix () const
+{
+  if (m_backupPrefixSet || isGlobal())
+    return m_backupPrefix;
+
+  return s_global->backupPrefix();
+}
+
 const QString &KateDocumentConfig::backupSuffix () const
 {
   if (m_backupSuffixSet || isGlobal())
@@ -479,6 +495,16 @@ const QString &KateDocumentConfig::backupSuffix () const
   return s_global->backupSuffix();
 }
 
+void KateDocumentConfig::setBackupPrefix (const QString &prefix)
+{
+  configStart ();
+
+  m_backupPrefixSet = true;
+  m_backupPrefix = prefix;
+
+  configEnd ();
+}
+
 void KateDocumentConfig::setBackupSuffix (const QString &suffix)
 {
   configStart ();
@@ -494,7 +520,7 @@ bool KateDocumentConfig::plugin (uint index) const
   if (index >= m_plugins.size())
     return false;
 
-  if (m_pluginsSet || isGlobal())
+  if (m_pluginsSet[index] || isGlobal())
     return m_plugins[index];
 
   return s_global->plugin (index);
@@ -507,7 +533,7 @@ void KateDocumentConfig::setPlugin (uint index, bool load)
   
   configStart ();
 
-  m_pluginsSet = true;
+  m_pluginsSet[index] = true;
   m_plugins[index] = load;
 
   configEnd ();
@@ -522,6 +548,7 @@ KateViewConfig::KateViewConfig ()
    m_dynWordWrapIndicatorsSet (true),
    m_dynWordWrapAlignIndentSet (true),
    m_lineNumbersSet (true),
+   m_scrollBarMarksSet (true),
    m_iconBarSet (true),
    m_foldingBarSet (true),
    m_bookmarkSortSet (true),
@@ -546,6 +573,7 @@ KateViewConfig::KateViewConfig (KateView *view)
    m_dynWordWrapIndicatorsSet (false),
    m_dynWordWrapAlignIndentSet (false),
    m_lineNumbersSet (false),
+   m_scrollBarMarksSet (false),
    m_iconBarSet (false),
    m_foldingBarSet (false),
    m_bookmarkSortSet (false),
@@ -572,6 +600,8 @@ void KateViewConfig::readConfig (KConfig *config)
 
   setLineNumbers (config->readBoolEntry( "Line Numbers",  false));
 
+  setScrollBarMarks (config->readBoolEntry( "Scroll Bar Marks",  false));
+
   setIconBar (config->readBoolEntry( "Icon Bar", false ));
 
   setFoldingBar (config->readBoolEntry( "Folding Bar", true));
@@ -599,6 +629,8 @@ void KateViewConfig::writeConfig (KConfig *config)
 
   config->writeEntry( "Line Numbers", lineNumbers() );
 
+  config->writeEntry( "Scroll Bar Marks", scrollBarMarks() );
+
   config->writeEntry( "Icon Bar", iconBar() );
 
   config->writeEntry( "Folding Bar", foldingBar() );
@@ -705,6 +737,24 @@ void KateViewConfig::setLineNumbers (bool on)
   configEnd ();
 }
 
+bool KateViewConfig::scrollBarMarks () const
+{
+  if (m_scrollBarMarksSet || isGlobal())
+    return m_scrollBarMarks;
+
+  return s_global->scrollBarMarks();
+}
+
+void KateViewConfig::setScrollBarMarks (bool on)
+{
+  configStart ();
+
+  m_scrollBarMarksSet = true;
+  m_scrollBarMarks = on;
+
+  configEnd ();
+}
+
 bool KateViewConfig::iconBar () const
 {
   if (m_iconBarSet || isGlobal())
@@ -856,14 +906,8 @@ void KateViewConfig::setTextToSearchMode (int mode)
 //BEGIN KateRendererConfig
 KateRendererConfig::KateRendererConfig ()
  :
-   m_font (new FontStruct ()),
-   m_backgroundColor (0),
-   m_selectionColor (0),
-   m_highlightedLineColor (0),
-   m_highlightedBracketColor (0),
-   m_wordWrapMarkerColor (0),
-   m_tabMarkerColor (0),
-   m_iconBarColor (0),
+   m_font (new KateFontStruct ()),
+   m_lineMarkerColor (KTextEditor::MarkInterface::reservedMarkersCount()),
    m_schemaSet (true),
    m_fontSet (true),
    m_wordWrapMarkerSet (true),
@@ -874,8 +918,13 @@ KateRendererConfig::KateRendererConfig ()
    m_wordWrapMarkerColorSet (true),
    m_tabMarkerColorSet(true),
    m_iconBarColorSet (true),
+   m_lineNumberColorSet (true),
+   m_lineMarkerColorSet (m_lineMarkerColor.size()),
    m_renderer (0)
 {
+  // init bitarray
+  m_lineMarkerColorSet.fill (true);
+
   s_global = this;
 
   // init with defaults from config or really hardcoded ones
@@ -886,13 +935,7 @@ KateRendererConfig::KateRendererConfig ()
 
 KateRendererConfig::KateRendererConfig (KateRenderer *renderer)
  : m_font (0),
-   m_backgroundColor (0),
-   m_selectionColor (0),
-   m_highlightedLineColor (0),
-   m_highlightedBracketColor (0),
-   m_wordWrapMarkerColor (0),
-   m_tabMarkerColor (0),
-   m_iconBarColor (0),
+   m_lineMarkerColor (KTextEditor::MarkInterface::reservedMarkersCount()),
    m_schemaSet (false),
    m_fontSet (false),
    m_wordWrapMarkerSet (false),
@@ -903,21 +946,17 @@ KateRendererConfig::KateRendererConfig (KateRenderer *renderer)
    m_wordWrapMarkerColorSet (false),
    m_tabMarkerColorSet(false),
    m_iconBarColorSet (false),
+   m_lineNumberColorSet (false),
+   m_lineMarkerColorSet (m_lineMarkerColor.size()),
    m_renderer (renderer)
 {
+  // init bitarray
+  m_lineMarkerColorSet.fill (false);
 }
 
 KateRendererConfig::~KateRendererConfig ()
 {
   delete m_font;
-
-  delete m_backgroundColor;
-  delete m_selectionColor;
-  delete m_highlightedLineColor;
-  delete m_highlightedBracketColor;
-  delete m_wordWrapMarkerColor;
-  delete m_tabMarkerColor;
-  delete m_iconBarColor;
 }
 
 void KateRendererConfig::readConfig (KConfig *config)
@@ -979,6 +1018,7 @@ void KateRendererConfig::setSchema (uint schema)
   QColor tmp4 (tmp2.dark());
   QColor tmp5 ( KGlobalSettings::textColor() );
   QColor tmp6 ( "#EAE9E8" );
+  QColor tmp7 ( "#000000" );
 
   setBackgroundColor (config->readColorEntry("Color Background", &tmp0));
   setSelectionColor (config->readColorEntry("Color Selection", &tmp1));
@@ -987,6 +1027,22 @@ void KateRendererConfig::setSchema (uint schema)
   setWordWrapMarkerColor (config->readColorEntry("Color Word Wrap Marker", &tmp4));
   setTabMarkerColor (config->readColorEntry("Color Tab Marker", &tmp5));
   setIconBarColor (config->readColorEntry("Color Icon Bar", &tmp6));
+  setLineNumberColor (config->readColorEntry("Color Line Number", &tmp7));
+
+    // same std colors like in KateDocument::markColor
+  QColor mark[7];
+  mark[0] = Qt::blue;
+  mark[1] = Qt::red;
+  mark[2] = Qt::yellow;
+  mark[3] = Qt::magenta;
+  mark[4] = Qt::gray;
+  mark[5] = Qt::green;
+  mark[6] = Qt::red;
+
+  for (int i = 1; i < 8; i++) {
+    setLineMarkerColor(config->readColorEntry(QString("Color MarkType%1").arg(i), &mark[i - 1]),
+      static_cast<KTextEditor::MarkInterface::MarkTypes>( static_cast<int>( pow(2, i - 1) ) ));
+  }
 
   QFont f (KGlobalSettings::fixedFont());
 
@@ -995,7 +1051,7 @@ void KateRendererConfig::setSchema (uint schema)
   configEnd ();
 }
 
-FontStruct *KateRendererConfig::fontStruct ()
+KateFontStruct *KateRendererConfig::fontStruct ()
 {
   if (m_fontSet || isGlobal())
     return m_font;
@@ -1020,7 +1076,7 @@ void KateRendererConfig::setFont(const QFont &font)
   if (!m_fontSet)
   {
     m_fontSet = true;
-    m_font = new FontStruct ();
+    m_font = new KateFontStruct ();
   }
 
   m_font->setFont(font);
@@ -1046,7 +1102,7 @@ void KateRendererConfig::setWordWrapMarker (bool on)
   configEnd ();
 }
 
-const QColor *KateRendererConfig::backgroundColor() const
+const QColor& KateRendererConfig::backgroundColor() const
 {
   if (m_backgroundColorSet || isGlobal())
     return m_backgroundColor;
@@ -1059,13 +1115,12 @@ void KateRendererConfig::setBackgroundColor (const QColor &col)
   configStart ();
 
   m_backgroundColorSet = true;
-  delete m_backgroundColor;
-  m_backgroundColor = new QColor (col);
+  m_backgroundColor = col;
 
   configEnd ();
 }
 
-const QColor *KateRendererConfig::selectionColor() const
+const QColor& KateRendererConfig::selectionColor() const
 {
   if (m_selectionColorSet || isGlobal())
     return m_selectionColor;
@@ -1078,13 +1133,12 @@ void KateRendererConfig::setSelectionColor (const QColor &col)
   configStart ();
 
   m_selectionColorSet = true;
-  delete m_selectionColor;
-  m_selectionColor = new QColor (col);
+  m_selectionColor = col;
 
   configEnd ();
 }
 
-const QColor *KateRendererConfig::highlightedLineColor() const
+const QColor& KateRendererConfig::highlightedLineColor() const
 {
   if (m_highlightedLineColorSet || isGlobal())
     return m_highlightedLineColor;
@@ -1097,13 +1151,35 @@ void KateRendererConfig::setHighlightedLineColor (const QColor &col)
   configStart ();
 
   m_highlightedLineColorSet = true;
-  delete m_highlightedLineColor;
-  m_highlightedLineColor = new QColor (col);
+  m_highlightedLineColor = col;
 
   configEnd ();
 }
 
-const QColor *KateRendererConfig::highlightedBracketColor() const
+const QColor& KateRendererConfig::lineMarkerColor(KTextEditor::MarkInterface::MarkTypes type) const
+{
+  int index = static_cast<int>( log(static_cast<double>(type)) / log(2.0) );
+  Q_ASSERT( index >= 0 && index < KTextEditor::MarkInterface::reservedMarkersCount() );
+
+  if (m_lineMarkerColorSet[index] || isGlobal())
+    return m_lineMarkerColor[index];
+
+  return s_global->lineMarkerColor();
+}
+
+void KateRendererConfig::setLineMarkerColor (const QColor &col, KTextEditor::MarkInterface::MarkTypes type)
+{
+  int index = static_cast<int>( log(static_cast<double>(type)) / log(2.0) );
+  Q_ASSERT( index >= 0 && index < KTextEditor::MarkInterface::reservedMarkersCount() );
+  configStart ();
+
+  m_lineMarkerColorSet[index] = true;
+  m_lineMarkerColor[index] = col;
+
+  configEnd ();
+}
+
+const QColor& KateRendererConfig::highlightedBracketColor() const
 {
   if (m_highlightedBracketColorSet || isGlobal())
     return m_highlightedBracketColor;
@@ -1116,13 +1192,12 @@ void KateRendererConfig::setHighlightedBracketColor (const QColor &col)
   configStart ();
 
   m_highlightedBracketColorSet = true;
-  delete m_highlightedBracketColor;
-  m_highlightedBracketColor = new QColor (col);
+  m_highlightedBracketColor = col;
 
   configEnd ();
 }
 
-const QColor *KateRendererConfig::wordWrapMarkerColor() const
+const QColor& KateRendererConfig::wordWrapMarkerColor() const
 {
   if (m_wordWrapMarkerColorSet || isGlobal())
     return m_wordWrapMarkerColor;
@@ -1135,13 +1210,12 @@ void KateRendererConfig::setWordWrapMarkerColor (const QColor &col)
   configStart ();
 
   m_wordWrapMarkerColorSet = true;
-  delete m_wordWrapMarkerColor;
-  m_wordWrapMarkerColor = new QColor (col);
+  m_wordWrapMarkerColor = col;
 
   configEnd ();
 }
 
-const QColor *KateRendererConfig::tabMarkerColor() const
+const QColor& KateRendererConfig::tabMarkerColor() const
 {
   if (m_tabMarkerColorSet || isGlobal())
     return m_tabMarkerColor;
@@ -1154,13 +1228,12 @@ void KateRendererConfig::setTabMarkerColor (const QColor &col)
   configStart ();
 
   m_tabMarkerColorSet = true;
-  delete m_tabMarkerColor;
-  m_tabMarkerColor = new QColor (col);
+  m_tabMarkerColor = col;
 
   configEnd ();
 }
 
-const QColor *KateRendererConfig::iconBarColor() const
+const QColor& KateRendererConfig::iconBarColor() const
 {
   if (m_iconBarColorSet || isGlobal())
     return m_iconBarColor;
@@ -1173,11 +1246,28 @@ void KateRendererConfig::setIconBarColor (const QColor &col)
   configStart ();
 
   m_iconBarColorSet = true;
-  delete m_iconBarColor;
-  m_iconBarColor = new QColor (col);
+  m_iconBarColor = col;
 
   configEnd ();
 }
 
+const QColor& KateRendererConfig::lineNumberColor() const
+{
+  if (m_lineNumberColorSet || isGlobal())
+    return m_lineNumberColor;
+
+  return s_global->lineNumberColor();
+}
+
+void KateRendererConfig::setLineNumberColor (const QColor &col)
+{
+  configStart ();
+
+  m_lineNumberColorSet = true;
+  m_lineNumberColor = col;
+
+  configEnd ();
+}
 //END
+
 // kate: space-indent on; indent-width 2; replace-tabs on;
