@@ -1,5 +1,5 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
+   Copyright (C) 2001-2004 Christoph Cullmann <cullmann@kde.org>
    Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
    Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
@@ -18,11 +18,12 @@
    Boston, MA 02111-1307, USA.
 */
 
-#ifndef kate_document_h
-#define kate_document_h
+#ifndef _KATE_DOCUMENT_H_
+#define _KATE_DOCUMENT_H_
 
 #include "katesupercursor.h"
 #include "katetextline.h"
+#include "kateundo.h"
 
 #include "../interfaces/document.h"
 
@@ -33,7 +34,11 @@
 
 #include <dcopobject.h>
 
+#include <kmimetype.h>
+#include <klocale.h>
+
 #include <qintdict.h>
+#include <qmap.h>
 #include <qdatetime.h>
 
 namespace KTextEditor { class Plugin; }
@@ -48,13 +53,12 @@ class KateCodeFoldingTree;
 class KateBuffer;
 class KateView;
 class KateViewInternal;
-class LineRange;
 class KateArbitraryHighlight;
 class KateSuperRange;
 class KateLineInfo;
 class KateBrowserExtension;
 class KateDocumentConfig;
-class Highlight;
+class KateHighlighting;
 class KatePartPluginItem;
 class KatePartPluginInfo;
 
@@ -67,6 +71,7 @@ class QTimer;
 // Kate KTextEditor::Document class (and even KTextEditor::Editor ;)
 //
 class KateDocument : public Kate::Document,
+                     public Kate::DocumentExt,
                      public KTextEditor::ConfigInterfaceExtension,
                      public KTextEditor::EncodingInterface,
                      public KTextEditor::SessionConfigInterface,
@@ -241,7 +246,7 @@ class KateDocument : public Kate::Document,
     void undoCancel();
 
   private:
-    void editAddUndo (uint type, uint line, uint col, uint len, const QString &text);
+    void editAddUndo (KateUndoGroup::UndoType type, uint line, uint col, uint len, const QString &text);
     void editTagLine (uint line);
     void editRemoveTagLine (uint line);
     void editInsertTagLine (uint line);
@@ -446,6 +451,60 @@ class KateDocument : public Kate::Document,
     bool print ();
 
   //
+  // KTextEditor::DocumentInfoInterface ( ### unfinished )
+  //
+  public:
+    /**
+     * @return the name of the mimetype for the document.
+     *
+     * This method is using @see KMimeType::findByURL, and if the pointer
+     * is then still the default MimeType for a nonlocal or unsaved file,
+     * uses mimeTypeForContent().
+     *
+     * @since Kate 2.3
+     */
+    QString mimeType();
+
+    /**
+     * @return the calculated size in bytes that the document would have when saved to
+     * disk.
+     *
+     * @since Kate 2.3
+     * @todo implement this (it returns 0 right now)
+     */
+    long fileSize();
+
+    /**
+     * @return the calculated size the document would have when saved to disk
+     * as a human readable string.
+     *
+     * @since Kate 2.3
+     * @todo implement this (it returns "UNKNOWN")
+     */
+    QString niceFileSize();
+
+    /**
+     * @return a pointer to the KMimeType for this document, found by analyzing the
+     * actual content.
+     *
+     * Note that this method is *not* part of the DocumentInfoInterface.
+     *
+     * @since Kate 2.3
+     */
+    KMimeType::Ptr mimeTypeForContent();
+
+  //
+  // KTextEditor::VariableInterface
+  //
+  public:
+    QString variable( const QString &name ) const;
+
+  signals:
+    void variableChanged( const QString &, const QString & );
+
+  private:
+    QMap<QString, QString> m_storedVariables;
+
   //
   // KParts::ReadWrite stuff
   //
@@ -506,8 +565,8 @@ class KateDocument : public Kate::Document,
      */
     uint lastLine() const { return numLines()-1;}
 
-    TextLine::Ptr kateTextLine(uint i);
-    TextLine::Ptr plainKateTextLine(uint i);
+    KateTextLine::Ptr kateTextLine(uint i);
+    KateTextLine::Ptr plainKateTextLine(uint i);
 
     uint configFlags ();
     void setConfigFlags (uint flags);
@@ -520,7 +579,7 @@ class KateDocument : public Kate::Document,
     // Repaint all of all of the views
     void repaintViews(bool paintOnlyDirty = true);
 
-    Highlight *highlight () { return m_highlight; }
+    KateHighlighting *highlight () { return m_highlight; }
 
   public slots:    //please keep prototypes and implementations in same order
     void tagLines(int start, int end);
@@ -569,6 +628,7 @@ class KateDocument : public Kate::Document,
 
     void indent ( KateView *view, uint line, int change );
     void comment ( KateView *view, uint line, int change );
+    void align ( uint line );
 
     enum TextTransform { Uppercase, Lowercase, Capitalize };
 
@@ -598,7 +658,7 @@ class KateDocument : public Kate::Document,
       Otherwise they have both the value -1.
       @param line Line of the character which is examined first.
       @param col Column of the character which is examined first.
-      @returns True if the specified or a following character is not a space
+      @return True if the specified or a following character is not a space
                Otherwise false.
     */
     bool nextNonSpaceCharPos(int &line, int &col);
@@ -607,22 +667,52 @@ class KateDocument : public Kate::Document,
       Find the position (line and col) of the previous char
       that is not a space. If found line and col point to the found character.
       Otherwise they have both the value -1.
-      @returns True if the specified or a preceding character is not a space.
+      @return True if the specified or a preceding character is not a space.
                Otherwise false.
     */
     bool previousNonSpaceCharPos(int &line, int &col);
 
-    void addStartLineCommentToSingleLine(int line);
-    bool removeStartLineCommentFromSingleLine(int line);
+    /**
+    * Sets a comment marker as defined by the language providing the attribute
+    * @p attrib on the line @p line
+    */
+    void addStartLineCommentToSingleLine(int line, int attrib=0);
+    /**
+    * Removes a comment marker as defined by the language providing the attribute
+    * @p attrib on the line @p line
+    */
+    bool removeStartLineCommentFromSingleLine(int line, int attrib=0);
 
-    void addStartStopCommentToSingleLine(int line);
-    bool removeStartStopCommentFromSingleLine(int line);
+    /**
+    * @see addStartLineCommentToSingleLine.
+    */
+    void addStartStopCommentToSingleLine(int line, int attrib=0);
+    /**
+    *@see removeStartLineCommentFromSingleLine.
+    */
+    bool removeStartStopCommentFromSingleLine(int line, int attrib=0);
 
-    void addStartStopCommentToSelection();
-    void addStartLineCommentToSelection();
+    /**
+     * Add a comment marker as defined by the language providing the attribute
+     * @p attrib to each line in the selection.
+     */
+           void addStartStopCommentToSelection( int attrib=0 );
+    /**
+    * @see addStartStopCommentToSelection.
+    */
+          void addStartLineCommentToSelection( int attrib=0 );
 
-    bool removeStartStopCommentFromSelection();
-    bool removeStartLineCommentFromSelection();
+    /**
+    * Removes comment markers relevant to the language providing
+    * the attribuge @p attrib from each line in the selection.
+    *
+    * @return whether the operation succeded.
+    */
+    bool removeStartStopCommentFromSelection( int attrib=0 );
+    /**
+    * @see removeStartStopCommentFromSelection.
+    */
+    bool removeStartLineCommentFromSelection( int attrib=0 );
 
   public:
     QString getWord( const KateTextCursor& cursor );
@@ -637,16 +727,7 @@ class KateDocument : public Kate::Document,
   private:
     void guiActivateEvent( KParts::GUIActivateEvent *ev );
 
-  private slots:
-    void slotBufferChanged();
-
   public:
-    /**
-     * Checks if the file on disk is newer than document contents.
-     * If forceReload is true, the document is reloaded without asking the user,
-     * otherwise [default] the user is asked what to do.
-     */
-    void isModOnHD(bool forceReload=false);
 
     QString docName () {return m_docName;};
 
@@ -656,12 +737,37 @@ class KateDocument : public Kate::Document,
 
     KateCodeFoldingTree *foldingTree ();
 
+  public:
+    /**
+     * @return wheather the document is modified on disc since last saved.
+     *
+     * @since 3.3
+     */
+    bool isModifiedOnDisc() { return m_modOnHd; };
+
+    /** @deprecated */
+    void isModOnHD( bool =false ) {};
+
+    void setModifiedOnDisk( int reason );
+
   public slots:
     /**
-     * Reloads the current document from disk if possible
+     * Ask the user what to do, if the file has been modified on disc.
+     * Reimplemented from Kate::Document.
+     *
+     * @since 3.3
+     */
+    void slotModifiedOnDisk( Kate::View *v=0 );
+
+    /**
+     * Reloads the current document from disc if possible
      */
     void reloadFile();
 
+  private:
+    int m_isasking; // don't reenter slotModifiedOnDisk when this is true
+                    // -1: ignore once, 0: false, 1: true
+
   public slots:
     void setEncoding (const QString &e);
     QString encoding() const;
@@ -721,8 +827,27 @@ class KateDocument : public Kate::Document,
      * This is using KMD5::hexDigest().
      *
      * @return wheather the operation was attempted and succeded.
+     *
+     * @since 3.3
      */
-    bool createDigest( QCString &result );
+    bool createDigest ( QCString &result );
+
+    /**
+     * create a string for the modonhd warnings, giving the reason.
+     *
+     * @since 3.3
+     */
+    QString reasonedMOHString() const;
+
+    /**
+     * Removes all trailing whitespace form @p line, if
+     * the cfRemoveTrailingDyn confg flag is set,
+     * and the active view cursor is not on line and behind
+     * the last nonspace character.
+     *
+     * @since 3.3
+     */
+    void removeTrailingSpace( uint line );
 
   public:
     // should cursor be wrapped ? take config + blockselection state in account
@@ -738,9 +863,9 @@ class KateDocument : public Kate::Document,
   //
   private:
     // text buffer
-    KateBuffer *buffer;
+    KateBuffer *m_buffer;
 
-    Highlight *m_highlight;
+    KateHighlighting *m_highlight;
 
     KateArbitraryHighlight* m_arbitraryHL;
 
@@ -759,6 +884,11 @@ class KateDocument : public Kate::Document,
     int m_fileType;
     bool m_fileTypeSetByUser;
 
+    /**
+     * document is still reloading a file
+     */
+    bool m_reloading;
+
   public slots:
     void spellcheck();
     void ready(KSpell *);
@@ -771,15 +901,14 @@ class KateDocument : public Kate::Document,
     void slotQueryClose_save(bool *handled, bool* abortClosing);
 
   private:
-    void makeAttribs ();
+    //void makeAttribs ();
 
     void locatePosition( uint pos, uint& line, uint& col );
     KSpell*         m_kspell;
-    int             m_mispellCount;
-    int             m_replaceCount;
-    bool            m_reloading;
 
   public:
+    void makeAttribs ();
+
     static bool checkOverwrite( KURL u );
 
     static void setDefaultEncoding (const QString &encoding);
