@@ -47,18 +47,49 @@ class KateFontMetrics : public QFontMetrics
 };
 
 //
-// FontStruct definition
+// KateFontStruct definition
 //
 
-class FontStruct
+class KateFontStruct
 {
   public:
-    FontStruct();
-    ~FontStruct();
-
-    int width(const QString& text, int col, bool bold, bool italic, int tabWidth);
-    int width(const QChar& c, bool bold, bool italic, int tabWidth);
+    KateFontStruct();
+    ~KateFontStruct();
+  
+    void setFont(const QFont & font);
+      
+  private:
+    void updateFontData ();
 
+  public:
+    inline int width (const QString& text, int col, bool bold, bool italic, int tabWidth)
+    {
+      if (text[col] == QChar('\t'))
+        return tabWidth * myFontMetrics.width(' ');
+    
+      return (bold) ?
+        ( (italic) ?
+          myFontMetricsBI.charWidth(text, col) :
+          myFontMetricsBold.charWidth(text, col) ) :
+        ( (italic) ?
+          myFontMetricsItalic.charWidth(text, col) :
+          myFontMetrics.charWidth(text, col) );
+    }
+    
+    inline int width (const QChar& c, bool bold, bool italic, int tabWidth)
+    {
+      if (c == QChar('\t'))
+        return tabWidth * myFontMetrics.width(' ');
+    
+      return (bold) ?
+        ( (italic) ?
+          myFontMetricsBI.width(c) :
+          myFontMetricsBold.width(c) ) :
+        ( (italic) ?
+          myFontMetricsItalic.width(c) :
+          myFontMetrics.width(c) );
+    }
+    
     inline const QFont& font(bool bold, bool italic) const
     {
       return (bold) ?
@@ -66,11 +97,8 @@ class FontStruct
         ( (italic) ? myFontItalic : myFont );
     }
 
-    void setFont(const QFont & font);
-
-  private:
-     void updateFontData ();
-
+    inline bool fixedPitch() const { return m_fixedPitch; }
+    
   public:
     QFont myFont, myFontBold, myFontItalic, myFontBI;
 
@@ -78,6 +106,9 @@ class FontStruct
 
     int fontHeight;
     int fontAscent;
+
+  private:
+    bool m_fixedPitch;
 };
 
 #endif
