@@ -71,31 +71,16 @@ KateAttribute* KateRenderer::attribute(uint pos)
   return &m_attributes->at(0);
 }
 
-bool KateRenderer::drawCaret() const
-{
-  return m_drawCaret;
-}
-
 void KateRenderer::setDrawCaret(bool drawCaret)
 {
   m_drawCaret = drawCaret;
 }
 
-bool KateRenderer::caretStyle() const
-{
-  return m_caretStyle;
-}
-
-void KateRenderer::setCaretStyle(int style)
+void KateRenderer::setCaretStyle(KateRenderer::caretStyles style)
 {
   m_caretStyle = style;
 }
 
-bool KateRenderer::showTabs() const
-{
-  return m_showTabs;
-}
-
 void KateRenderer::setShowTabs(bool showTabs)
 {
   m_showTabs = showTabs;
@@ -106,11 +91,6 @@ void KateRenderer::setTabWidth(int tabWidth)
   m_tabWidth = tabWidth;
 }
 
-bool KateRenderer::showSelections() const
-{
-  return m_showSelections;
-}
-
 void KateRenderer::setShowSelections(bool showSelections)
 {
   m_showSelections = showSelections;
@@ -147,12 +127,12 @@ void KateRenderer::setPrinterFriendly(bool printerFriendly)
   setDrawCaret(false);
 }
 
-void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xStart, int xEnd, const KateTextCursor* cursor, const KateTextRange* bracketmark)
+void KateRenderer::paintTextLine(QPainter& paint, const KateLineRange* range, int xStart, int xEnd, const KateTextCursor* cursor, const KateTextRange* bracketmark)
 {
   int line = range->line;
 
   // textline
-  TextLine::Ptr textLine = m_doc->kateTextLine(line);
+  KateTextLine::Ptr textLine = m_doc->kateTextLine(line);
 
   if (!textLine)
     return;
@@ -164,28 +144,28 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
   // A bit too verbose for my tastes
   // Re-write a bracketmark class? put into its own function? add more helper constructors to the range stuff?
   // Also, need a light-weight arbitraryhighlightrange class for static stuff
-  ArbitraryHighlightRange* bracketStartRange (0L);
-  ArbitraryHighlightRange* bracketEndRange (0L);
+  KateArbitraryHighlightRange* bracketStartRange (0L);
+  KateArbitraryHighlightRange* bracketEndRange (0L);
   if (bracketmark && bracketmark->isValid()) {
     if (range->includesCursor(bracketmark->start())) {
       KateTextCursor startend = bracketmark->start();
       startend.setCol(startend.col()+1);
-      bracketStartRange = new ArbitraryHighlightRange(m_doc, bracketmark->start(), startend);
-      bracketStartRange->setBGColor(*config()->highlightedBracketColor());
+      bracketStartRange = new KateArbitraryHighlightRange(m_doc, bracketmark->start(), startend);
+      bracketStartRange->setBGColor(config()->highlightedBracketColor());
       superRanges.append(bracketStartRange);
     }
 
     if (range->includesCursor(bracketmark->end())) {
       KateTextCursor endend = bracketmark->end();
       endend.setCol(endend.col()+1);
-      bracketEndRange = new ArbitraryHighlightRange(m_doc, bracketmark->end(), endend);
-      bracketEndRange->setBGColor(*config()->highlightedBracketColor());
+      bracketEndRange = new KateArbitraryHighlightRange(m_doc, bracketmark->end(), endend);
+      bracketEndRange->setBGColor(config()->highlightedBracketColor());
       superRanges.append(bracketEndRange);
     }
   }
 
   // font data
-  FontStruct * fs = config()->fontStruct();
+  KateFontStruct * fs = config()->fontStruct();
 
   bool currentLine = false;
 
@@ -219,17 +199,17 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
   int cursorMaxWidth = 0;
 
   // should we paint the word wrap marker?
-  bool paintWWMarker = !isPrinterFriendly() && config()->wordWrapMarker() && QFontInfo( fs->myFont ).fixedPitch();
-  
+  bool paintWWMarker = !isPrinterFriendly() && config()->wordWrapMarker() && fs->fixedPitch();
+
   // Normal background color
-  QColor backgroundColor (*config()->backgroundColor());
+  QColor backgroundColor (config()->backgroundColor());
 
   // Paint selection background as the whole line is selected
   if (!isPrinterFriendly())
   {
     if (showSelections() && m_doc->lineSelected(line))
     {
-      backgroundColor = *config()->selectionColor();
+      backgroundColor = config()->selectionColor();
       selectionPainted = true;
       hasSel = true;
       startSel = 0;
@@ -239,7 +219,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
     {
       // paint the current line background if we're on the current line
       if (currentLine)
-        backgroundColor = *config()->highlightedLineColor();
+        backgroundColor = config()->highlightedLineColor();
 
       // Check for mark background
       int markRed = 0, markGreen = 0, markBlue = 0, markCount = 0;
@@ -332,7 +312,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
 
   // Draws the dashed underline at the start of a folded block of text.
   if (range->startsInvisibleBlock) {
-    paint.setPen(QPen(*config()->wordWrapMarkerColor(), 1, Qt::DashLine));
+    paint.setPen(QPen(config()->wordWrapMarkerColor(), 1, Qt::DashLine));
     paint.drawLine(0, fs->fontHeight - 1, xEnd - xStart, fs->fontHeight - 1);
   }
 
@@ -345,8 +325,8 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
 
   // draw word-wrap-honor-indent filling
   if (range->xOffset() && range->xOffset() > xStart)
-    paint.fillRect(0, 0, range->xOffset() - xStart, fs->fontHeight, QBrush(*config()->wordWrapMarkerColor(), QBrush::DiagCrossPattern));
-  
+    paint.fillRect(0, 0, range->xOffset() - xStart, fs->fontHeight, QBrush(config()->wordWrapMarkerColor(), QBrush::DiagCrossPattern));
+
   // Optimisation to quickly draw an empty line of text
   if (len < 1)
   {
@@ -374,8 +354,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
 
       // Determine current syntax highlighting attribute
       // A bit legacy but doesn't need to change
-      KateAttribute* curAt = (!noAttribs && (*a) >= atLen) ? &at[0] : &at[*a];
-
+      KateAttribute* curAt = (noAttribs || ((*a) >= atLen)) ? &at[0] : &at[*a];
       // X position calculation. Incorrect for fonts with non-zero leftBearing() and rightBearing() results.
       // TODO: make internal charWidth() function, use QFontMetrics::charWidth().
       xPosAfter += curAt->width(*fs, curChar, m_tabWidth);
@@ -403,7 +382,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
         // Incorporate in arbitrary highlighting
         if (curAt != oldAt || curColor != oldColor || (superRanges.count() && superRanges.currentBoundary() && *(superRanges.currentBoundary()) == currentPos)) {
           if (superRanges.count() && superRanges.currentBoundary() && *(superRanges.currentBoundary()) == currentPos)
-            customHL = ArbitraryHighlightRange::merge(superRanges.rangesIncluding(currentPos));
+            customHL = KateArbitraryHighlightRange::merge(superRanges.rangesIncluding(currentPos));
 
           KateAttribute hl = customHL;
 
@@ -432,7 +411,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
         {
           if (!isPrinterFriendly() && !selectionPainted) {
             if (isSel)
-              paint.fillRect(oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight, *config()->selectionColor());
+              paint.fillRect(oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight, config()->selectionColor());
             else if (currentHL.itemSet(KateAttribute::BGColor))
               paint.fillRect(oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight, currentHL.bgColor());
           }
@@ -447,7 +426,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
           if (showTabs())
           {
             QPen penBackup( paint.pen() );
-            paint.setPen( *(config()->tabMarkerColor()) );
+            paint.setPen( config()->tabMarkerColor() );
             paint.drawPoint(xPos - xStart, y);
             paint.drawPoint(xPos - xStart + 1, y);
             paint.drawPoint(xPos - xStart, y - 1);
@@ -491,7 +470,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
           // TODO: genericise background painting
           if (!isPrinterFriendly() && !selectionPainted) {
             if (isSel)
-              paint.fillRect(oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight, *config()->selectionColor());
+              paint.fillRect(oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight, config()->selectionColor());
             else if (currentHL.itemSet(KateAttribute::BGColor))
               paint.fillRect(oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight, currentHL.bgColor());
           }
@@ -521,6 +500,12 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
           // Here's where the money is...
           paint.drawText(oldXPos-xStart, y, textLine->string(), oldCol, curCol+1-oldCol);
 
+          // Draw preedit's underline
+          if (isIMEdit) {
+            QRect r( oldXPos - xStart, 0, xPosAfter - oldXPos, fs->fontHeight );
+            paint.drawLine( r.bottomLeft(), r.bottomRight() );
+          }
+
           // Put pen color back
           if (isIMSel) paint.restore();
 
@@ -579,7 +564,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
   // TODO: genericise background painting
   if (!isPrinterFriendly() && showSelections() && !selectionPainted && m_doc->lineEndSelected (line, endcol))
   {
-    paint.fillRect(xPos-xStart, 0, xEnd - xStart, fs->fontHeight, *config()->selectionColor());
+    paint.fillRect(xPos-xStart, 0, xEnd - xStart, fs->fontHeight, config()->selectionColor());
     selectionPainted = true;
   }
 
@@ -605,10 +590,10 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
         paint.fillRect(cursorXPos2-xStart, 0, 2, fs->fontHeight, attribute(0)->textColor());
     }
   }
-  
+
   // show word wrap marker if desirable
   if ( paintWWMarker ) {
-    paint.setPen( *config()->wordWrapMarkerColor() );
+    paint.setPen( config()->wordWrapMarkerColor() );
     int _x = m_doc->config()->wordWrapAt() * fs->myFontMetrics.width('x') - xStart;
     paint.drawLine( _x,0,_x,fs->fontHeight );
   }
@@ -618,7 +603,7 @@ void KateRenderer::paintTextLine(QPainter& paint, const LineRange* range, int xS
   delete bracketEndRange;
 }
 
-uint KateRenderer::textWidth(const TextLine::Ptr &textLine, int cursorCol)
+uint KateRenderer::textWidth(const KateTextLine::Ptr &textLine, int cursorCol)
 {
   if (!textLine)
     return 0;
@@ -628,7 +613,7 @@ uint KateRenderer::textWidth(const TextLine::Ptr &textLine, int cursorCol)
   if (cursorCol < 0)
     cursorCol = len;
 
-  FontStruct *fs = config()->fontStruct();
+  KateFontStruct *fs = config()->fontStruct();
 
   int x = 0;
   int width;
@@ -651,9 +636,9 @@ uint KateRenderer::textWidth(const TextLine::Ptr &textLine, int cursorCol)
   return x;
 }
 
-uint KateRenderer::textWidth(const TextLine::Ptr &textLine, uint startcol, uint maxwidth, bool *needWrap, int *endX)
+uint KateRenderer::textWidth(const KateTextLine::Ptr &textLine, uint startcol, uint maxwidth, bool *needWrap, int *endX)
 {
-  FontStruct *fs = config()->fontStruct();
+  KateFontStruct *fs = config()->fontStruct();
   uint x = 0;
   uint endcol = startcol;
   int endX2 = 0;
@@ -756,11 +741,11 @@ uint KateRenderer::textWidth( KateTextCursor &cursor, int xPos, uint startCol)
   int len;
   int x, oldX;
 
-  FontStruct *fs = config()->fontStruct();
+  KateFontStruct *fs = config()->fontStruct();
 
   if (cursor.line() < 0) cursor.setLine(0);
   if (cursor.line() > (int)m_doc->lastLine()) cursor.setLine(m_doc->lastLine());
-  TextLine::Ptr textLine = m_doc->kateTextLine(cursor.line());
+  KateTextLine::Ptr textLine = m_doc->kateTextLine(cursor.line());
 
   if (!textLine) return 0;
 
@@ -805,18 +790,18 @@ const QFontMetrics* KateRenderer::currentFontMetrics()
   return config()->fontMetrics();
 }
 
-uint KateRenderer::textPos(uint line, int xPos, uint startCol)
+uint KateRenderer::textPos(uint line, int xPos, uint startCol, bool nearest)
 {
-  return textPos(m_doc->kateTextLine(line), xPos, startCol);
+  return textPos(m_doc->kateTextLine(line), xPos, startCol, nearest);
 }
 
-uint KateRenderer::textPos(const TextLine::Ptr &textLine, int xPos, uint startCol)
+uint KateRenderer::textPos(const KateTextLine::Ptr &textLine, int xPos, uint startCol, bool nearest)
 {
   Q_ASSERT(textLine);
   if (!textLine)
     return 0;
 
-  FontStruct *fs = config()->fontStruct();
+  KateFontStruct *fs = config()->fontStruct();
 
   int x, oldX;
   x = oldX = 0;
@@ -831,7 +816,7 @@ uint KateRenderer::textPos(const TextLine::Ptr &textLine, int xPos, uint startCo
 
     z++;
   }
-  if (xPos - oldX < x - xPos && z > 0) {
+  if ( ( (! nearest) || xPos - oldX < x - xPos ) && z > 0 ) {
     z--;
    // newXPos = oldX;
   }// else newXPos = x;
