@@ -19,6 +19,10 @@
 
 #include "katesyntaxdocument.h"
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
@@ -27,10 +31,7 @@
 
 #include <qfile.h>
 
-/** Constructor
-    Sets the current file to nothing and build the ModeList (katesyntaxhighlightingrc)
-*/
-SyntaxDocument::SyntaxDocument(bool force)
+KateSyntaxDocument::KateSyntaxDocument(bool force)
   : QDomDocument()
 {
   // Let's build the Mode List (katesyntaxhighlightingrc)
@@ -38,10 +39,7 @@ SyntaxDocument::SyntaxDocument(bool force)
   myModeList.setAutoDelete( true );
 }
 
-/** Destructor
-    Do nothing yet
-*/
-SyntaxDocument::~SyntaxDocument()
+KateSyntaxDocument::~KateSyntaxDocument()
 {
 }
 
@@ -49,7 +47,7 @@ SyntaxDocument::~SyntaxDocument()
     the new one and assign some other things.
     identifier = File name and path of the new xml needed
 */
-bool SyntaxDocument::setIdentifier(const QString& identifier)
+bool KateSyntaxDocument::setIdentifier(const QString& identifier)
 {
   // if the current file is the same as the new one don't do anything.
   if(currentFile != identifier)
@@ -89,17 +87,10 @@ bool SyntaxDocument::setIdentifier(const QString& identifier)
   return true;
 }
 
-/** Get the complete syntax mode list
-*/
-SyntaxModeList SyntaxDocument::modeList()
-{
-  return myModeList;
-}
-
 /**
- * Jump to the next group, syntaxContextData::currentGroup will point to the next group
+ * Jump to the next group, KateSyntaxContextData::currentGroup will point to the next group
  */
-bool SyntaxDocument::nextGroup( syntaxContextData* data)
+bool KateSyntaxDocument::nextGroup( KateSyntaxContextData* data)
 {
   if(!data)
     return false;
@@ -128,9 +119,9 @@ bool SyntaxDocument::nextGroup( syntaxContextData* data)
 }
 
 /**
- * Jump to the next item, syntaxContextData::item will point to the next item
+ * Jump to the next item, KateSyntaxContextData::item will point to the next item
  */
-bool SyntaxDocument::nextItem( syntaxContextData* data)
+bool KateSyntaxDocument::nextItem( KateSyntaxContextData* data)
 {
   if(!data)
     return false;
@@ -156,9 +147,9 @@ bool SyntaxDocument::nextItem( syntaxContextData* data)
 }
 
 /**
- * This function is used to fetch the atributes of the tags of the item in a syntaxContextData.
+ * This function is used to fetch the atributes of the tags of the item in a KateSyntaxContextData.
  */
-QString SyntaxDocument::groupItemData( const syntaxContextData* data, const QString& name){
+QString KateSyntaxDocument::groupItemData( const KateSyntaxContextData* data, const QString& name){
   if(!data)
     return QString::null;
 
@@ -178,7 +169,7 @@ QString SyntaxDocument::groupItemData( const syntaxContextData* data, const QStr
 
 }
 
-QString SyntaxDocument::groupData( const syntaxContextData* data,const QString& name)
+QString KateSyntaxDocument::groupData( const KateSyntaxContextData* data,const QString& name)
 {
   if(!data)
     return QString::null;
@@ -193,15 +184,15 @@ QString SyntaxDocument::groupData( const syntaxContextData* data,const QString&
   }
 }
 
-void SyntaxDocument::freeGroupInfo( syntaxContextData* data)
+void KateSyntaxDocument::freeGroupInfo( KateSyntaxContextData* data)
 {
   if (data)
     delete data;
 }
 
-syntaxContextData* SyntaxDocument::getSubItems(syntaxContextData* data)
+KateSyntaxContextData* KateSyntaxDocument::getSubItems(KateSyntaxContextData* data)
 {
-  syntaxContextData *retval = new syntaxContextData;
+  KateSyntaxContextData *retval = new KateSyntaxContextData;
 
   if (data != 0)
   {
@@ -212,7 +203,7 @@ syntaxContextData* SyntaxDocument::getSubItems(syntaxContextData* data)
   return retval;
 }
 
-bool SyntaxDocument::getElement (QDomElement &element, const QString &mainGroupName, const QString &config)
+bool KateSyntaxDocument::getElement (QDomElement &element, const QString &mainGroupName, const QString &config)
 {
   kdDebug(13010) << "Looking for \"" << mainGroupName << "\" -> \"" << config << "\"." << endl;
 
@@ -249,15 +240,15 @@ bool SyntaxDocument::getElement (QDomElement &element, const QString &mainGroupN
 }
 
 /**
- * Get the syntaxContextData of the QDomElement Config inside mainGroupName
- * syntaxContextData::item will contain the QDomElement found
+ * Get the KateSyntaxContextData of the QDomElement Config inside mainGroupName
+ * KateSyntaxContextData::item will contain the QDomElement found
  */
-syntaxContextData* SyntaxDocument::getConfig(const QString& mainGroupName, const QString &config)
+KateSyntaxContextData* KateSyntaxDocument::getConfig(const QString& mainGroupName, const QString &config)
 {
   QDomElement element;
   if (getElement(element, mainGroupName, config))
   {
-    syntaxContextData *data = new syntaxContextData;
+    KateSyntaxContextData *data = new KateSyntaxContextData;
     data->item = element;
     return data;
   }
@@ -265,15 +256,15 @@ syntaxContextData* SyntaxDocument::getConfig(const QString& mainGroupName, const
 }
 
 /**
- * Get the syntaxContextData of the QDomElement Config inside mainGroupName
- * syntaxContextData::parent will contain the QDomElement found
+ * Get the KateSyntaxContextData of the QDomElement Config inside mainGroupName
+ * KateSyntaxContextData::parent will contain the QDomElement found
  */
-syntaxContextData* SyntaxDocument::getGroupInfo(const QString& mainGroupName, const QString &group)
+KateSyntaxContextData* KateSyntaxDocument::getGroupInfo(const QString& mainGroupName, const QString &group)
 {
   QDomElement element;
   if (getElement(element, mainGroupName, group+"s"))
   {
-    syntaxContextData *data = new syntaxContextData;
+    KateSyntaxContextData *data = new KateSyntaxContextData;
     data->parent = element;
     return data;
   }
@@ -283,7 +274,7 @@ syntaxContextData* SyntaxDocument::getGroupInfo(const QString& mainGroupName, co
 /**
  * Returns a list with all the keywords inside the list type
  */
-QStringList& SyntaxDocument::finddata(const QString& mainGroup, const QString& type, bool clearList)
+QStringList& KateSyntaxDocument::finddata(const QString& mainGroup, const QString& type, bool clearList)
 {
   kdDebug(13010)<<"Create a list of keywords \""<<type<<"\" from \""<<mainGroup<<"\"."<<endl;
   if (clearList)
@@ -336,7 +327,7 @@ QStringList& SyntaxDocument::finddata(const QString& mainGroup, const QString& t
 /** Generate the list of hl modes, store them in myModeList
     force: if true forces to rebuild the Mode List from the xml files (instead of katesyntax...rc)
 */
-void SyntaxDocument::setupModeList (bool force)
+void KateSyntaxDocument::setupModeList (bool force)
 {
   // If there's something in myModeList the Mode List was already built so, don't do it again
   if (!myModeList.isEmpty())
@@ -360,22 +351,31 @@ void SyntaxDocument::setupModeList (bool force)
   for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it )
   {
     // Each file has a group called:
-    QString Group="Cache "+*it;
+    QString Group="Cache "+ *it;
+
+    // Let's go to this group
+    config.setGroup(Group);
+
+    // stat the file
+    struct stat sbuf;
+    memset (&sbuf, 0, sizeof(sbuf));
+    stat(QFile::encodeName(*it), &sbuf);
 
     // If the group exist and we're not forced to read the xml file, let's build myModeList for katesyntax..rc
-    if ((config.hasGroup(Group)) && (!force))
+    if (!force && config.hasGroup(Group) && (sbuf.st_mtime == config.readNumEntry("lastModified")))
     {
-      // Let's go to this group
-      config.setGroup(Group);
-
-      // Let's make a new syntaxModeListItem to instert in myModeList from the information in katesyntax..rc
-      syntaxModeListItem *mli=new syntaxModeListItem;
-      mli->name       = config.readEntry("name"); // ### TODO: translation (bug #72220)
+      // Let's make a new KateSyntaxModeListItem to instert in myModeList from the information in katesyntax..rc
+      KateSyntaxModeListItem *mli=new KateSyntaxModeListItem;
+      mli->name       = config.readEntry("name");
+      mli->nameTranslated = i18n("Language",mli->name.utf8());
       mli->section    = i18n("Language Section",config.readEntry("section").utf8());
       mli->mimetype   = config.readEntry("mimetype");
       mli->extension  = config.readEntry("extension");
       mli->version    = config.readEntry("version");
       mli->priority   = config.readEntry("priority");
+      mli->author    = config.readEntry("author");
+      mli->license   = config.readEntry("license");
+      mli->hidden   =  config.readBoolEntry("hidden");
       mli->identifier = *it;
 
       // Apend the item to the list
@@ -383,6 +383,8 @@ void SyntaxDocument::setupModeList (bool force)
     }
     else
     {
+      kdDebug (13010) << "UPDATE hl cache for: " << *it << endl;
+
       // We're forced to read the xml files or the mode doesn't exist in the katesyntax...rc
       QFile f(*it);
 
@@ -407,7 +409,7 @@ void SyntaxDocument::setupModeList (bool force)
             if (root.tagName()=="language")
             {
               // let's make the mode list item.
-              syntaxModeListItem *mli = new syntaxModeListItem;
+              KateSyntaxModeListItem *mli = new KateSyntaxModeListItem;
 
               mli->name      = root.attribute("name");
               mli->section   = root.attribute("section");
@@ -415,26 +417,32 @@ void SyntaxDocument::setupModeList (bool force)
               mli->extension = root.attribute("extensions");
               mli->version   = root.attribute("version");
               mli->priority  = root.attribute("priority");
+              mli->author    = root.attribute("author");
+              mli->license   = root.attribute("license");
+
+              QString hidden = root.attribute("hidden");
+              mli->hidden    = (hidden == "true" || hidden == "TRUE");
 
               mli->identifier = *it;
 
               // Now let's write or overwrite (if force==true) the entry in katesyntax...rc
               config.setGroup(Group);
               config.writeEntry("name",mli->name);
-              if (mli->section.isEmpty()) // ### TODO: can this happen at all?
-                config.writeEntry("section","Other");
-              else
-                config.writeEntry("section",mli->section);
+              config.writeEntry("section",mli->section);
               config.writeEntry("mimetype",mli->mimetype);
               config.writeEntry("extension",mli->extension);
               config.writeEntry("version",mli->version);
               config.writeEntry("priority",mli->priority);
+              config.writeEntry("author",mli->author);
+              config.writeEntry("license",mli->license);
+              config.writeEntry("hidden",mli->hidden);
+
+              // modified time to keep cache in sync
+              config.writeEntry("lastModified", sbuf.st_mtime);
 
               // Now that the data is in the config file, translate section
-              if (mli->section.isEmpty()) // ### TODO: can this happen at all?
-                mli->section    = i18n("Language Section",mli->section.utf8());
-              else
-                mli->section    = i18n("Language Section","Other"); // We need the i18n context for when reading again the config
+              mli->section    = i18n("Language Section",mli->section.utf8());
+              mli->nameTranslated = i18n("Language",mli->name.utf8());
 
               // Append the new item to the list.
               myModeList.append(mli);
@@ -443,13 +451,14 @@ void SyntaxDocument::setupModeList (bool force)
         }
         else
         {
-          syntaxModeListItem *emli=new syntaxModeListItem;
+          KateSyntaxModeListItem *emli=new KateSyntaxModeListItem;
 
           emli->section=i18n("Errors!");
           emli->mimetype="invalid_file/invalid_file";
           emli->extension="invalid_file.invalid_file";
           emli->version="1.";
-          emli->name=i18n("Error: %1").arg(*it);
+          emli->name=QString ("Error: %1").arg(*it); // internal
+          emli->nameTranslated=i18n("Error: %1").arg(*it); // translated
           emli->identifier=(*it);
 
           myModeList.append(emli);
@@ -457,6 +466,7 @@ void SyntaxDocument::setupModeList (bool force)
       }
     }
   }
+
   // Syncronize with the file katesyntax...rc
   config.sync();
 }
