@@ -50,6 +50,8 @@
 
 #include <qtimer.h>
 
+#include <kdebug.h>
+
 KateCmdLine::KateCmdLine (KateView *view)
   : KLineEdit (view)
   , m_view (view)
@@ -61,10 +63,6 @@ KateCmdLine::KateCmdLine (KateView *view)
   completionObject()->insertItems (KateCmd::self()->cmds());
 }
 
-KateCmdLine::~KateCmdLine ()
-{
-}
-
 void KateCmdLine::slotReturnPressed ( const QString& cmd )
 {
   if (cmd.length () > 0)
@@ -106,7 +104,10 @@ void KateCmdLine::slotReturnPressed ( const QString& cmd )
 
 void KateCmdLine::hideMe ()
 {
-  m_view->showCmdLine (false);
+  if (isVisibleTo(parentWidget())) {
+     m_view->toggleCmdLine ();
+  }
+  //m_view->/*show*/setCmdLine (false);
 }
 
 void KateCmdLine::focusInEvent ( QFocusEvent *ev )
@@ -125,7 +126,8 @@ void KateCmdLine::keyPressEvent( QKeyEvent *ev )
   if (ev->key() == Key_Escape)
   {
     m_view->setFocus ();
-    m_view->showCmdLine (false);
+    hideMe();
+    //m_view->showCmdLine (false);
   }
 
   return KLineEdit::keyPressEvent (ev);
@@ -306,16 +308,16 @@ int KateIconBorder::lineNumberWidth() const
   if (m_view->dynWordWrap() && m_dynWrapIndicatorsOn) {
     width = QMAX(style().scrollBarExtent().width() + 4, width);
 
-    if (m_cachedLNWidth != width || m_oldBackgroundColor != *m_view->renderer()->config()->iconBarColor()) {
+    if (m_cachedLNWidth != width || m_oldBackgroundColor != m_view->renderer()->config()->iconBarColor()) {
       int w = style().scrollBarExtent().width();
       int h = m_view->renderer()->config()->fontMetrics()->height();
 
       QSize newSize(w, h);
-      if ((m_arrow.size() != newSize || m_oldBackgroundColor != *m_view->renderer()->config()->iconBarColor()) && !newSize.isEmpty()) {
+      if ((m_arrow.size() != newSize || m_oldBackgroundColor != m_view->renderer()->config()->iconBarColor()) && !newSize.isEmpty()) {
         m_arrow.resize(newSize);
 
         QPainter p(&m_arrow);
-        p.fillRect( 0, 0, w, h, *m_view->renderer()->config()->iconBarColor() );
+        p.fillRect( 0, 0, w, h, m_view->renderer()->config()->iconBarColor() );
 
         h = m_view->renderer()->config()->fontMetrics()->ascent();
 
@@ -368,14 +370,14 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
   if ( m_lineNumbersOn || (m_view->dynWordWrap() && m_dynWrapIndicatorsOn) ) // avoid calculating unless needed ;-)
   {
     lnWidth = lineNumberWidth();
-    if ( lnWidth != m_cachedLNWidth || m_oldBackgroundColor != *m_view->renderer()->config()->iconBarColor() )
+    if ( lnWidth != m_cachedLNWidth || m_oldBackgroundColor != m_view->renderer()->config()->iconBarColor() )
     {
       // we went from n0 ->n9 lines or vice verca
       // this causes an extra updateGeometry() first time the line numbers
       // are displayed, but sizeHint() is supposed to be const so we can't set
       // the cached value there.
       m_cachedLNWidth = lnWidth;
-      m_oldBackgroundColor = *m_view->renderer()->config()->iconBarColor();
+      m_oldBackgroundColor = m_view->renderer()->config()->iconBarColor();
       updateGeometry();
       update ();
       return;
@@ -386,7 +388,9 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
 
   QPainter p ( this );
   p.setFont ( *m_view->renderer()->config()->font() ); // for line numbers
-  p.setPen ( m_view->renderer()->attribute(0)->textColor() );
+  // the line number color is for the line numbers, vertical separator lines
+  // and for for the code folding lines.
+  p.setPen ( m_view->renderer()->config()->lineNumberColor() );
 
   KateLineInfo oldInfo;
   if (startz < lineRangesSize)
@@ -407,8 +411,8 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
 
     int lnX ( 0 );
 
-    p.fillRect( 0, y, w-4, h, *m_view->renderer()->config()->iconBarColor() );
-    p.fillRect( w-4, y, 4, h, *m_view->renderer()->config()->backgroundColor() );
+    p.fillRect( 0, y, w-4, h, m_view->renderer()->config()->iconBarColor() );
+    p.fillRect( w-4, y, 4, h, m_view->renderer()->config()->backgroundColor() );
 
     // icon pane
     if( m_iconBorderOn )
@@ -523,7 +527,6 @@ void KateIconBorder::paintBorder (int /*x*/, int y, int /*width*/, int height)
 KateIconBorder::BorderArea KateIconBorder::positionToArea( const QPoint& p ) const
 {
   int x = 0;
-
   if( m_iconBorderOn ) {
     x += iconPaneWidth;
     if( p.x() <= x )
@@ -544,7 +547,7 @@ KateIconBorder::BorderArea KateIconBorder::positionToArea( const QPoint& p ) con
 
 void KateIconBorder::mousePressEvent( QMouseEvent* e )
 {
-  m_lastClickedLine = m_viewInternal->yToLineRange(e->y()).line;
+  m_lastClickedLine = m_viewInternal->yToKateLineRange(e->y()).line;
 
   if ( positionToArea( e->pos() ) != IconBorder )
   {
@@ -557,14 +560,17 @@ void KateIconBorder::mousePressEvent( QMouseEvent* e )
 
 void KateIconBorder::mouseMoveEvent( QMouseEvent* e )
 {
-  QMouseEvent forward( QEvent::MouseMove,
-    QPoint( 0, e->y() ), e->button(), e->state() );
-  m_viewInternal->mouseMoveEvent( &forward );
+  if ( positionToArea( e->pos() ) != IconBorder )
+  {
+    QMouseEvent forward( QEvent::MouseMove,
+      QPoint( 0, e->y() ), e->button(), e->state() );
+    m_viewInternal->mouseMoveEvent( &forward );
+  }
 }
 
 void KateIconBorder::mouseReleaseEvent( QMouseEvent* e )
 {
-  uint cursorOnLine = m_viewInternal->yToLineRange(e->y()).line;
+  uint cursorOnLine = m_viewInternal->yToKateLineRange(e->y()).line;
 
   if (cursorOnLine == m_lastClickedLine &&
       cursorOnLine <= m_doc->lastLine() )
