@@ -50,6 +50,7 @@
 #include <qlayout.h>
 #include <qclipboard.h>
 #include <qpixmap.h>
+#include <qvbox.h>
 
 KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   : QWidget (view, "", Qt::WStaticContents | Qt::WRepaintNoErase | Qt::WResizeNoErase )
@@ -84,16 +85,19 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   , m_imPreeditStartLine(0)
   , m_imPreeditStart(0)
   , m_imPreeditLength(0)
+  , m_imPreeditSelStart(0)
 {
   setMinimumSize (0,0);
 
   // cursor
   cursor.setMoveOnInsert (true);
 
+  // invalidate selStartCached, or keyb selection is screwed initially
+  selStartCached.setLine( -1 );
   //
   // scrollbar for lines
   //
-  m_lineScroll = new KateScrollBar(QScrollBar::Vertical, m_view);
+  m_lineScroll = new KateScrollBar(QScrollBar::Vertical, this);
   m_lineScroll->show();
   m_lineScroll->setTracking (true);
 
@@ -161,6 +165,9 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   // event filter
   installEventFilter(this);
 
+  // im
+  setInputMethodEnabled(true);
+
   // set cursor
   setCursor( KCursor::ibeamCursor() );
 
@@ -276,7 +283,7 @@ KateTextCursor KateViewInternal::endPos() const
   }
 
   for (int i = viewLines; i >= 0; i--) {
-    LineRange& thisRange = lineRanges[i];
+    KateLineRange& thisRange = lineRanges[i];
 
     if (thisRange.line == -1) continue;
 
@@ -298,7 +305,7 @@ uint KateViewInternal::endLine() const
   return endPos().line();
 }
 
-LineRange KateViewInternal::yToLineRange(uint y) const
+KateLineRange KateViewInternal::yToKateLineRange(uint y) const
 {
   return lineRanges[y / m_view->renderer()->fontHeight()];
 }
@@ -498,7 +505,7 @@ void KateViewInternal::updateView(bool changed, int viewLinesScrolled)
   if (oldSize != newSize) {
     lineRanges.resize((height() / m_view->renderer()->fontHeight()) + 1);
     if (newSize > oldSize) {
-      static LineRange blank;
+      static KateLineRange blank;
       for (uint i = oldSize; i < newSize; i++) {
         lineRanges[i] = blank;
       }
@@ -530,7 +537,7 @@ void KateViewInternal::updateView(bool changed, int viewLinesScrolled)
     KateTextCursor realStart = startPos();
     realStart.setLine(m_doc->getRealLine(realStart.line()));
 
-    LineRange startRange = range(realStart);
+    KateLineRange startRange = range(realStart);
     uint line = startRange.virtualLine;
     int realLine = startRange.line;
     uint oldLine = line;
@@ -541,7 +548,7 @@ void KateViewInternal::updateView(bool changed, int viewLinesScrolled)
     bool wrap = false;
     int newViewLine = startRange.viewLine;
     // z is the current display view line
-    TextLine::Ptr text = textLine(realLine);
+    KateTextLine::Ptr text = textLine(realLine);
 
     bool alreadyDirty = false;
 
@@ -757,7 +764,7 @@ void KateViewInternal::paintText (int x, int y, int width, int height, bool pain
       if (!(z >= lineRangesSize))
         lineRanges[z].dirty = false;
 
-      paint.fillRect( x, z * h, width, h, *m_view->renderer()->config()->backgroundColor() );
+      paint.fillRect( x, z * h, width, h, m_view->renderer()->config()->backgroundColor() );
     }
     else if (!paintOnlyDirty || lineRanges[z].dirty)
     {
@@ -885,6 +892,26 @@ QPoint KateViewInternal::cursorCoordinates()
   return QPoint(x, y);
 }
 
+
+void KateViewInternal::updateMicroFocusHint()
+{
+  int line = displayViewLine(displayCursor, true);
+  if (line == -1)
+      return;
+
+// Cursor placement code is changed for Asian input method that
+  // shows candidate window. This behavior is same as Qt/E 2.3.7
+  // which supports Asian input methods. Asian input methods need
+  // start point of IM selection text to place candidate window as
+  // adjacent to the selection text.
+  uint preeditStrLen = m_view->renderer()->textWidth(textLine(m_imPreeditStartLine), cursor.col()) - m_view->renderer()->textWidth(textLine(m_imPreeditStartLine), m_imPreeditSelStart);
+  uint x = cXPos - m_startX - lineRanges[line].startX + lineRanges[line].xOffset() - preeditStrLen;
+  uint y = line * m_view->renderer()->fontHeight();
+
+  setMicroFocusHint( x, y, 0, m_view->renderer()->fontHeight() );
+}
+
+
 void KateViewInternal::doReturn()
 {
   KateTextCursor c = cursor;
@@ -1009,7 +1036,7 @@ public:
     if (n > 0 && m_vi->m_view->dynWordWrap()) {
       // Need to constrain to current visible text line for dynamic wrapping mode
       if (m_col > m_vi->m_doc->lineLength(m_line)) {
-        LineRange currentRange = m_vi->range(*this);
+        KateLineRange currentRange = m_vi->range(*this);
 
         int endX;
         bool crap;
@@ -1104,7 +1131,7 @@ void KateViewInternal::moveWord( Bias bias, bool sel )
 
   WrappingCursor c( this, cursor );
   if( !c.atEdge( bias ) ) {
-    Highlight* h = m_doc->highlight();
+    KateHighlighting* h = m_doc->highlight();
 
     bool moved = false;
     while( !c.atEdge( bias ) && !h->isInWord( m_doc->textLine( c.line() )[ c.col() - (bias == left ? 1 : 0) ] ) )
@@ -1187,7 +1214,7 @@ void KateViewInternal::end( bool sel )
   moveEdge( right, sel );
 }
 
-LineRange KateViewInternal::range(int realLine, const LineRange* previous)
+KateLineRange KateViewInternal::range(int realLine, const KateLineRange* previous)
 {
   // look at the cache first
   if (!m_updatingView && realLine >= lineRanges[0].line && realLine <= lineRanges[lineRanges.count() - 1].line)
@@ -1197,11 +1224,11 @@ LineRange KateViewInternal::range(int realLine, const LineRange* previous)
           return lineRanges[i];
 
   // Not in the cache, we have to create it
-  LineRange ret;
+  KateLineRange ret;
 
-  TextLine::Ptr text = textLine(realLine);
+  KateTextLine::Ptr text = textLine(realLine);
   if (!text) {
-    return LineRange();
+    return KateLineRange();
   }
 
   if (!m_view->dynWordWrap()) {
@@ -1252,14 +1279,14 @@ LineRange KateViewInternal::range(int realLine, const LineRange* previous)
   return ret;
 }
 
-LineRange KateViewInternal::currentRange()
+KateLineRange KateViewInternal::currentRange()
 {
-//   Q_ASSERT(m_view->dynWordWrap());
+//  Q_ASSERT(m_view->dynWordWrap());
 
   return range(cursor);
 }
 
-LineRange KateViewInternal::previousRange()
+KateLineRange KateViewInternal::previousRange()
 {
   uint currentViewLine = viewLine(cursor);
 
@@ -1269,7 +1296,7 @@ LineRange KateViewInternal::previousRange()
     return range(m_doc->getRealLine(displayCursor.line() - 1), -1);
 }
 
-LineRange KateViewInternal::nextRange()
+KateLineRange KateViewInternal::nextRange()
 {
   uint currentViewLine = viewLine(cursor) + 1;
 
@@ -1281,11 +1308,11 @@ LineRange KateViewInternal::nextRange()
   }
 }
 
-LineRange KateViewInternal::range(const KateTextCursor& realCursor)
+KateLineRange KateViewInternal::range(const KateTextCursor& realCursor)
 {
-//   Q_ASSERT(m_view->dynWordWrap());
+//  Q_ASSERT(m_view->dynWordWrap());
 
-  LineRange thisRange;
+  KateLineRange thisRange;
   bool first = true;
 
   do {
@@ -1296,11 +1323,11 @@ LineRange KateViewInternal::range(const KateTextCursor& realCursor)
   return thisRange;
 }
 
-LineRange KateViewInternal::range(uint realLine, int viewLine)
+KateLineRange KateViewInternal::range(uint realLine, int viewLine)
 {
-//   Q_ASSERT(m_view->dynWordWrap());
+//  Q_ASSERT(m_view->dynWordWrap());
 
-  LineRange thisRange;
+  KateLineRange thisRange;
   bool first = true;
 
   do {
@@ -1325,7 +1352,7 @@ uint KateViewInternal::viewLine(const KateTextCursor& realCursor)
 
   if (realCursor.col() == 0) return 0;
 
-  LineRange thisRange;
+  KateLineRange thisRange;
   bool first = true;
 
   do {
@@ -1391,7 +1418,7 @@ uint KateViewInternal::lastViewLine(uint realLine)
 {
   if (!m_view->dynWordWrap()) return 0;
 
-  LineRange thisRange;
+  KateLineRange thisRange;
   bool first = true;
 
   do {
@@ -1452,7 +1479,7 @@ KateTextCursor KateViewInternal::viewLineOffset(const KateTextCursor& virtualCur
     currentOffset = lastViewLine(realCursor.line()) - cursorViewLine;
     if (offset <= currentOffset) {
       // the answer is on the same line
-      LineRange thisRange = range(realCursor.line(), cursorViewLine + offset);
+      KateLineRange thisRange = range(realCursor.line(), cursorViewLine + offset);
       Q_ASSERT(thisRange.virtualLine == virtualCursor.line());
       return KateTextCursor(virtualCursor.line(), thisRange.startCol);
     }
@@ -1464,7 +1491,7 @@ KateTextCursor KateViewInternal::viewLineOffset(const KateTextCursor& virtualCur
     currentOffset = cursorViewLine;
     if (offset <= currentOffset) {
       // the answer is on the same line
-      LineRange thisRange = range(realCursor.line(), cursorViewLine - offset);
+      KateLineRange thisRange = range(realCursor.line(), cursorViewLine - offset);
       Q_ASSERT(thisRange.virtualLine == virtualCursor.line());
       return KateTextCursor(virtualCursor.line(), thisRange.startCol);
     }
@@ -1476,7 +1503,7 @@ KateTextCursor KateViewInternal::viewLineOffset(const KateTextCursor& virtualCur
 
   while (virtualLine >= 0 && virtualLine < (int)m_doc->visibleLines())
   {
-    LineRange thisRange;
+    KateLineRange thisRange;
     bool first = true;
     int realLine = m_doc->getRealLine(virtualLine);
 
@@ -1533,7 +1560,7 @@ KateTextCursor KateViewInternal::viewLineOffset(const KateTextCursor& virtualCur
     return KateTextCursor(0, 0);
 }
 
-int KateViewInternal::lineMaxCursorX(const LineRange& range)
+int KateViewInternal::lineMaxCursorX(const KateLineRange& range)
 {
   if (!m_doc->wrapCursor() && !range.wrap)
     return INT_MAX;
@@ -1548,7 +1575,7 @@ int KateViewInternal::lineMaxCursorX(const LineRange& range)
   return maxX;
 }
 
-int KateViewInternal::lineMaxCol(const LineRange& range)
+int KateViewInternal::lineMaxCol(const KateLineRange& range)
 {
   int maxCol = range.endCol;
 
@@ -1568,9 +1595,9 @@ void KateViewInternal::cursorUp(bool sel)
 
   if (m_view->dynWordWrap()) {
     // Dynamic word wrapping - navigate on visual lines rather than real lines
-    LineRange thisRange = currentRange();
+    KateLineRange thisRange = currentRange();
     // This is not the first line because that is already simplified out above
-    LineRange pRange = previousRange();
+    KateLineRange pRange = previousRange();
 
     // Ensure we're in the right spot
     Q_ASSERT((cursor.line() == thisRange.line) &&
@@ -1629,9 +1656,9 @@ void KateViewInternal::cursorDown(bool sel)
 
   if (m_view->dynWordWrap()) {
     // Dynamic word wrapping - navigate on visual lines rather than real lines
-    LineRange thisRange = currentRange();
+    KateLineRange thisRange = currentRange();
     // This is not the last line because that is already simplified out above
-    LineRange nRange = nextRange();
+    KateLineRange nRange = nextRange();
 
     // Ensure we're in the right spot
     Q_ASSERT((cursor.line() == thisRange.line) &&
@@ -1786,7 +1813,7 @@ void KateViewInternal::pageUp( bool sel )
     KateTextCursor newPos = viewLineOffset(newStartPos, viewLine, true);
     newPos.setLine(m_doc->getRealLine(newPos.line()));
 
-    LineRange newLine = range(newPos);
+    KateLineRange newLine = range(newPos);
 
     if (m_currentMaxX - newLine.xOffset() > xPos)
       xPos = m_currentMaxX - newLine.xOffset();
@@ -1842,7 +1869,7 @@ void KateViewInternal::pageDown( bool sel )
     KateTextCursor newPos = viewLineOffset(newStartPos, viewLine, true);
     newPos.setLine(m_doc->getRealLine(newPos.line()));
 
-    LineRange newLine = range(newPos);
+    KateLineRange newLine = range(newPos);
 
     if (m_currentMaxX - newLine.xOffset() > xPos)
       xPos = m_currentMaxX - newLine.xOffset();
@@ -1867,7 +1894,7 @@ bool KateViewInternal::scrollbarVisible(uint startLine)
 
 int KateViewInternal::maxLen(uint startLine)
 {
-  Q_ASSERT(!m_view->dynWordWrap());
+//  Q_ASSERT(!m_view->dynWordWrap());
 
   int displayLines = (m_view->height() / m_view->renderer()->fontHeight()) + 1;
 
@@ -1879,7 +1906,7 @@ int KateViewInternal::maxLen(uint startLine)
     if (virtualLine < 0 || virtualLine >= (int)m_doc->visibleLines())
       break;
 
-    LineRange thisRange = range((int)m_doc->getRealLine(virtualLine));
+    KateLineRange thisRange = range((int)m_doc->getRealLine(virtualLine));
 
     maxLen = QMAX(maxLen, thisRange.endX);
   }
@@ -1917,8 +1944,9 @@ void KateViewInternal::bottom_end( bool sel )
   updateCursor( c );
 }
 
-void KateViewInternal::updateSelection( const KateTextCursor& newCursor, bool keepSel )
+void KateViewInternal::updateSelection( const KateTextCursor& _newCursor, bool keepSel )
 {
+  KateTextCursor newCursor = _newCursor;
   if( keepSel )
   {
     if ( !m_doc->hasSelection() || (selectAnchor.line() == -1)
@@ -1929,7 +1957,85 @@ void KateViewInternal::updateSelection( const KateTextCursor& newCursor, bool ke
       m_doc->setSelection( cursor, newCursor );
     }
     else
-      m_doc->setSelection( selectAnchor, newCursor);
+    {
+      bool doSelect = true;
+      switch (m_selectionMode)
+      {
+        case Word:
+        {
+          bool same = ( newCursor.line() == selStartCached.line() );
+          uint c;
+          if ( newCursor.line() > selStartCached.line() ||
+               ( same && newCursor.col() > selEndCached.col() ) )
+          {
+            selectAnchor = selStartCached;
+
+            KateTextLine::Ptr l = m_doc->kateTextLine( newCursor.line() );
+
+            for ( c = newCursor.col(); c < l->length(); c++ )
+              if ( !m_doc->m_highlight->isInWord( l->getChar( c ) ) )
+                break;
+
+            newCursor.setCol( c );
+          }
+          else if ( newCursor.line() < selStartCached.line() ||
+               ( same && newCursor.col() < selStartCached.col() ) )
+          {
+            selectAnchor = selEndCached;
+
+            KateTextLine::Ptr l = m_doc->kateTextLine( newCursor.line() );
+
+            for ( c = newCursor.col(); c > 0; c-- )
+              if ( !m_doc->m_highlight->isInWord( l->getChar( c ) ) )
+                break;
+
+            newCursor.setCol( c+1 );
+          }
+          else
+            doSelect = false;
+
+        }
+        break;
+        case Line:
+          if ( newCursor.line() > selStartCached.line() )
+          {
+            selectAnchor = selStartCached;
+            newCursor.setCol( m_doc->textLine( newCursor.line() ).length() );
+          }
+          else if ( newCursor.line() < selStartCached.line() )
+          {
+            selectAnchor = selEndCached;
+            newCursor.setCol( 0 );
+          }
+          else // same line, ignore
+            doSelect = false;
+        break;
+        default: // *allways* keep original selection for mouse
+        {
+          if ( selStartCached.line() < 0 ) // invalid
+            break;
+
+          if ( newCursor.line() > selEndCached.line() ||
+               ( newCursor.line() == selEndCached.line() &&
+                 newCursor.col() > selEndCached.col() ) )
+            selectAnchor = selStartCached;
+
+          else if ( newCursor.line() < selStartCached.line() ||
+               ( newCursor.line() == selStartCached.line() &&
+                 newCursor.col() < selStartCached.col() ) )
+            selectAnchor = selEndCached;
+
+          else
+            doSelect = false;
+        }
+//         break;
+      }
+
+      if ( doSelect )
+        m_doc->setSelection( selectAnchor, newCursor);
+      else if ( selStartCached.line() > 0 ) // we have a cached selectino, so we restore that
+        m_doc->setSelection( selStartCached, selEndCached );
+    }
 
     m_selChangedByUser = true;
   }
@@ -1939,7 +2045,7 @@ void KateViewInternal::updateSelection( const KateTextCursor& newCursor, bool ke
 
 void KateViewInternal::updateCursor( const KateTextCursor& newCursor, bool force, bool center, bool calledExternally )
 {
-  TextLine::Ptr l = textLine( newCursor.line() );
+  KateTextLine::Ptr l = textLine( newCursor.line() );
 
   if ( !force && (cursor == newCursor) )
   {
@@ -1955,6 +2061,10 @@ void KateViewInternal::updateCursor( const KateTextCursor& newCursor, bool force
     return;
   }
 
+  // remove trailing spaces ### really not nice here, unless it is *really* nessecary
+//   if ( m_doc->isReadWrite() && cursor.line() != newCursor.line() )
+//     m_doc->removeTrailingSpace( cursor.line() );
+
   // unfold if required
   if ( l && ! l->isVisible() )
     m_doc->foldingTree()->ensureVisible( newCursor.line() );
@@ -1973,12 +2083,12 @@ void KateViewInternal::updateCursor( const KateTextCursor& newCursor, bool force
   tagLine(oldDisplayCursor);
   tagLine(displayCursor);
 
-  QPoint cursorP = cursorCoordinates();
-  setMicroFocusHint( cursorP.x(), cursorP.y(), 0, m_view->renderer()->fontHeight() );
+  updateMicroFocusHint();
 
   if (m_cursorTimer.isActive ())
   {
-    m_cursorTimer.start( KApplication::cursorFlashTime() / 2 );
+    if ( KApplication::cursorFlashTime() > 0 )
+      m_cursorTimer.start( KApplication::cursorFlashTime() / 2 );
     m_view->renderer()->setDrawCaret(true);
   }
 
@@ -2121,7 +2231,7 @@ void KateViewInternal::paintCursor()
 // Point in content coordinates
 void KateViewInternal::placeCursor( const QPoint& p, bool keepSelection, bool updateSelection )
 {
-  LineRange thisRange = yToLineRange(p.y());
+  KateLineRange thisRange = yToKateLineRange(p.y());
 
   if (thisRange.line == -1) {
     for (int i = (p.y() / m_view->renderer()->fontHeight()); i >= 0; i--) {
@@ -2152,19 +2262,19 @@ void KateViewInternal::placeCursor( const QPoint& p, bool keepSelection, bool up
 // Point in content coordinates
 bool KateViewInternal::isTargetSelected( const QPoint& p )
 {
-  LineRange thisRange = yToLineRange(p.y());
+  KateLineRange thisRange = yToKateLineRange(p.y());
 
-  TextLine::Ptr l = textLine( thisRange.line );
+  KateTextLine::Ptr l = textLine( thisRange.line );
   if( !l )
     return false;
 
-  int col = m_view->renderer()->textPos( l, p.x() - thisRange.xOffset(), thisRange.startCol );
+  int col = m_view->renderer()->textPos( l, p.x() - thisRange.xOffset(), thisRange.startCol, false );
 
   return m_doc->lineColSelected( thisRange.line, col );
 }
 
 //
-// START EVENT HANDLING STUFF !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+// BEGIN EVENT HANDLING STUFF !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 //
 
 bool KateViewInternal::eventFilter( QObject *obj, QEvent *e )
@@ -2188,6 +2298,14 @@ bool KateViewInternal::eventFilter( QObject *obj, QEvent *e )
     {
       QKeyEvent *k = (QKeyEvent *)e;
 
+      if (m_view->m_codeCompletion->codeCompletionVisible ())
+      {
+        kdDebug (13030) << "hint around" << endl;
+
+        if( k->key() == Key_Escape )
+          m_view->m_codeCompletion->abortCompletion();
+      }
+
       if ((k->key() == Qt::Key_Escape) && !(m_doc->configFlags() & KateDocument::cfPersistent) )
       {
         m_doc->clearSelection();
@@ -2220,6 +2338,7 @@ bool KateViewInternal::eventFilter( QObject *obj, QEvent *e )
     } break;
 
     case QEvent::DragLeave:
+      // happens only when pressing ESC while dragging
       stopDragScroll();
       break;
 
@@ -2234,10 +2353,36 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
 {
   KKey key(e);
 
-   if (key == Qt::Key_Left)
+  bool codeComp = m_view->m_codeCompletion->codeCompletionVisible ();
+
+  if (codeComp)
+  {
+    kdDebug (13030) << "hint around" << endl;
+
+    if( e->key() == Key_Enter || e->key() == Key_Return  ||
+    (key == SHIFT + Qt::Key_Return) || (key == SHIFT + Qt::Key_Enter)) {
+      m_view->m_codeCompletion->doComplete();
+      e->accept();
+      return;
+    }
+
+    if( (e->key() == Key_Up)    || (e->key() == Key_Down ) ||
+        (e->key() == Key_Home ) || (e->key() == Key_End)   ||
+        (e->key() == Key_Prior) || (e->key() == Key_Next )) {
+       m_view->m_codeCompletion->handleKey (e);
+       e->accept();
+       return;
+    }
+  }
+
+  if (key == Qt::Key_Left)
   {
     m_view->cursorLeft();
     e->accept();
+
+    if (codeComp)
+      m_view->m_codeCompletion->updateBox ();
+
     return;
   }
 
@@ -2245,6 +2390,10 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
   {
     m_view->cursorRight();
     e->accept();
+
+    if (codeComp)
+      m_view->m_codeCompletion->updateBox ();
+
     return;
   }
 
@@ -2268,18 +2417,52 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
     return;
   }
 
-  if ((key == Qt::Key_Return) || (key == Qt::Key_Enter) ||
-      (key == SHIFT + Qt::Key_Return) || (key == SHIFT + Qt::Key_Enter))
+  if ((key == Qt::Key_Return) || (key == Qt::Key_Enter))
   {
     m_view->keyReturn();
     e->accept();
     return;
   }
 
+  if ((key == SHIFT + Qt::Key_Return) || (key == SHIFT + Qt::Key_Enter))
+  {
+    uint ln = cursor.line();
+    int col = cursor.col();
+    KateTextLine::Ptr line = m_doc->kateTextLine( ln );
+    int pos = line->firstChar();
+    if (pos > cursor.col()) pos = cursor.col();
+    if (pos != -1) {
+      while ((int)line->length() > pos &&
+             !line->getChar(pos).isLetterOrNumber() &&
+             pos < cursor.col()) ++pos;
+    } else {
+      pos = line->length(); // stay indented
+    }
+    m_doc->editStart();
+    m_doc->insertText( cursor.line(), line->length(), "\n" +  line->string(0, pos)
+      + line->string().right( line->length() - cursor.col() ) );
+    cursor.setPos(ln + 1, pos);
+    if (col < line->length())
+      m_doc->editRemoveText(ln, col, line->length() - col);
+    m_doc->editEnd();
+    updateCursor(cursor, true);
+    updateView();
+    e->accept();
+
+    if (codeComp)
+      m_view->m_codeCompletion->updateBox ();
+
+    return;
+  }
+
   if (key == Qt::Key_Backspace || key == SHIFT + Qt::Key_Backspace)
   {
     m_view->backspace();
     e->accept();
+
+    if (codeComp)
+      m_view->m_codeCompletion->updateBox ();
+
     return;
   }
 
@@ -2287,6 +2470,10 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
   {
     m_view->keyDelete();
     e->accept();
+
+    if (codeComp)
+      m_view->m_codeCompletion->updateBox ();
+
     return;
   }
 
@@ -2303,6 +2490,10 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
         m_doc->insertIndentChars ( m_view );
 
       e->accept();
+
+      if (codeComp)
+        m_view->m_codeCompletion->updateBox ();
+
       return;
     }
 
@@ -2310,6 +2501,10 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
     {
       m_doc->indent( m_view, cursor.line(), -1 );
       e->accept();
+
+      if (codeComp)
+        m_view->m_codeCompletion->updateBox ();
+
       return;
     }
   }
@@ -2318,6 +2513,10 @@ void KateViewInternal::keyPressEvent( QKeyEvent* e )
        && m_doc->typeChars ( m_view, e->text() ) )
   {
     e->accept();
+
+    if (codeComp)
+      m_view->m_codeCompletion->updateBox ();
+
     return;
   }
 
@@ -2362,16 +2561,37 @@ void KateViewInternal::mousePressEvent( QMouseEvent* e )
         {
           possibleTripleClick = false;
 
-          m_doc->selectLine( cursor );
+          m_selectionMode = Line;
+
+          if ( e->state() & Qt::ShiftButton )
+          {
+            updateSelection( cursor, true );
+          }
+          else
+          {
+            m_doc->selectLine( cursor );
+          }
+
           QApplication::clipboard()->setSelectionMode( true );
           m_doc->copy();
           QApplication::clipboard()->setSelectionMode( false );
 
+          selStartCached = m_doc->selectStart;
+          selEndCached = m_doc->selectEnd;
+
           cursor.setCol(0);
           updateCursor( cursor );
           return;
         }
 
+        if ( e->state() & Qt::ShiftButton )
+        {
+          selStartCached = m_doc->selectStart;
+          selEndCached = m_doc->selectEnd;
+        }
+        else
+          selStartCached.setLine( -1 ); // invalidate
+
         if( isTargetSelected( e->pos() ) )
         {
           dragInfo.state = diPending;
@@ -2382,6 +2602,7 @@ void KateViewInternal::mousePressEvent( QMouseEvent* e )
           dragInfo.state = diNone;
 
           placeCursor( e->pos(), e->state() & ShiftButton );
+
           scrollX = 0;
           scrollY = 0;
 
@@ -2391,8 +2612,9 @@ void KateViewInternal::mousePressEvent( QMouseEvent* e )
         e->accept ();
         break;
 
+    // try to show popup menu
     case RightButton:
-      if ( !isTargetSelected( e->pos() ) )
+      if ( ! isTargetSelected( e->pos() ) )
         placeCursor( e->pos() );
 
       // popup is a qguardedptr now
@@ -2413,7 +2635,18 @@ void KateViewInternal::mouseDoubleClickEvent(QMouseEvent *e)
   switch (e->button())
   {
     case LeftButton:
-      m_doc->selectWord( cursor );
+      m_selectionMode = Word;
+
+      if ( e->state() & Qt::ShiftButton )
+      {
+        selStartCached = m_doc->selectStart;
+        selEndCached = m_doc->selectEnd;
+        updateSelection( cursor, true );
+      }
+      else
+      {
+        m_doc->selectWord( cursor );
+      }
 
       // Move cursor to end of selected word
       if (m_doc->hasSelection())
@@ -2424,6 +2657,9 @@ void KateViewInternal::mouseDoubleClickEvent(QMouseEvent *e)
 
         cursor.setPos(m_doc->selectEnd);
         updateCursor( cursor );
+
+        selStartCached = m_doc->selectStart;
+        selEndCached = m_doc->selectEnd;
       }
 
       possibleTripleClick = true;
@@ -2448,6 +2684,9 @@ void KateViewInternal::mouseReleaseEvent( QMouseEvent* e )
   switch (e->button())
   {
     case LeftButton:
+      m_selectionMode = Default;
+      selStartCached.setLine( -1 );
+
       if (m_selChangedByUser)
       {
         QApplication::clipboard()->setSelectionMode( true );
@@ -2458,7 +2697,7 @@ void KateViewInternal::mouseReleaseEvent( QMouseEvent* e )
       }
 
       if (dragInfo.state == diPending)
-        placeCursor( e->pos() );
+        placeCursor( e->pos(), e->state() & ShiftButton );
       else if (dragInfo.state == diNone)
         m_scrollTimer.stop ();
 
@@ -2529,6 +2768,7 @@ void KateViewInternal::mouseMoveEvent( QMouseEvent* e )
     }
 
     placeCursor( QPoint( mouseX, mouseY ), true );
+
   }
   else
   {
@@ -2581,7 +2821,7 @@ void KateViewInternal::resizeEvent(QResizeEvent* e)
       if (!m_doc->wrapCursor()) {
         // May have to restrain cursor to new smaller width...
         if (cursor.col() > m_doc->lineLength(cursor.line())) {
-          LineRange thisRange = currentRange();
+          KateLineRange thisRange = currentRange();
 
           KateTextCursor newCursor(cursor.line(), thisRange.endCol + ((width() - thisRange.xOffset() - (thisRange.endX - thisRange.startX)) / m_view->renderer()->spaceWidth()) - 1);
           updateCursor(newCursor);
@@ -2622,7 +2862,7 @@ void KateViewInternal::textHintTimeout ()
 {
   m_textHintTimer.stop ();
 
-  LineRange thisRange = yToLineRange(m_textHintMouseY);
+  KateLineRange thisRange = yToKateLineRange(m_textHintMouseY);
 
   if (thisRange.line == -1) return;
 
@@ -2643,7 +2883,8 @@ void KateViewInternal::textHintTimeout ()
 
 void KateViewInternal::focusInEvent (QFocusEvent *)
 {
-  m_cursorTimer.start ( KApplication::cursorFlashTime() / 2 );
+  if (KApplication::cursorFlashTime() > 0)
+    m_cursorTimer.start ( KApplication::cursorFlashTime() / 2 );
 
   if (m_textHintEnabled)
     m_textHintTimer.start( m_textHintTimeout );
@@ -2673,7 +2914,7 @@ void KateViewInternal::doDrag()
 {
   dragInfo.state = diDragging;
   dragInfo.dragObject = new QTextDrag(m_doc->selection(), this);
-  dragInfo.dragObject->dragCopy();
+  dragInfo.dragObject->drag();
 }
 
 void KateViewInternal::dragEnterEvent( QDragEnterEvent* event )
@@ -2686,6 +2927,10 @@ void KateViewInternal::dragMoveEvent( QDragMoveEvent* event )
 {
   // track the cursor to the current drop location
   placeCursor( event->pos(), true, false );
+
+  // important: accept action to switch between copy and move mode
+  // without this, the text will always be copied.
+  event->acceptAction();
 }
 
 void KateViewInternal::dropEvent( QDropEvent* event )
@@ -2715,12 +2960,27 @@ void KateViewInternal::dropEvent( QDropEvent* event )
       return;
     }
 
-    // atm only copy the text, no move
+    // use one transaction
+    m_doc->editStart ();
+
+    // on move: remove selected text; on copy: duplicate text
+    if ( event->action() != QDropEvent::Copy )
+      m_doc->removeSelectedText();
+
     m_doc->insertText( cursor.line(), cursor.col(), text );
+
+    m_doc->editEnd ();
+
     placeCursor( event->pos() );
 
+    event->acceptAction();
     updateView();
   }
+
+  // finally finish drag and drop mode
+  dragInfo.state = diNone;
+  // important, because the eventFilter`s DragLeave does not occure
+  stopDragScroll();
 }
 
 void KateViewInternal::imStartEvent( QIMEvent *e )
@@ -2736,6 +2996,7 @@ void KateViewInternal::imStartEvent( QIMEvent *e )
   m_imPreeditStartLine = cursor.line();
   m_imPreeditStart = cursor.col();
   m_imPreeditLength = 0;
+  m_imPreeditSelStart = m_imPreeditStart;
 
   m_doc->setIMSelectionValue( m_imPreeditStartLine, m_imPreeditStart, 0, 0, 0, true );
 }
@@ -2760,7 +3021,9 @@ void KateViewInternal::imComposeEvent( QIMEvent *e )
 
   updateView( true );
   updateCursor( cursor, true );
+
   m_imPreeditLength = e->text().length();
+  m_imPreeditSelStart = m_imPreeditStart + e->cursorPos();
 }
 
 void KateViewInternal::imEndEvent( QIMEvent *e )
@@ -2780,7 +3043,7 @@ void KateViewInternal::imEndEvent( QIMEvent *e )
   if ( e->text().length() > 0 ) {
     m_doc->insertText( cursor.line(), cursor.col(), e->text() );
 
-    if ( !m_cursorTimer.isActive() )
+    if ( !m_cursorTimer.isActive() && KApplication::cursorFlashTime() > 0 )
       m_cursorTimer.start ( KApplication::cursorFlashTime() / 2 );
 
     updateView( true );
@@ -2790,10 +3053,11 @@ void KateViewInternal::imEndEvent( QIMEvent *e )
 
   m_imPreeditStart = 0;
   m_imPreeditLength = 0;
+  m_imPreeditSelStart = 0;
 }
 
 //
-// END EVENT HANDLING STUFF !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+// END EVENT HANDLING STUFF !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 //
 
 void KateViewInternal::clear()
@@ -2861,8 +3125,10 @@ void KateViewInternal::doDragScroll()
 
   if (dy)
     scrollLines(startPos().line() + dy);
-  if (dx)
-    scrollColumns(m_startX + dx);
+
+  if (!m_view->dynWordWrap() && m_columnScrollDisplayed && dx)
+    scrollColumns(kMin (m_startX + dx, m_columnScroll->maxValue()));
+
   if (!dy && !dx)
     stopDragScroll();
 }
@@ -2942,11 +3208,21 @@ void KateViewInternal::docSelectionChanged ()
 }
 
 // BEGIN KateScrollBar
-KateScrollBar::KateScrollBar (Orientation orientation, QWidget* parent, const char* name)
-  : QScrollBar (orientation, parent, name)
+KateScrollBar::KateScrollBar (Orientation orientation, KateViewInternal* parent, const char* name)
+  : QScrollBar (orientation, parent->m_view, name)
   , m_middleMouseDown (false)
+  , m_view(parent->m_view)
+  , m_doc(parent->m_doc)
+  , m_viewInternal(parent)
+  , m_topMargin(-1)
+  , m_bottomMargin(-1)
+  , m_savVisibleLines(0)
+  , m_showMarks(false)
 {
   connect(this, SIGNAL(valueChanged(int)), SLOT(sliderMaybeMoved(int)));
+  connect(m_doc, SIGNAL(marksChanged()), this, SLOT(marksChanged()));
+
+  m_lines.setAutoDelete(true);
 }
 
 void KateScrollBar::mousePressEvent(QMouseEvent* e)
@@ -2955,6 +3231,8 @@ void KateScrollBar::mousePressEvent(QMouseEvent* e)
     m_middleMouseDown = true;
 
   QScrollBar::mousePressEvent(e);
+
+  redrawMarks();
 }
 
 void KateScrollBar::mouseReleaseEvent(QMouseEvent* e)
@@ -2962,6 +3240,122 @@ void KateScrollBar::mouseReleaseEvent(QMouseEvent* e)
   QScrollBar::mouseReleaseEvent(e);
 
   m_middleMouseDown = false;
+
+  redrawMarks();
+}
+
+void KateScrollBar::mouseMoveEvent(QMouseEvent* e)
+{
+  QScrollBar::mouseMoveEvent(e);
+
+  if (e->state() | LeftButton)
+    redrawMarks();
+}
+
+void KateScrollBar::paintEvent(QPaintEvent *e)
+{
+  QScrollBar::paintEvent(e);
+  redrawMarks();
+}
+
+void KateScrollBar::resizeEvent(QResizeEvent *e)
+{
+  QScrollBar::resizeEvent(e);
+  recomputeMarksPositions();
+}
+
+void KateScrollBar::styleChange(QStyle &s)
+{
+  QScrollBar::styleChange(s);
+  m_topMargin = -1;
+  recomputeMarksPositions();
+}
+
+void KateScrollBar::valueChange()
+{
+  QScrollBar::valueChange();
+  redrawMarks();
+}
+
+void KateScrollBar::rangeChange()
+{
+  QScrollBar::rangeChange();
+  recomputeMarksPositions();
+}
+
+void KateScrollBar::marksChanged()
+{
+  recomputeMarksPositions(true);
+}
+
+void KateScrollBar::redrawMarks()
+{
+  if (!m_showMarks)
+    return;
+
+  QPainter painter(this);
+  QRect rect = sliderRect();
+  for (QIntDictIterator<QColor> it(m_lines); it.current(); ++it)
+  {
+    if (it.currentKey() < rect.top() || it.currentKey() > rect.bottom())
+    {
+      painter.setPen(*it.current());
+      painter.drawLine(0, it.currentKey(), width(), it.currentKey());
+    }
+  }
+}
+
+void KateScrollBar::recomputeMarksPositions(bool forceFullUpdate)
+{
+  if (m_topMargin == -1)
+    watchScrollBarSize();
+
+  m_lines.clear();
+  m_savVisibleLines = m_doc->visibleLines();
+
+  int realHeight = frameGeometry().height() - m_topMargin - m_bottomMargin;
+
+  QPtrList<KTextEditor::Mark> marks = m_doc->marks();
+  KateCodeFoldingTree *tree = m_doc->foldingTree();
+
+  for (KTextEditor::Mark *mark = marks.first(); mark; mark = marks.next())
+  {
+    uint line = mark->line;
+
+    if (tree)
+    {
+      KateCodeFoldingNode *node = tree->findNodeForLine(line);
+
+      while (node)
+      {
+        if (!node->visible)
+          line = tree->getStartLine(node);
+        node = node->parentNode;
+      }
+    }
+
+    line = m_doc->getVirtualLine(line);
+
+    double d = (double)line / (m_savVisibleLines - 1);
+    m_lines.insert(m_topMargin + (int)(d * realHeight),
+                   new QColor(KateRendererConfig::global()->lineMarkerColor((KTextEditor::MarkInterface::MarkTypes)mark->type)));
+  }
+
+  if (forceFullUpdate)
+    update();
+  else
+    redrawMarks();
+}
+
+void KateScrollBar::watchScrollBarSize()
+{
+  int savMax = maxValue();
+  setMaxValue(0);
+  QRect rect = sliderRect();
+  setMaxValue(savMax);
+
+  m_topMargin = rect.top();
+  m_bottomMargin = frameGeometry().height() - rect.bottom();
 }
 
 void KateScrollBar::sliderMaybeMoved(int value)
@@ -2970,7 +3364,7 @@ void KateScrollBar::sliderMaybeMoved(int value)
     emit sliderMMBMoved(value);
 }
 
-TextLine::Ptr KateViewInternal::textLine( int realLine )
+KateTextLine::Ptr KateViewInternal::textLine( int realLine )
 {
   if (m_usePlainLines)
     return m_doc->plainKateTextLine(realLine);
