@@ -32,6 +32,7 @@
 #include <qscrollbar.h>
 #include <qpoint.h>
 #include <qtimer.h>
+#include <qintdict.h>
 
 class KateView;
 class KateDocument;
@@ -51,13 +52,18 @@ enum Bias
  * This class is required because QScrollBar's sliderMoved() signal is
  * really supposed to be a sliderDragged() signal... so this way we can capture
  * MMB slider moves as well
+ *
+ * Also, it adds some usefull indicators on the scrollbar.
  */
 class KateScrollBar : public QScrollBar
 {
   Q_OBJECT
 
   public:
-    KateScrollBar(Orientation orientation, QWidget* parent, const char* name = 0L);
+    KateScrollBar(Orientation orientation, class KateViewInternal *parent, const char* name = 0L);
+
+    inline bool showMarks() { return m_showMarks; };
+    inline void setShowMarks(bool b) { m_showMarks = b; update(); };
 
   signals:
     void sliderMMBMoved(int value);
@@ -65,12 +71,35 @@ class KateScrollBar : public QScrollBar
   protected:
     virtual void mousePressEvent(QMouseEvent* e);
     virtual void mouseReleaseEvent(QMouseEvent* e);
+    virtual void mouseMoveEvent (QMouseEvent* e);
+    virtual void paintEvent(QPaintEvent *);
+    virtual void resizeEvent(QResizeEvent *);
+    virtual void styleChange(QStyle &oldStyle);
+    virtual void valueChange();
+    virtual void rangeChange();
 
   protected slots:
     void sliderMaybeMoved(int value);
+    void marksChanged();
 
   private:
+    void redrawMarks();
+    void recomputeMarksPositions(bool forceFullUpdate = false);
+    void watchScrollBarSize();
+
   bool m_middleMouseDown;
+
+    KateView *m_view;
+    KateDocument *m_doc;
+    class KateViewInternal *m_viewInternal;
+
+    int m_topMargin;
+    int m_bottomMargin;
+    uint m_savVisibleLines;
+
+    QIntDict<QColor> m_lines;
+
+    bool m_showMarks;
 };
 
 class KateViewInternal : public QWidget
@@ -79,6 +108,7 @@ class KateViewInternal : public QWidget
 
     friend class KateView;
     friend class KateIconBorder;
+    friend class KateScrollBar;
     friend class CalculatingCursor;
     friend class BoundedCursor;
     friend class WrappingCursor;
@@ -124,7 +154,7 @@ class KateViewInternal : public QWidget
     KateTextCursor endPos () const;
     uint endLine () const;
 
-    LineRange yToLineRange(uint y) const;
+    KateLineRange yToKateLineRange(uint y) const;
 
     void prepareForDynWrapChange();
     void dynWrapChanged();
@@ -230,6 +260,8 @@ class KateViewInternal : public QWidget
 
     void paintCursor();
 
+    void updateMicroFocusHint();
+
     void placeCursor( const QPoint& p, bool keepSelection = false, bool updateSelection = true );
     bool isTargetSelected( const QPoint& p );
 
@@ -266,7 +298,7 @@ class KateViewInternal : public QWidget
     //
     // line scrollbar + first visible (virtual) line in the current view
     //
-    QScrollBar *m_lineScroll;
+    KateScrollBar *m_lineScroll;
     QWidget* m_dummy;
     QVBoxLayout* m_lineLayout;
     QHBoxLayout* m_colLayout;
@@ -297,32 +329,40 @@ class KateViewInternal : public QWidget
     bool m_selChangedByUser;
     KateTextCursor selectAnchor;
 
+    enum SelectionMode { Default=0, Word, Line }; ///< for drag selection. @since 2.3
+    uint m_selectionMode;
+    // when drag selecting after double/triple click, keep the initial selected
+    // word/line independant of direction.
+    // They get set in the event of a double click, and is used with mouse move + leftbutton
+    KateTextCursor selStartCached;
+    KateTextCursor selEndCached;
+
     //
     // lines Ranges, mostly useful to speedup + dyn. word wrap
     //
-    QMemArray<LineRange> lineRanges;
+    QMemArray<KateLineRange> lineRanges;
 
     // Used to determine if the scrollbar will appear/disappear in non-wrapped mode
     bool scrollbarVisible(uint startLine);
     int maxLen(uint startLine);
 
     // returns the maximum X value / col value a cursor can take for a specific line range
-    int lineMaxCursorX(const LineRange& range);
-    int lineMaxCol(const LineRange& range);
+    int lineMaxCursorX(const KateLineRange& range);
+    int lineMaxCol(const KateLineRange& range);
 
     // get the values for a specific range.
     // specify lastLine to get the next line of a range.
-    LineRange range(int realLine, const LineRange* previous = 0L);
+    KateLineRange range(int realLine, const KateLineRange* previous = 0L);
 
-    LineRange currentRange();
-    LineRange previousRange();
-    LineRange nextRange();
+    KateLineRange currentRange();
+    KateLineRange previousRange();
+    KateLineRange nextRange();
 
     // Finds the lineRange currently occupied by the cursor.
-    LineRange range(const KateTextCursor& realCursor);
+    KateLineRange range(const KateTextCursor& realCursor);
 
     // Returns the lineRange of the specified realLine + viewLine.
-    LineRange range(uint realLine, int viewLine);
+    KateLineRange range(uint realLine, int viewLine);
 
     // find the view line of cursor c (0 = same line, 1 = down one, etc.)
     uint viewLine(const KateTextCursor& realCursor);
@@ -347,7 +387,7 @@ class KateViewInternal : public QWidget
     int m_currentMaxX;
 
     bool m_usePlainLines; // accept non-highlighted lines if this is set
-    TextLine::Ptr textLine(int realLine);
+    KateTextLine::Ptr textLine(int realLine);
 
     bool m_updatingView;
     int m_wrapChangeViewLine;
@@ -390,6 +430,9 @@ class KateViewInternal : public QWidget
    int m_imPreeditStartLine;
    int m_imPreeditStart;
    int m_imPreeditLength;
+   int m_imPreeditSelStart;
 };
 
 #endif
+
+// kate: space-indent on; indent-width 2; replace-tabs on;
