@@ -40,8 +40,9 @@ public:
    * Constructor.
    *
    * @param name The name of the catalog
+   * @param name The language of this catalog
    */
-  explicit KCatalogue(const QString & name = QString::null);
+  explicit KCatalogue(const QString & name = QString::null, const QString & language = QString::null);
 
   /**
    * Copy constructor.
@@ -66,12 +67,28 @@ public:
   QString name() const;
 
   /**
-   * Changes the current file name.
+   * Returns the language of the catalog.
    *
-   * @param fileName The new file name
+   * @return The language of the catalog
    */
-
-  void setFileName( const QString & fileName );
+  QString language() const;
+  
+  /**
+   * Returns the plural type for the catalog. This type is based on the language of the catalog
+   and is cached for performance.
+   *
+   * @return The plural type for the catalog
+   */
+  int pluralType() const;
+  
+  /**
+   * Sets the plural type for the catalog. The caller has probably looked it up in a kdelibs.mo-catalog 
+   * for the appropriate language
+   *
+   * @return The plural type for the catalog
+   */
+  void setPluralType( int pluralType );
+  
 
   /**
    * Retrieves a translation of the specified message id.
@@ -85,6 +102,13 @@ public:
   const char * translate( const char * msgid ) const;
 
 private:
+  /**
+   * @internal Changes the current file name.
+   *
+   * @param fileName The new file name
+   */
+
+  void setFileName( const QString & fileName );
   /**
    * @internal Retrieves the current file name.
    *
