@@ -19,7 +19,7 @@
   Boston, MA 02111-1307, USA.
 */
 
-// $Id: kconfig.cpp,v 1.79.2.1 2004/05/21 21:05:08 waba Exp $
+// $Id: kconfig.cpp,v 1.85 2004/05/21 20:51:18 waba Exp $
 
 #include <config.h>
 
@@ -38,6 +38,7 @@
 #include "kconfig.h"
 #include "kglobal.h"
 #include "kstandarddirs.h"
+#include "kstaticdeleter.h"
 #include <qtimer.h>
 
 KConfig::KConfig( const QString& fileName,
@@ -127,7 +128,7 @@ QStringList KConfig::groupList() const
          {
             if (group != "$Version") // Special case!
                retList.append(QString::fromUtf8(group));
-            break; // Grou is non-empty, added, next gropup
+            break; // Group is non-empty, added, next group
          }
          ++aIt;
       }
@@ -276,6 +277,13 @@ void KConfig::setFileWriteMode(int mode)
   backEnd->setFileWriteMode(mode);
 }
 
+KLockFile::Ptr KConfig::lockFile(bool bGlobal)
+{
+  KConfigINIBackEnd *aBackEnd = dynamic_cast<KConfigINIBackEnd*>(backEnd);
+  if (!aBackEnd) return 0;
+  return aBackEnd->lockFile(bGlobal);
+}
+
 void KConfig::checkUpdate(const QString &id, const QString &updateFile)
 {
   QString oldGroup = group();
@@ -320,6 +328,7 @@ KConfig* KConfig::copyTo(const QString &file, KConfig *config) const
 void KConfig::virtual_hook( int id, void* data )
 { KConfigBase::virtual_hook( id, data ); }
 
+static KStaticDeleter< QValueList<KSharedConfig*> > sd;
 QValueList<KSharedConfig*> *KSharedConfig::s_list = 0;
 
 KSharedConfig::Ptr KSharedConfig::openConfig(const QString& fileName, bool immutable, bool useKDEGlobals )
@@ -329,7 +338,9 @@ KSharedConfig::Ptr KSharedConfig::openConfig(const QString& fileName, bool immut
      for(QValueList<KSharedConfig*>::ConstIterator it = s_list->begin();
          it != s_list->end(); ++it)
      {
-        if ((*it)->backEnd->fileName() == fileName)
+        if ((*it)->backEnd->fileName() == fileName &&
+                (*it)->backEnd->bFileImmutable == immutable &&
+                (*it)->backEnd->useKDEGlobals == useKDEGlobals )
            return (*it);
      }
   }
@@ -340,14 +351,17 @@ KSharedConfig::KSharedConfig( const QString& fileName, bool readonly, bool usekd
  : KConfig(fileName, readonly, usekdeglobals)
 {
   if (!s_list)
-     s_list = new QValueList<KSharedConfig*>;
-     
+  {
+    sd.setObject(s_list, new QValueList<KSharedConfig*>);
+  }
+
   s_list->append(this);
 }
 
 KSharedConfig::~KSharedConfig()
 {
-  s_list->remove(this);
+  if ( s_list )
+    s_list->remove(this);
 }
 
 #include "kconfig.moc"
