@@ -19,14 +19,17 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kconfig.h,v 1.51 2002/09/28 12:28:47 tjansen Exp $
+// $Id: kconfig.h,v 1.64 2004/05/07 12:47:15 waba Exp $
 
 #ifndef _KCONFIG_H
 #define _KCONFIG_H
 
 class QTimer;
 
+#include <qvaluelist.h>
+
 #include "kconfigbase.h"
+#include "klockfile.h"
 
 class KConfigPrivate;
 
@@ -36,7 +39,7 @@ class KConfigPrivate;
 * This class implements KDE's default configuration system.
 *
 * @author Kalle Dalheimer <kalle@kde.org>, Preston Brown <pbrown@kde.org>
-* @version $Id: kconfig.h,v 1.51 2002/09/28 12:28:47 tjansen Exp $
+* @version $Id: kconfig.h,v 1.64 2004/05/07 12:47:15 waba Exp $
 * @see KGlobal::config(), KConfigBase, KSimpleConfig
 * @short KDE Configuration Management class
 */
@@ -45,6 +48,7 @@ class KConfig : public KConfigBase
   Q_OBJECT
 
 public:
+
   /**
    * Constructs a KConfig object.
    *
@@ -56,11 +60,13 @@ public:
    *        object will automatically become read-only if either the user does not have
    *        write permission to @p fileName or if no file was specified.
    * @param bUseKDEGlobals Toggle reading the global KDE configuration file.
-   * @param resType the place to look in (config, data, etc) See @ref KStandardDirs.
+   * @param resType the place to look in (config, data, etc) See KStandardDirs.
    */
   KConfig( const QString& fileName = QString::null,
           bool bReadOnly = false, bool bUseKDEGlobals = true, const char *resType="config");
 
+  KConfig(KConfigBackEnd *backEnd, bool bReadOnly = false);
+
   /**
    * Destructs the KConfig object.
    *
@@ -72,7 +78,7 @@ public:
   /**
    * Clears all entries out of the @p dirtyEntryMap, so the
    * values will not be written to disk on a later call to
-   * @ref sync().
+   * sync().
    *
    * @param bDeep If true, the dirty map is actually emptied.
    *        otherwise, the config object's global dirty flag is set to
@@ -121,14 +127,14 @@ public:
    * Forces all following write-operations being performed on kdeglobals,
    * independent of the bGlobal flag in writeEntry().
    * @param force true to force writing in kdeglobals
-   * @see #forceGlobal
+   * @see forceGlobal
    */
   void setForceGlobal( bool force ) { bForceGlobal = force; }
 
   /**
    * Returns true if all entries are being written into kdeglobals.
    * @return true if all entries are being written into kdeglobals
-   * @see #setForceGlobal
+   * @see setForceGlobal
    */
   bool forceGlobal() const { return bForceGlobal; }
 
@@ -147,7 +153,34 @@ public:
    * @since 3.1
    */
   void checkUpdate(const QString &id, const QString &updateFile);
-    
+
+  /**
+   * Copies all entries from this config object to a new config
+   * object that will save itself to @p file.
+   *
+   * Actual saving to @p file happens when the returned object is
+   * destructed or when sync() is called upon it.
+   *
+   * @param file the new config object will save itself to.
+   * @param config optional config object to reuse
+   * @since 3.2
+   */
+  KConfig* copyTo(const QString &file, KConfig *config=0) const;
+
+  /**
+   * Returns a lock file object for the configuration file or 0 if
+   * the backend does not support locking.
+   * @param bGlobal if true, return the lock file for the global config file
+   *
+   * NOTE: KConfig::sync() requires a lock on both the normal and global
+   * config file. When calling KConfig::sync() while having a lock on the
+   * global config file, the normal config file MUST be locked AS WELL and the 
+   * normal config file MUST be locked BEFORE the global config file!
+   * Otherwise there is a risk of deadlock.
+   * @since 3.3
+   */
+  KLockFile::Ptr lockFile( bool bGlobal=false );
+
 protected:
 
   /**
@@ -159,6 +192,7 @@ protected:
   virtual bool internalHasGroup(const QCString &group) const;
 
   /**
+   * @internal
    * Returns a map (tree) of the entries in the specified group.
    *
    * Do not use this function, the implementation / return type are
@@ -166,19 +200,17 @@ protected:
    *
    * @param pGroup the group to provide a KEntryMap for.
    * @return The map of the entries in the group.
-   * @internal
    */
   virtual KEntryMap internalEntryMap(const QString &pGroup) const;
 
   /**
+   * @internal
    * Returns a copy of the internal map used to hold all entries.
    *
    * Do not use this function, the implementation / return type are
    * subject to change.
    *
-   * @param pGroup the group to provide a KEntryMap for.
    * @return The map of the entries in the group.
-   * @internal
    */
    virtual KEntryMap internalEntryMap() const { return aEntryMap; }
 
@@ -208,7 +240,7 @@ protected:
    * Contains all key,value entries, as well as some "special"
    * keys which indicate the start of a group of entries.
    *
-   * These special keys will have the .key portion of their @ref KEntryKey
+   * These special keys will have the .key portion of their KEntryKey
    * set to QString::null.
    */
   KEntryMap aEntryMap;
@@ -235,5 +267,26 @@ private:
   KConfigPrivate *d;
 };
 
+class KSharedConfig : public KConfig, public KShared
+{
+  friend class QValueList<KSharedConfig*>;
+public:
+  typedef KSharedPtr<KSharedConfig> Ptr;
+
+public:  
+  /**
+   * Returns a ref-counted pointer to a shared read-write config object.
+   * @param immutable, if true, force the config object to be read-only.
+   * @param bUseKDEGlobals Toggle reading the global KDE configuration file.
+   */
+  static KSharedConfig::Ptr openConfig(const QString& fileName, bool immutable = false,
+    bool bUseKDEGlobals = true);
+
+private:
+  KSharedConfig( const QString& fileName, bool immutable, bool useKDEGlobals );
+  ~KSharedConfig();
+
+  static QValueList<KSharedConfig*> *s_list;
+};
 
 #endif
