@@ -37,12 +37,14 @@
 #include <ksimpleconfig.h>
 #include <kstandarddirs.h>
 
+#include <iostream>
+
 static const KCmdLineOptions options[] =
 {
   { "d", 0, 0 },
   { "directory <dir>", I18N_NOOP("Directory to generate files in"), "." },
-  { "+file.kfcg", I18N_NOOP("Input kcfg XML file."), 0 },
-  { "+file.kcfgc", I18N_NOOP("Code generation options file."), 0 },
+  { "+file.kcfg", I18N_NOOP("Input kcfg XML file"), 0 },
+  { "+file.kcfgc", I18N_NOOP("Code generation options file"), 0 },
   KCmdLineLastOption
 };
 
@@ -136,7 +138,13 @@ class CfgEntry
 // whatsthis
       kdDebug() << "  code: " << mCode << endl;
 //      kdDebug() << "  values: " << mValues.join(":") << endl;
-      kdDebug() << "  paramvalues: " << mParamValues.join(":") << endl;
+      
+      if (!param().isEmpty())
+      {
+        kdDebug() << "  param name: "<< mParamName << endl;
+        kdDebug() << "  param type: "<< mParamType << endl;
+        kdDebug() << "  paramvalues: " << mParamValues.join(":") << endl;
+      }
       kdDebug() << "  default: " << mDefaultValue << endl;
       kdDebug() << "  hidden: " << mHidden << endl;
       kdDebug() << "  min: " << mMin << endl;
@@ -202,6 +210,16 @@ static void addQuotes( QString &s )
   if ( s.right( 1 ) != "\"" ) s.append( "\"" );
 }
 
+static QString quoteString( const QString &s )
+{
+  QString r = s;
+  r.replace( "\\", "\\\\" );
+  r.replace( "\"", "\\\"" );
+  r.replace( "\r", "" );
+  r.replace( "\n", "\\n\"\n\"" );
+  return "\"" + r + "\"";
+}
+
 static QString dumpNode(const QDomNode &node)
 {
   QString msg;
@@ -242,7 +260,7 @@ static void preProcessDefault( QString &defaultValue, const QString &name,
       QStringList defaults = QStringList::split( ",", defaultValue );
       QStringList::ConstIterator it;
       for( it = defaults.begin(); it != defaults.end(); ++it ) {
-        cpp << "  default" << name << ".append( \"" << *it << "\" );"
+        cpp << "  default" << name << ".append( QString::fromUtf8( \"" << *it << "\" ) );"
             << endl;
       }
       defaultValue = "default" + name;
@@ -411,7 +429,7 @@ CfgEntry *parseEntry( const QString &group, const QDomElement &element )
 
   if ( name.isEmpty() ) {
     name = key;
-    name.replace( " ", "" );
+    name.replace( " ", QString::null );
   } else if ( name.contains( ' ' ) ) {
     kdWarning()<<"Entry '"<<name<<"' contains spaces! <name> elements can't contain speces!"<<endl;
     name.remove( ' ' );
@@ -612,7 +630,9 @@ static QString itemDeclaration(const CfgEntry *e)
      return QString::null;
 
   return "  KConfigSkeleton::Item"+itemType( e->type() ) +
-         "  *item" + e->name() + ";\n";
+         "  *item" + e->name() + 
+         ( (!e->param().isEmpty())?(QString("[%1]").arg(e->paramMax()+1)) : QString::null) + 
+         ";\n";
 }
 
 static QString itemVar(const CfgEntry *e)
@@ -630,7 +650,11 @@ QString newItem( const QString &type, const QString &name, const QString &key,
   QString t = "new KConfigSkeleton::Item" + itemType( type ) +
               "( currentGroup(), " + key + ", " + varName( name ) + param;
   if ( type == "Enum" ) t += ", values" + name;
-  if ( !defaultValue.isEmpty() ) t += ", " + defaultValue;
+  if ( !defaultValue.isEmpty() ) {
+    t += ", ";
+    if ( type == "String" ) t += defaultValue;
+    else t+= defaultValue;
+  }
   t += " );";
 
   return t;
@@ -649,7 +673,7 @@ QString paramString(const QString &s, const CfgEntry *e, int i)
     }
     else
     {
-      tmp = QString("%1").arg(i);
+      tmp = QString::number(i);
     }
 
     result.replace(needle, tmp);
@@ -674,21 +698,31 @@ QString paramString(const QString &group, const QStringList &parameters)
      }
   }
   if (arguments.isEmpty())
-    return "\""+group+"\"";
+    return "QString::fromLatin1( \""+group+"\" )";
 
-  return "QString(\""+paramString+"\")"+arguments;
+  return "QString::fromLatin1( \""+paramString+"\" )"+arguments;
 }
 
-QString userTextsFunctions( CfgEntry *e )
+/* int i is the value of the parameter */
+QString userTextsFunctions( CfgEntry *e, QString itemVarStr=QString::null, QString i=QString::null )
 {
   QString txt;
+  if (itemVarStr.isNull()) itemVarStr=itemVar(e);
   if ( !e->label().isEmpty() ) {
-    txt += "  " + itemVar(e) + "->setLabel( i18n(\"" +
-           e->label() + "\") );\n";
+    txt += "  " + itemVarStr + "->setLabel( i18n(";
+    if ( !e->param().isEmpty() )
+      txt += quoteString(e->label().replace("$("+e->param()+")", i));
+    else 
+      txt+= quoteString(e->label());
+    txt+= ") );\n";
   }
   if ( !e->whatsThis().isEmpty() ) {
-    txt += "  " + itemVar(e) + "->setWhatsThis( i18n(\"" +
-           e->whatsThis() + "\") );\n";
+    txt += "  " + itemVarStr + "->setWhatsThis( i18n(";
+    if ( !e->param().isEmpty() )
+      txt += quoteString(e->whatsThis().replace("$("+e->param()+")", i));
+    else 
+      txt+= quoteString(e->whatsThis());
+    txt+=") );\n";
   }
   return txt;
 }
@@ -696,10 +730,12 @@ QString userTextsFunctions( CfgEntry *e )
 int main( int argc, char **argv )
 {
   KAboutData aboutData( "kconfig_compiler", I18N_NOOP("KDE .kcfg compiler"), "0.3",
-  	I18N_NOOP("KConfig Compiler") , KAboutData::License_LGPL );
+    I18N_NOOP("KConfig Compiler") , KAboutData::License_LGPL );
   aboutData.addAuthor( "Cornelius Schumacher", 0, "schumacher@kde.org" );
   aboutData.addAuthor( "Waldo Bastian", 0, "bastian@kde.org" );
   aboutData.addAuthor( "Zack Rusin", 0, "zack@kde.org" );
+  aboutData.addCredit( "Reinhold Kainhofer", "Fix for parametrized entries", 
+      "reinhold@kainhofer.com", "http://reinhold.kainhofer.com" );
 
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options );
@@ -857,6 +893,7 @@ int main( int argc, char **argv )
 
   QString headerFileName = baseName + ".h";
   QString implementationFileName = baseName + ".cpp";
+  QString cppPreamble; // code to be inserted at the beginnin of the cpp file, e.g. initialization of static values
 
   QFile header( baseDir + headerFileName );
   if ( !header.open( IO_WriteOnly ) ) {
@@ -914,11 +951,21 @@ int main( int argc, char **argv )
     }
     QStringList values = e->paramValues();
     if ( !values.isEmpty() ) {
-      h << "    class " << enumName(e->param()) << endl;
-      h << "    {" << endl;
-      h << "      public:" << endl;
-      h << "      enum { " << values.join( ", " ) << ", COUNT };" << endl;
-      h << "    };" << endl;
+      if ( globalEnums ) {
+        h << "    enum { " << values.join( ", " ) << " };" << endl;
+        h << "    static const char* const " << enumName(e->param()) << "ToString[];" << endl;
+        cppPreamble += "const char* const " + className + "::" + enumName(e->param()) + "ToString[] = " +
+            "{ \"" + values.join( "\", \"" ) + "\" };\n";
+      } else {
+        h << "    class " << enumName(e->param()) << endl;
+        h << "    {" << endl;
+        h << "      public:" << endl;
+        h << "      enum { " << values.join( ", " ) << ", COUNT };" << endl;
+        h << "      static const char* const enumToString[];" << endl;
+        h << "    };" << endl;
+        cppPreamble += "const char* const " + className + "::" + enumName(e->param()) + "::enumToString[] = " +
+            "{ \"" + values.join( "\", \"" ) + "\" };\n";
+      }
     }
   }
 
@@ -968,7 +1015,23 @@ int main( int argc, char **argv )
         h << cppType(e->paramType()) << " i, ";
       h << param( t ) << " v )" << endl;
       h << "    {" << endl;
-      h << "      if (!" << This << "isImmutable( \"" << n << "\" ))" << endl;
+      h << "      if (!" << This << "isImmutable( QString::fromLatin1( \"";
+      if (!e->param().isEmpty()) {
+        h << e->paramName().replace("$("+e->param()+")", "%1") << "\" ).arg( ";
+        if ( e->paramType() == "Enum" ) {
+          h << "QString::fromLatin1( ";
+          if (globalEnums) 
+            h << enumName(e->name()) << "ToString[i]";
+          else 
+            h << enumName(e->param()) << "::enumToString[i]";
+          h << " )";
+        } else {
+          h << "i";
+        }
+        h << " )";
+      } else
+        h << n << "\" )";
+      h << " ))" << endl;
       h << "        " << This << varName(n);
       if (!e->param().isEmpty())
         h << "[i]";
@@ -988,8 +1051,7 @@ int main( int argc, char **argv )
     h << ")" << Const << endl;
     h << "    {" << endl;
     h << "      return " << This << varName(n);
-    if (!e->param().isEmpty())
-      h << "[i]";
+    if (!e->param().isEmpty()) h << "[i]";
     h << ";" << endl;
     h << "    }" << endl;
 
@@ -1001,9 +1063,15 @@ int main( int argc, char **argv )
         << endl;
       h << "    */" << endl;
       h << "    Item" << itemType( e->type() ) << " *"
-        << getFunction( n ) << "Item()" << endl;
+        << getFunction( n ) << "Item(";
+      if (!e->param().isEmpty()) {
+        h << " " << cppType(e->paramType()) << " i ";
+      }
+      h << ")" << endl;
       h << "    {" << endl;
-      h << "      return " << itemVar(e) << ";" << endl;
+      h << "      return " << itemVar(e);
+      if (!e->param().isEmpty()) h << "[i]";
+      h << ";" << endl;
       h << "    }" << endl;
     }
 
@@ -1057,7 +1125,9 @@ int main( int argc, char **argv )
   h << endl << "  private:" << endl;
   if ( itemAccessors ) {
     for( e = entries.first(); e; e = entries.next() ) {
-      h << "    Item" << itemType( e->type() ) << " *" << itemVar( e ) << ";" << endl;
+      h << "    Item" << itemType( e->type() ) << " *" << itemVar( e );
+      if (!e->param().isEmpty() ) h << QString("[%1]").arg( e->paramMax()+1 );
+      h << ";" << endl;
     }
   }
 
@@ -1071,7 +1141,7 @@ int main( int argc, char **argv )
 
   if ( !nameSpace.isEmpty() ) h << "}" << endl << endl;
 
-  h << "#endif" << endl << endl;
+  h << "#endif" << endl;
 
 
   header.close();
@@ -1108,17 +1178,20 @@ int main( int argc, char **argv )
   // Singleton implementation
   if ( singleton ) {
     cpp << className << " *" << className << "::mSelf = 0;" << endl;
-    cpp << "static KStaticDeleter<" << className << "> staticDeleter;" << endl << endl;
+    cpp << "static KStaticDeleter<" << className << "> static" << className << "Deleter;" << endl << endl;
 
     cpp << className << " *" << className << "::self()" << endl;
     cpp << "{" << endl;
     cpp << "  if ( !mSelf ) {" << endl;
-    cpp << "    staticDeleter.setObject( mSelf, new " << className << "() );" << endl;
+    cpp << "    static" << className << "Deleter.setObject( mSelf, new " << className << "() );" << endl;
     cpp << "    mSelf->readConfig();" << endl;
     cpp << "  }" << endl << endl;
     cpp << "  return mSelf;" << endl;
     cpp << "}" << endl << endl;
   }
+  
+  if ( !cppPreamble.isEmpty() )
+    cpp << cppPreamble << endl;
 
   // Constructor
   cpp << className << "::" << className << "( ";
@@ -1134,8 +1207,9 @@ int main( int argc, char **argv )
   cpp << " )" << endl;
 
   cpp << "  : " << inherits << "(";
-  if ( !cfgFileName.isEmpty() ) cpp << " \"" << cfgFileName << "\" ";
+  if ( !cfgFileName.isEmpty() ) cpp << " QString::fromLatin1( \"" << cfgFileName << "\" ";
   if ( cfgFileNameArg ) cpp << " config ";
+  if ( !cfgFileName.isEmpty() ) cpp << ") ";
   cpp << ")" << endl;
 
   // Store parameters
@@ -1173,12 +1247,12 @@ int main( int argc, char **argv )
       for( it = choices.begin(); it != choices.end(); ++it ) {
         cpp << "  {" << endl;
         cpp << "    KConfigSkeleton::ItemEnum::Choice choice;" << endl;
-        cpp << "    choice.name = \"" << (*it).name << "\";" << endl;
+        cpp << "    choice.name = QString::fromLatin1( \"" << (*it).name << "\" );" << endl;
         if ( setUserTexts ) {
           if ( !(*it).label.isEmpty() )
-            cpp << "    choice.label = i18n(\"" << (*it).label << "\");" << endl;
+            cpp << "    choice.label = i18n(" << quoteString((*it).label) << ");" << endl;
           if ( !(*it).whatsThis.isEmpty() )
-            cpp << "    choice.whatsThis = i18n(\"" << (*it).whatsThis << "\");" << endl;
+            cpp << "    choice.whatsThis = i18n(" << quoteString((*it).whatsThis) << ");" << endl;
         }
         cpp << "    values" << e->name() << ".append( choice );" << endl;
         cpp << "  }" << endl;
@@ -1202,17 +1276,17 @@ int main( int argc, char **argv )
       cpp << "  addItem( " << itemVar(e);
       QString quotedName = e->name();
       addQuotes( quotedName );
-      if ( quotedName != key ) cpp << ", \"" << e->name() << "\"";
+      if ( quotedName != key ) cpp << ", QString::fromLatin1( \"" << e->name() << "\" )";
       cpp << " );" << endl;
     }
     else
     {
-// TODO: itemAccessors don't work with parameterized entries
-// TODO: itemVar(e) should be an array in that case
       // Indexed
       for(int i = 0; i <= e->paramMax(); i++)
       {
         QString defaultStr;
+        QString itemVarStr(itemVar(e)+QString("[%1]").arg(i));
+        
         if ( !e->paramDefaultValue(i).isEmpty() )
           defaultStr = e->paramDefaultValue(i);
         else if ( !e->defaultValue().isEmpty() )
@@ -1220,15 +1294,23 @@ int main( int argc, char **argv )
         else
           defaultStr = defaultValue( e->type() );
 
-        cpp << "  " << itemVar(e) << " = "
+        cpp << "  " << itemVarStr << " = "
             << newItem( e->type(), e->name(), paramString(key, e, i), defaultStr, QString("[%1]").arg(i) )
             << endl;
 
         if ( setUserTexts )
-          cpp << userTextsFunctions( e );
+          cpp << userTextsFunctions( e, itemVarStr, e->paramName() );
 
-        cpp << "  addItem( " << itemVar( e ) << ", \""
-            << paramString(e->paramName(), e, i) << "\" );" << endl;
+        // Make mutators for enum parameters work by adding them with $(..) replaced by the 
+        // param name. The check for isImmutable in the set* functions doesn't have the param 
+        // name available, just the corresponding enum value (int), so we need to store the 
+        // param names in a separate static list!.
+        cpp << "  addItem( " << itemVarStr << ", QString::fromLatin1( \"";
+        if ( e->paramType()=="Enum" )
+          cpp << e->paramName().replace( "$("+e->param()+")", "%1").arg(e->paramValues()[i] );
+        else
+          cpp << e->paramName().replace( "$("+e->param()+")", "%1").arg(i);
+        cpp << "\" ) );" << endl;
       }
     }
   }
@@ -1240,7 +1322,7 @@ int main( int argc, char **argv )
   cpp << "{" << endl;
   if ( singleton ) {
     cpp << "  if ( mSelf == this )" << endl;
-    cpp << "    staticDeleter.setObject( mSelf, 0, false );" << endl;
+    cpp << "    static" << className << "Deleter.setObject( mSelf, 0, false );" << endl;
   }
   cpp << "}" << endl << endl;
 
