@@ -20,8 +20,6 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kconfigbase.h,v 1.104 2003/11/26 23:28:41 ossi Exp $
-
 #ifndef _KCONFIGBASE_H
 #define _KCONFIGBASE_H
 
@@ -63,7 +61,6 @@ class KConfigGroup;
  * group name.
  *
  * @author Kalle Dalheimer <kalle@kde.org>, Preston Brown <pbrown@kde.org>
- * @version $Id: kconfigbase.h,v 1.104 2003/11/26 23:28:41 ossi Exp $
  * @see  KGlobal#config()  KConfig  KSimpleConfig
  * @short KDE Configuration Management abstract base class
  */
@@ -139,7 +136,7 @@ public:
    *
    * @param pKey The key to search for.
    * @param aDefault A default value returned if the key was not found.
-   * @return The value for this key. Can be QString::null if aDefault it null.
+   * @return The value for this key. Can be QString::null if aDefault is null.
    */
    QString readEntry(const QString& pKey,
                      const QString& aDefault = QString::null ) const;
@@ -149,7 +146,7 @@ public:
    *
    * @param pKey The key to search for.
    * @param aDefault A default value returned if the key was not found.
-   * @return The value for this key. Can be QString::null if aDefault it null.
+   * @return The value for this key. Can be QString::null if aDefault is null.
    */
    QString readEntry(const char *pKey,
                      const QString& aDefault = QString::null ) const;
@@ -261,6 +258,18 @@ public:
    */
   QStringList readListEntry( const char *pKey, char sep = ',' ) const;
 
+  /**
+   * Reads a list of strings, but returns a default if the key 
+   * did not exist.
+   * @param pKey The key to search for.
+   * @param aDefault The default value to use if the key does not exist.
+   * @param sep The list separator (default is ",").
+   * @return The list. Contains @p aDefault if the Key does not exist.
+   * @since 3.3
+   */
+  QStringList readListEntry( const char* pKey, const QStringList& aDefault, 
+		  char sep = ',' ) const;
+
   /**
    * Reads a list of Integers.
    *
@@ -552,7 +561,7 @@ public:
    * @param bDefault A default value returned if the key was not found.
    * @return The value for this key.
    */
-  bool readBoolEntry( const QString& pKey, const bool bDefault = false ) const;
+  bool readBoolEntry( const QString& pKey, bool bDefault = false ) const;
 
   /**
    * Reads a boolean entry.
@@ -565,7 +574,7 @@ public:
    * @param bDefault A default value returned if the key was not found.
    * @return The value for this key.
    */
-  bool readBoolEntry( const char *pKey, const bool bDefault = false ) const;
+  bool readBoolEntry( const char *pKey, bool bDefault = false ) const;
 
   /**
    * Reads a QRect entry.
@@ -1144,7 +1153,7 @@ public:
    * @param bNLS        If @p bNLS is true, the locale tag is added to the key
    *  when writing it back.
    */
-  void writeEntry( const QString& pKey, Q_LLONG nValue,
+  void writeEntry( const QString& pKey, Q_INT64 nValue,
                       bool bPersistent = true, bool bGlobal = false,
                       bool bNLS = false );
   /**
@@ -1161,7 +1170,7 @@ public:
    * @param bNLS        If @p bNLS is true, the locale tag is added to the key
    *  when writing it back.
    */
-  void writeEntry( const char *pKey, Q_LLONG nValue,
+  void writeEntry( const char *pKey, Q_INT64 nValue,
                       bool bPersistent = true, bool bGlobal = false,
                       bool bNLS = false );
 
@@ -1179,7 +1188,7 @@ public:
    * @param bNLS        If @p bNLS is true, the locale tag is added to the key
    *  when writing it back.
    */
-  void writeEntry( const QString& pKey, Q_ULLONG nValue,
+  void writeEntry( const QString& pKey, Q_UINT64 nValue,
                       bool bPersistent = true, bool bGlobal = false,
                       bool bNLS = false );
   /**
@@ -1196,7 +1205,7 @@ public:
    * @param bNLS        If @p bNLS is true, the locale tag is added to the key
    *  when writing it back.
    */
-  void writeEntry( const char *pKey, Q_ULLONG nValue,
+  void writeEntry( const char *pKey, Q_UINT64 nValue,
                       bool bPersistent = true, bool bGlobal = false,
                       bool bNLS = false );
 
@@ -1627,7 +1636,7 @@ public:
    *
    * @param pKey The key to delete.
    * @param bGlobal     If @p bGlobal is true, the pair is not removed from the
-   *  application specific config file, but to the global KDE config file.
+   *  application specific config file, but from the global KDE config file.
    * @param bNLS        If @p bNLS is true, the key with the locale tag is removed.
    */
    void deleteEntry( const char *pKey,
@@ -1645,8 +1654,8 @@ public:
    * @param group The name of the group
    * @param bDeep Specify whether non-empty groups should be completely
    *        deleted (including their entries).
-   * @param bGlobal     If @p bGlobal is true, the pair is not removed from the
-   *  application specific config file, but to the global KDE config file.
+   * @param bGlobal     If @p bGlobal is true, the group is not removed from the
+   *  application specific config file, but from the global KDE config file.
    * @return If the group is not empty and bDeep is false,
    *         deleteGroup returns false.
    */
@@ -1843,19 +1852,25 @@ public:
    * Returns whether a default is specified for an entry in either the
    * system wide configuration file or the global KDE config file.
    *
-   * If an application uses a dynamically determined default value for
-   * a certain entry, it may wish to make the following check before
+   * If an application computes a default value at runtime for
+   * a certain entry, e.g. like:
+   * \code
+   * QColor computedDefault = kapp->palette().color(QPalette::Active, QColorGroup::Text)
+   * QColor color = config->readEntry(key, computedDefault);
+   * \encode
+   *
+   * Then it may wish to make the following check before
    * writing back changes:
    * \code
-   * if ( (value == dynamicDefault) && !config->hasDefault(key) )
-   *    revertToDefault(key)
+   * if ( (value == computedDefault) && !config->hasDefault(key) )
+   *    config->revertToDefault(key)
    * else
-   *    writeEntry(key, value)
+   *    config->writeEntry(key, value)
    * \endcode
    *
-   * This ensures that as long as the entry is not modified to differ
-   * from the dynamically determined default, the application will
-   * follow changes of the default.
+   * This ensures that as long as the entry is not modified to differ from 
+   * the computed default, the application will keep using the computed default
+   * and will follow changes the computed default makes over time.
    * @param key The key of the entry to check.
    * @since 3.2
    */
@@ -2018,13 +2033,16 @@ class KConfigGroupSaverPrivate;
   * one group (including the creation of the KConfigGroupSaver object)
   * in one block.
   *
+  * @deprecated This class is deprecated and will be removed in KDE 4.
+  * KConfigGroup provides similar functionality in a more object oriented
+  * way.
+  *
   * @author Matthias Kalle Dalheimer <kalle@kde.org>
-  * @version $Id: kconfigbase.h,v 1.104 2003/11/26 23:28:41 ossi Exp $
-  * @see KConfigBase, KConfig, KSimpleConfig
+  * @see KConfigBase, KConfig, KSimpleConfig, KConfigGroup
   * @short Helper class for easier use of KConfig/KSimpleConfig groups
   */
 
-class KConfigGroupSaver
+class KConfigGroupSaver // KDE4 remove
 {
 public:
   /**
