@@ -37,6 +37,9 @@ class QStringList;
 class QColor;
 class QPen;
 class QBrush;
+class QVariant;
+template <class T>
+class QValueList;
 
 class kdbgstream;
 class kndbgstream;
@@ -83,8 +86,7 @@ class kdbgstream {
     kdbgstream(const char * initialString, unsigned int _area, unsigned int _level, bool _print = true) :
       output(QString::fromLatin1(initialString)), area(_area), level(_level),  print(_print) { }
     /// Copy constructor
-    kdbgstream(kdbgstream &str) :
-      output(str.output), area(str.area), level(str.level), print(str.print) { str.output.truncate(0); }
+    kdbgstream(kdbgstream &str);
     kdbgstream(const kdbgstream &str) :
       output(str.output), area(str.area), level(str.level), print(str.print) {}
     ~kdbgstream();
@@ -120,17 +122,17 @@ class kdbgstream {
     }
     /**
      * Prints the given value.
-     * @param i the char to print
+     * @param ch the char to print
      * @return this stream
      */
-    kdbgstream &operator<<(char i);
+    kdbgstream &operator<<(char ch);
     /**
      * Prints the given value.
-     * @param i the unsigned char to print
+     * @param ch the unsigned char to print
      * @return this stream
      */
-    kdbgstream &operator<<(unsigned char i) {
-        return operator<<( static_cast<char>( i ) );
+    kdbgstream &operator<<(unsigned char ch) {
+        return operator<<( static_cast<char>( ch ) );
     }
     /**
      * Prints the given value.
@@ -172,11 +174,39 @@ class kdbgstream {
         QString tmp; tmp.setNum(i); output += tmp;
         return *this;
     }
+    /**
+     * Prints the given value.
+     * @param i the long long to print
+     * @return this stream
+     */
+    kdbgstream &operator<<(Q_LLONG i) {
+        if (!print) return *this;
+        QString tmp; tmp.setNum(i); output += tmp;
+        return *this;
+    }
+    /**
+     * Prints the given value.
+     * @param i the unsigned long long to print
+     * @return this stream
+     */
+    kdbgstream &operator<<(Q_ULLONG i) {
+        if (!print) return *this;
+        QString tmp; tmp.setNum(i); output += tmp;
+        return *this;
+    }
+
     /**
      * Flushes the output.
      */
     void flush(); //AB: maybe this should be virtual! would save some trouble for some 3rd party projects
 
+    /**
+     * Prints the given value.
+     * @param ch the char to print
+     * @return this stream
+     * @since 3.3
+     */
+    kdbgstream &operator<<(QChar ch);
     /**
      * Prints the given value.
      * @param string the string to print
@@ -318,6 +348,7 @@ class kdbgstream {
      * @param list the stringlist to print
      * @return this stream
      */
+    // ### KDE4: Remove in favor of template operator for QValueList<T> below
     kdbgstream& operator << ( const QStringList& list);
 
     /**
@@ -342,6 +373,30 @@ class kdbgstream {
      */
     kdbgstream& operator << ( const QBrush& brush );
 
+    /**
+     * Prints the given value.
+     * @param variant the variant to print
+     * @return this stream
+     * @since 3.3
+     */
+    kdbgstream& operator << ( const QVariant& variant );
+
+    /**
+     * Prints the given value.
+     * @param data the byte array to print
+     * @return this stream
+     * @since 3.3
+     */
+    kdbgstream& operator << ( const QByteArray& data );
+
+    /**
+     * Prints the given value
+     * @param list the list to print
+     * @return this stream
+     * @since 3.3
+     */
+    template <class T>
+    kdbgstream& operator << ( const QValueList<T> &list );
 
  private:
     QString output;
@@ -350,6 +405,21 @@ class kdbgstream {
     kdbgstreamprivate* d;
 };
 
+template <class T>
+kdbgstream &kdbgstream::operator<<( const QValueList<T> &list )
+{
+    *this << "(";
+    typename QValueList<T>::ConstIterator it = list.begin();
+    if ( !list.isEmpty() ) {
+      *this << *it++;
+    }
+    for ( ; it != list.end(); ++it ) {
+      *this << "," << *it;
+    }
+    *this << ")";
+    return *this;
+}
+
 /**
  * \relates KGlobal
  * Prints an "\n".
@@ -413,6 +483,11 @@ class kndbgstream {
      * Does nothing.
      */
     void flush() {}
+    /**
+     * Does nothing.
+     * @return this stream
+     */
+    kndbgstream &operator<<(QChar)  { return *this; }
     /**
      * Does nothing.
      * @return this stream
@@ -453,6 +528,16 @@ class kndbgstream {
      * @return this stream
      */
     kndbgstream& operator<<(unsigned long) { return *this; }
+    /**
+     * Does nothing.
+     * @return this stream
+     */
+    kndbgstream& operator<<(Q_LLONG) { return *this; }
+    /**
+     * Does nothing.
+     * @return this stream
+     */
+    kndbgstream& operator<<(Q_ULLONG) { return *this; }
     /**
      * Does nothing.
      * @return this stream
@@ -482,6 +567,11 @@ class kndbgstream {
     kndbgstream& operator<<( const QColor & ) { return *this; }
     kndbgstream& operator<<( const QPen & ) { return *this; }
     kndbgstream& operator<<( const QBrush & ) { return *this; }
+    kndbgstream& operator<<( const QVariant & ) { return *this; }
+    kndbgstream& operator<<( const QByteArray & ) { return *this; }
+
+    template <class T>
+    kndbgstream& operator<<( const QValueList<T> & ) { return *this; }
 };
 
 /**
