@@ -19,7 +19,7 @@
   Boston, MA 02111-1307, USA.
 */
 
-// $Id: kdesktopfile.cpp,v 1.44 2003/09/19 22:51:47 hausmann Exp $
+// $Id: kdesktopfile.cpp,v 1.45.2.1 2004/10/04 10:14:06 waba Exp $
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -27,6 +27,7 @@
 #include <qfile.h>
 #include <qtextstream.h>
 
+#include <kdebug.h>
 #include "kurl.h"
 #include "kconfigbackend.h"
 #include "kapplication.h"
@@ -59,17 +60,25 @@ QString KDesktopFile::locateLocal(const QString &path)
   QString local;
   if (path.endsWith(".directory"))
   {
-    if (!path.startsWith("/"))
+    local = path;
+    if (local.startsWith("/"))
     {
-      local = ::locateLocal("apps", path); // Relative to apps
+      // Relative wrt apps?
+      local = KGlobal::dirs()->relativeLocation("apps", path);
+    }
+
+    if (!local.startsWith("/"))
+    {
+      local = ::locateLocal("apps", local); // Relative to apps
     }
     else
     {
       // XDG Desktop menu items come with absolute paths, we need to 
       // extract their relative path and then build a local path.
-      local = KGlobal::dirs()->relativeLocation("xdgdata-dirs", path);
+      local = KGlobal::dirs()->relativeLocation("xdgdata-dirs", local);
       if (local.startsWith("/"))
       {
+        // Hm, that didn't work...
         // What now? Use filename only and hope for the best.
         local = path.mid(path.findRev('/')+1);
       }
@@ -130,6 +139,8 @@ bool KDesktopFile::isAuthorizedDesktopFile(const QString& path)
      return true;
   if (dirs->relativeLocation("data", path).startsWith("kdesktop/Desktop"))
      return true;
+     
+  kdWarning() << "Access to '" << path << "' denied because of 'run_desktop_files' restriction." << endl;
   return false;
 }
 
