@@ -25,17 +25,27 @@
 #include <kgenericfactory.tcc>
 #include <kglobal.h>
 #include <klocale.h>
+#include <kdebug.h>
 
 /* @internal */
 template <class T>
-class KGenericFactoryBase 
+class KGenericFactoryBase
 {
 public:
     KGenericFactoryBase( const char *instanceName )
-        : m_instanceName( instanceName ) 
+        : m_instanceName( instanceName )
+    {
+        m_aboutData=0L;
+        s_self = this;
+        m_catalogueInitialized = false;
+    }
+    KGenericFactoryBase( const KAboutData *data )
+        : m_aboutData(data)
     {
         s_self = this;
+        m_catalogueInitialized = false;
     }
+
     virtual ~KGenericFactoryBase()
     {
         if ( s_instance )
@@ -50,8 +60,12 @@ public:
 protected:
     virtual KInstance *createInstance()
     {
-        if ( !m_instanceName )
-            return 0; // ### assert
+        if ( m_aboutData )
+            return new KInstance( m_aboutData );
+        if ( !m_instanceName ) {
+            kdWarning() << "KGenericFactory: instance requested but no instance name or about data passed to the constructor!" << endl;
+            return 0;
+        }
         return new KInstance( m_instanceName );
     }
 
@@ -63,16 +77,17 @@ protected:
 
     void initializeMessageCatalogue()
     {
-        static bool catalogueInitialized = false;
-        if ( !catalogueInitialized )
+        if ( !m_catalogueInitialized )
         {
-            catalogueInitialized = true;
+            m_catalogueInitialized = true;
             setupTranslations();
         }
     }
 
 private:
     QCString m_instanceName;
+    const KAboutData *m_aboutData;
+    bool m_catalogueInitialized;
 
     static KInstance *s_instance;
     static KGenericFactoryBase<T> *s_self;
@@ -96,14 +111,14 @@ KInstance *KGenericFactoryBase<T>::instance()
 }
 
 /**
- * This template provides a generic implementation of a @ref KLibFactory ,
+ * This template provides a generic implementation of a KLibFactory ,
  * for use with shared library components. It implements the pure virtual
  * createObject method of KLibFactory and instantiates objects of the
  * specified class (template argument) when the class name argument of
  * createObject matches a class name in the given hierarchy.
  *
  * In case you are developing a KParts component, skip this file and
- * go directly to @ref KParts::GenericFactory .
+ * go directly to KParts::GenericFactory .
  *
  * Note that the class specified as template argument needs to provide
  * a certain constructor:
@@ -125,23 +140,23 @@ KInstance *KGenericFactoryBase<T>::instance()
  * The args QStringList passed to the constructor is the args string list
  * that the caller passed to KLibFactory's create method.
  *
- * In addition upon instantiation this template provides a central 
- * @ref KInstance object for your component, accessible through the
- * static @ref instance() method. The instanceName argument of the
+ * In addition upon instantiation this template provides a central
+ * KInstance object for your component, accessible through the
+ * static instance() method. The instanceName argument of the
  * KGenericFactory constructor is passed to the KInstance object.
  *
  * The creation of the KInstance object can be customized by inheriting
  * from this template class and re-implementing the virtual createInstance
  * method. For example it could look like this:
- * <pre>
+ * \code
  *     KInstance *MyFactory::createInstance()
  *     {
  *         return new KInstance( myAboutData );
  *     }
- * </pre>
+ * \endcode
  *
  * Example of usage of the whole template:
- * <pre>
+ * \code
  *     class MyPlugin : public KParts::Plugin
  *     {
  *         Q_ OBJECT
@@ -151,36 +166,44 @@ KInstance *KGenericFactoryBase<T>::instance()
  *         ...
  *     };
  *
- *     K_EXPORT_COMPONENT_FACTORY( libmyplugin, KGenericFactory&lt;MyPlugin&gt; );
- * </pre>
+ *     K_EXPORT_COMPONENT_FACTORY( libmyplugin, KGenericFactory&lt;MyPlugin&gt; )
+ * \endcode
  */
 template <class Product, class ParentType = QObject>
 class KGenericFactory : public KLibFactory, public KGenericFactoryBase<Product>
 {
 public:
     KGenericFactory( const char *instanceName = 0 )
-        : KGenericFactoryBase<Product>( instanceName ) 
+        : KGenericFactoryBase<Product>( instanceName )
     {}
 
+    /**
+     * @since 3.3
+	*/
+    KGenericFactory( const KAboutData *data )
+        : KGenericFactoryBase<Product>( data )
+    {}
+
+
 protected:
     virtual QObject *createObject( QObject *parent, const char *name,
                                   const char *className, const QStringList &args )
-    {   
-        initializeMessageCatalogue();
+    {
+        KGenericFactoryBase<Product>::initializeMessageCatalogue();
         return KDEPrivate::ConcreteFactory<Product, ParentType>
             ::create( 0, 0, parent, name, className, args );
     }
 };
 
 /**
- * This template provides a generic implementation of a @ref KLibFactory ,
+ * This template provides a generic implementation of a KLibFactory ,
  * for use with shared library components. It implements the pure virtual
  * createObject method of KLibFactory and instantiates objects of the
- * specified classes in the given typelist template argument when the class 
+ * specified classes in the given typelist template argument when the class
  * name argument of createObject matches a class names in the given hierarchy
  * of classes.
- * 
- * Note that each class in the specified in the typelist template argument 
+ *
+ * Note that each class in the specified in the typelist template argument
  * needs to provide a certain constructor:
  * <ul>
  *     <li>If the class is derived from QObject then it needs to have
@@ -200,23 +223,23 @@ protected:
  * The args QStringList passed to the constructor is the args string list
  * that the caller passed to KLibFactory's create method.
  *
- * In addition upon instantiation this template provides a central 
- * @ref KInstance object for your component, accessible through the
- * static @ref instance() method. The instanceName argument of the
+ * In addition upon instantiation this template provides a central
+ * KInstance object for your component, accessible through the
+ * static instance() method. The instanceName argument of the
  * KGenericFactory constructor is passed to the KInstance object.
  *
  * The creation of the KInstance object can be customized by inheriting
  * from this template class and re-implementing the virtual createInstance
  * method. For example it could look like this:
- * <pre>
+ * \code
  *     KInstance *MyFactory::createInstance()
  *     {
  *         return new KInstance( myAboutData );
  *     }
- * </pre>
+ * \endcode
  *
  * Example of usage of the whole template:
- * <pre>
+ * \code
  *     class MyPlugin : public KParts::Plugin
  *     {
  *         Q_ OBJECT
@@ -236,11 +259,11 @@ protected:
  *     };
  *
  *     typedef K_TYPELIST_2( MyPlugin, MyDialogComponent ) Products;
- *     K_EXPORT_COMPONENT_FACTORY( libmyplugin, KGenericFactory&lt;Products&gt; );
- * </pre>
+ *     K_EXPORT_COMPONENT_FACTORY( libmyplugin, KGenericFactory&lt;Products&gt; )
+ * \endcode
  */
 template <class Product, class ProductListTail>
-class KGenericFactory< KTypeList<Product, ProductListTail>, QObject > 
+class KGenericFactory< KTypeList<Product, ProductListTail>, QObject >
     : public KLibFactory,
       public KGenericFactoryBase< KTypeList<Product, ProductListTail> >
 {
@@ -249,25 +272,33 @@ public:
         : KGenericFactoryBase< KTypeList<Product, ProductListTail> >( instanceName )
     {}
 
+    /**
+     * @since 3.3
+	*/
+    KGenericFactory( const KAboutData *data )
+        : KGenericFactoryBase< KTypeList<Product, ProductListTail> >( data )
+    {}
+
+
 protected:
     virtual QObject *createObject( QObject *parent, const char *name,
                                    const char *className, const QStringList &args )
     {
-        initializeMessageCatalogue();
+        this->initializeMessageCatalogue();
         return KDEPrivate::MultiFactory< KTypeList< Product, ProductListTail > >
             ::create( 0, 0, parent, name, className, args );
     }
 };
 
 /**
- * This template provides a generic implementation of a @ref KLibFactory ,
+ * This template provides a generic implementation of a KLibFactory ,
  * for use with shared library components. It implements the pure virtual
  * createObject method of KLibFactory and instantiates objects of the
- * specified classes in the given typelist template argument when the class 
+ * specified classes in the given typelist template argument when the class
  * name argument of createObject matches a class names in the given hierarchy
  * of classes.
- * 
- * Note that each class in the specified in the typelist template argument 
+ *
+ * Note that each class in the specified in the typelist template argument
  * needs to provide a certain constructor:
  * <ul>
  *     <li>If the class is derived from QObject then it needs to have
@@ -287,23 +318,23 @@ protected:
  * The args QStringList passed to the constructor is the args string list
  * that the caller passed to KLibFactory's create method.
  *
- * In addition upon instantiation this template provides a central 
- * @ref KInstance object for your component, accessible through the
- * static @ref instance() method. The instanceName argument of the
+ * In addition upon instantiation this template provides a central
+ * KInstance object for your component, accessible through the
+ * static instance() method. The instanceName argument of the
  * KGenericFactory constructor is passed to the KInstance object.
  *
  * The creation of the KInstance object can be customized by inheriting
  * from this template class and re-implementing the virtual createInstance
  * method. For example it could look like this:
- * <pre>
+ * \code
  *     KInstance *MyFactory::createInstance()
  *     {
  *         return new KInstance( myAboutData );
  *     }
- * </pre>
+ * \endcode
  *
  * Example of usage of the whole template:
- * <pre>
+ * \code
  *     class MyPlugin : public KParts::Plugin
  *     {
  *         Q_ OBJECT
@@ -323,13 +354,13 @@ protected:
  *     };
  *
  *     typedef K_TYPELIST_2( MyPlugin, MyDialogComponent ) Products;
- *     K_EXPORT_COMPONENT_FACTORY( libmyplugin, KGenericFactory&lt;Products&gt; );
- * </pre>
+ *     K_EXPORT_COMPONENT_FACTORY( libmyplugin, KGenericFactory&lt;Products&gt; )
+ * \endcode
  */
 template <class Product, class ProductListTail,
           class ParentType, class ParentTypeListTail>
 class KGenericFactory< KTypeList<Product, ProductListTail>,
-                       KTypeList<ParentType, ParentTypeListTail> > 
+                       KTypeList<ParentType, ParentTypeListTail> >
     : public KLibFactory,
       public KGenericFactoryBase< KTypeList<Product, ProductListTail> >
 {
@@ -337,12 +368,19 @@ public:
     KGenericFactory( const char *instanceName  = 0 )
         : KGenericFactoryBase< KTypeList<Product, ProductListTail> >( instanceName )
     {}
+	/**
+	* @since 3.3
+	*/
+    KGenericFactory( const KAboutData *data )
+        : KGenericFactoryBase< KTypeList<Product, ProductListTail> >( data )
+    {}
+
 
 protected:
     virtual QObject *createObject( QObject *parent, const char *name,
                                    const char *className, const QStringList &args )
     {
-        initializeMessageCatalogue();
+        this->initializeMessageCatalogue();
         return KDEPrivate::MultiFactory< KTypeList< Product, ProductListTail >,
                                          KTypeList< ParentType, ParentTypeListTail > >
                                        ::create( 0, 0, parent, name,
