@@ -8,34 +8,6 @@
 #include "kkeyserver_x11.h"
 #include "kshortcut.h"
 
-/**
- * @internal
- * Represents a key code and modifier combination.
- */
-class CodeMod
-{
- public:
-  /**
-   * The key code of the CodeMod.
-   */
-	uchar code;
-  /**
-   * The modifier flags of the CodeMod.
-   */
-	uint mod;
-
-	/**
-	 * Compares two CodeMods. 
-	 */
-	bool operator < ( const CodeMod& b ) const
-	{
-		if( code < b.code ) return true;
-		if( code == b.code && mod < b.mod ) return true;
-		return false;
-	}
-};
-typedef QMap<CodeMod, KAccelAction*> CodeModMap;
-
 /**
  * @internal
  */
@@ -55,12 +27,35 @@ class KGlobalAccelPrivate : public QWidget, public KAccelBase
 	virtual bool disconnectKey( KAccelAction&, const KKeyServer::Key& );
 	virtual bool disconnectKey( const KKeyServer::Key& );
 
- signals:
-	void activated();
-	void activated( int );
-	void activated( const QString& sAction, const QString& sDesc, const KKeySequence& seq );
-
  protected:
+	/**
+	 * @internal
+	 * Represents a key code and modifier combination.
+	 */
+	class CodeMod
+	{
+	 public:
+	  /**
+	   * The key code of the CodeMod.
+	   */
+		uchar code;
+	  /**
+	   * The modifier flags of the CodeMod.
+	   */
+		uint mod;
+	
+		/**
+		 * Compares two CodeMods. 
+		 */
+		bool operator < ( const CodeMod& b ) const
+		{
+			if( code < b.code ) return true;
+			if( code == b.code && mod < b.mod ) return true;
+			return false;
+		}
+	};
+	typedef QMap<CodeMod, KAccelAction*> CodeModMap;
+
 	CodeModMap m_rgCodeModToAction;
 
 	/**
