@@ -28,7 +28,7 @@
 #include <kapplication.h>
 
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#include <kipc.h> // schroder
+#include <kipc.h>
 #endif
 
 #include <kdebug.h>
@@ -45,7 +45,7 @@
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
 //#ifdef Q_WS_X11
 //#include <X11/X.h>
-#include <X11/Xlib.h> // schroder
+#include <X11/Xlib.h>
 //#include <X11/Xutil.h>
 #endif
 
@@ -391,7 +391,7 @@ QFont KGlobalSettings::largeFont(const QString &text)
 {
     QFontDatabase db;
     QStringList fam = db.families();
-        
+
     // Move a bunch of preferred fonts to the front.
     if (fam.remove("Arial"))
        fam.prepend("Arial");
@@ -461,8 +461,6 @@ void KGlobalSettings::initStatic() // should be called initPaths(). Don't put an
     // Desktop Path
     *s_desktopPath = QDir::homeDirPath() + "/Desktop/";
     *s_desktopPath = config->readPathEntry( "Desktop", *s_desktopPath);
-    if ( !s_desktopPath->startsWith("/") )
-      s_desktopPath->prepend( QDir::homeDirPath() + "/" );
     *s_desktopPath = QDir::cleanDirPath( *s_desktopPath );
     if ( !s_desktopPath->endsWith("/") )
       s_desktopPath->append('/');
@@ -470,8 +468,6 @@ void KGlobalSettings::initStatic() // should be called initPaths(). Don't put an
     // Trash Path
     *s_trashPath = *s_desktopPath + i18n("Trash") + "/";
     *s_trashPath = config->readPathEntry( "Trash" , *s_trashPath);
-    if ( !s_trashPath->startsWith("/") )
-      s_trashPath->prepend( QDir::homeDirPath() + "/" );
     *s_trashPath = QDir::cleanDirPath( *s_trashPath );
     if ( !s_trashPath->endsWith("/") )
       s_trashPath->append('/');
@@ -485,16 +481,12 @@ void KGlobalSettings::initStatic() // should be called initPaths(). Don't put an
     // Autostart Path
     *s_autostartPath = KGlobal::dirs()->localkdedir() + "Autostart/";
     *s_autostartPath = config->readPathEntry( "Autostart" , *s_autostartPath);
-    if ( !s_autostartPath->startsWith("/") )
-      s_autostartPath->prepend( QDir::homeDirPath() + "/" );
     *s_autostartPath = QDir::cleanDirPath( *s_autostartPath );
     if ( !s_autostartPath->endsWith("/") )
       s_autostartPath->append('/');
 
     // Document Path
-    *s_documentPath = config->readPathEntry( "Documents" );
-    if ( !s_documentPath->startsWith("/") )
-      s_documentPath->prepend( QDir::homeDirPath() + "/" );
+    *s_documentPath = config->readPathEntry( "Documents", QDir::homeDirPath() );
     *s_documentPath = QDir::cleanDirPath( *s_documentPath );
     if ( !s_documentPath->endsWith("/"))
       s_documentPath->append('/');
@@ -567,24 +559,21 @@ KGlobalSettings::KMouseSettings & KGlobalSettings::mouseSettings()
             // This is a simplified version of the code in input/mouse.cpp
             // Keep in sync !
             s.handed = KMouseSettings::RightHanded;
-            unsigned char map[5];
-            switch (XGetPointerMapping(kapp->getDisplay(), map, 5))
+            unsigned char map[20];
+            int num_buttons = XGetPointerMapping(kapp->getDisplay(), map, 20);
+            if( num_buttons == 2 )
             {
-                case 2:
-                    if ( (int)map[0] == 1 && (int)map[1] == 2 )
-                        s.handed = KMouseSettings::RightHanded;
-                    else if ( (int)map[0] == 2 && (int)map[1] == 1 )
-                        s.handed = KMouseSettings::LeftHanded;
-                    break;
-                case 3:
-                case 5:
-                    if ( (int)map[0] == 1 && (int)map[2] == 3 )
-                        s.handed = KMouseSettings::RightHanded;
-                    else if ( (int)map[0] == 3 && (int)map[2] == 1 )
-                        s.handed = KMouseSettings::LeftHanded;
-                    break;
-                default:
-                    break;
+                if ( (int)map[0] == 1 && (int)map[1] == 2 )
+                    s.handed = KMouseSettings::RightHanded;
+                else if ( (int)map[0] == 2 && (int)map[1] == 1 )
+                    s.handed = KMouseSettings::LeftHanded;
+            }
+            else if( num_buttons >= 3 )
+            {
+                if ( (int)map[0] == 1 && (int)map[2] == 3 )
+                    s.handed = KMouseSettings::RightHanded;
+                else if ( (int)map[0] == 3 && (int)map[2] == 1 )
+                    s.handed = KMouseSettings::LeftHanded;
             }
 #else
 	    // FIXME(E): Implement in Qt Embedded
@@ -694,3 +683,11 @@ bool KGlobalSettings::opaqueResize()
     return c->readBoolEntry("OpaqueResize",
         KDE_DEFAULT_OPAQUE_RESIZE);
 }
+
+int KGlobalSettings::buttonLayout()
+{
+    KConfig *c = KGlobal::config();
+    KConfigGroupSaver cgs( c, "KDE" );
+    return c->readNumEntry("ButtonLayout",
+        KDE_DEFAULT_BUTTON_LAYOUT);
+}
