@@ -32,6 +32,7 @@
 #define KDE_DEFAULT_WHEEL_ZOOM false
 #define KDE_DEFAULT_ICON_ON_PUSHBUTTON false
 #define KDE_DEFAULT_OPAQUE_RESIZE true
+#define KDE_DEFAULT_BUTTON_LAYOUT 0
 
 class KURL;
 
@@ -39,7 +40,7 @@ class KURL;
  * Access the KDE global configuration.
  *
  * @author David Faure <faure@kde.org>
- * @version $Id: kglobalsettings.h,v 1.50 2003/10/14 19:02:00 waba Exp $
+ * @version $Id: kglobalsettings.h,v 1.51 2004/05/17 20:23:45 waba Exp $
  */
 class KGlobalSettings
 {
@@ -478,6 +479,15 @@ class KGlobalSettings
      */
     static bool opaqueResize();
 
+    /**
+     * The layout scheme to use for dialog buttons
+     * 
+     * @return Returns the number of the scheme to use.
+     * @see KDialogBase::setButtonStyle
+     * @since 3.3
+     */
+    static int buttonLayout();
+
 private:
     /**
      * reads in all paths from kdeglobals
