@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kiconloader.cpp,v 1.217 2003/11/20 21:41:54 antlarr Exp $
+ * $Id: kiconloader.cpp,v 1.220 2004/07/31 10:17:48 binner Exp $
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -220,6 +220,7 @@ void KIconLoader::init( const QString& _appname, KStandardDirs *_dirs )
     // Insert application specific themes at the top.
     d->mpDirs->addResourceType("appicon", KStandardDirs::kde_default("data") +
 		appname + "/pics/");
+    // ################## KDE4: consider removing the toolbar directory
     d->mpDirs->addResourceType("appicon", KStandardDirs::kde_default("data") +
 		appname + "/toolbar/");
 
@@ -260,6 +261,7 @@ void KIconLoader::addAppDir(const QString& appname)
 {
     d->mpDirs->addResourceType("appicon", KStandardDirs::kde_default("data") +
 		appname + "/pics/");
+    // ################## KDE4: consider removing the toolbar directory
     d->mpDirs->addResourceType("appicon", KStandardDirs::kde_default("data") +
 		appname + "/toolbar/");
     addAppThemes(appname);
@@ -837,6 +839,10 @@ QImage *KIconLoader::loadOverlay(const QString &name, int size) const
 	return 0L;
     }
     image = new QImage(icon.path);
+    // In some cases (since size in findMatchingIcon() is more a hint than a
+    // constraint) image->size can be != size. If so perform rescaling.
+    if ( size != image->width() )
+        *image = image->smoothScale( size, size );
     d->imgDict.insert(key, image);
     return image;
 }
@@ -1017,6 +1023,7 @@ QStringList KIconLoader::queryIconsByContext(int group_or_size,
 	    name = *it;
 	else
 	    name = (*it).mid(n+1);
+	name = removeIconExtension(name);
 	if (!entries.contains(name))
 	{
 	    entries += name;
@@ -1056,6 +1063,7 @@ QStringList KIconLoader::queryIcons(int group_or_size, KIcon::Context context) c
 	    name = *it;
 	else
 	    name = (*it).mid(n+1);
+	name = removeIconExtension(name);
 	if (!entries.contains(name))
 	{
 	    entries += name;
