@@ -21,12 +21,6 @@
 #include <X11/Xutil.h>
 #include <X11/keysymdef.h>
 
-#undef NONE
-
-#ifndef KeyPress // for --enable-final
-#define KeyPress XKeyPress
-#endif
-
 namespace KKeyServer
 {
 
@@ -101,6 +95,19 @@ static const SymName g_rgSymNames[] = {
 	{ XK_Scroll_Lock,  I18N_NOOP("ScrollLock") },
 	{ XK_Prior,        I18N_NOOP("PageUp") },
 	{ XK_Next,         I18N_NOOP("PageDown") },
+#ifdef sun
+	{ XK_F11,          I18N_NOOP("Stop") },
+	{ XK_F12,          I18N_NOOP("Again") },
+	{ XK_F13,          I18N_NOOP("Props") },
+	{ XK_F14,          I18N_NOOP("Undo") },
+	{ XK_F15,          I18N_NOOP("Front") },
+	{ XK_F16,          I18N_NOOP("Copy") },
+	{ XK_F17,          I18N_NOOP("Open") },
+	{ XK_F18,          I18N_NOOP("Paste") },
+	{ XK_F19,          I18N_NOOP("Find") },
+	{ XK_F20,          I18N_NOOP("Cut") },
+	{ XK_F22,          I18N_NOOP("Print") },
+#endif
 	{ 0, 0 }
 };
 
@@ -118,7 +125,11 @@ static const TransKey g_rgQtToSymX[] =
 	{ Qt::Key_Insert,     XK_Insert },
 	{ Qt::Key_Delete,     XK_Delete },
 	{ Qt::Key_Pause,      XK_Pause },
+#ifdef sun
+	{ Qt::Key_Print,      XK_F22 },
+#else
 	{ Qt::Key_Print,      XK_Print },
+#endif
 	{ Qt::Key_SysReq,     XK_Sys_Req },
 	{ Qt::Key_Home,       XK_Home },
 	{ Qt::Key_End,        XK_End },
@@ -280,10 +291,21 @@ bool initializeMods()
 
 	g_rgModInfo[3].modX = g_modXNumLock = g_modXScrollLock = 0;
 
+        int min_keycode, max_keycode;
+        int keysyms_per_keycode = 0;
+        XDisplayKeycodes( qt_xdisplay(), &min_keycode, &max_keycode );
+        XFree( XGetKeyboardMapping( qt_xdisplay(), min_keycode, 1, &keysyms_per_keycode ));
 	// Qt assumes that Alt is always Mod1Mask, so start at Mod2Mask.
 	for( int i = Mod2MapIndex; i < 8; i++ ) {
 		uint mask = (1 << i);
-		uint keySymX = XKeycodeToKeysym( qt_xdisplay(), xmk->modifiermap[xmk->max_keypermod * i], 0 );
+		uint keySymX = NoSymbol;
+                // This used to be only XKeycodeToKeysym( ... , 0 ), but that fails with XFree4.3.99
+                // and X.org R6.7 , where for some reason only ( ... , 1 ) works. I have absolutely no
+                // idea what the problem is, but searching all posibilities until something valid is
+                // found fixes the problem.
+                for( int j = 0; j < xmk->max_keypermod && keySymX == NoSymbol; ++j )
+                    for( int k = 0; k < keysyms_per_keycode && keySymX == NoSymbol; ++k )
+                        keySymX = XKeycodeToKeysym( qt_xdisplay(), xmk->modifiermap[xmk->max_keypermod * i + j], k );
 		switch( keySymX ) {
 			case XK_Num_Lock:    g_modXNumLock = mask; break;     // Normally Mod2Mask
 			case XK_Super_L:
@@ -361,6 +383,7 @@ bool Sym::initQt( int keyQt )
 
 bool Sym::init( const QString& s )
 {
+	// If it's a single character, get unicode value.
 	if( s.length() == 1 ) {
 		m_sym = s[0].lower().unicode();
 		return true;
@@ -406,10 +429,10 @@ int Sym::qt() const
 
 QString Sym::toString( bool bUserSpace ) const
 {
-	// If it's a unicode character,
 	if( m_sym == 0 )
 		return QString::null;
-		
+
+	// If it's a unicode character,
 	else if( m_sym < 0x3000 ) {
 		QChar c = QChar(m_sym).upper();
 		// Print all non-space characters directly when output is user-visible.
@@ -424,7 +447,7 @@ QString Sym::toString( bool bUserSpace ) const
 		if( m_sym == g_rgSymNames[i].sym )
 			return bUserSpace ? i18n(g_rgSymNames[i].psName) : QString(g_rgSymNames[i].psName);
 	}
-	
+
 	// Get X-name
 	QString s = XKeysymToString( m_sym );
 	capitalizeKeyname( s );
@@ -535,7 +558,7 @@ bool keyQtToMod( int keyQt, uint& mod )
 	if( keyQt & Qt::SHIFT )    mod |= KKey::SHIFT;
 	if( keyQt & Qt::CTRL )     mod |= KKey::CTRL;
 	if( keyQt & Qt::ALT )      mod |= KKey::ALT;
-	if( keyQt & (Qt::ALT<<1) ) mod |= KKey::WIN;
+	if( keyQt & Qt::META ) mod |= KKey::WIN;
 
 	return true;
 }
@@ -856,7 +879,6 @@ void Variations::init( const KKey& key, bool bQt )
 }
 
 } // end of namespace KKeyServer block
-#undef KeyPress
 
 // FIXME: This needs to be moved to kshortcut.cpp, and create a 
 //  KKeyServer::method which it will call.
