@@ -23,8 +23,6 @@
 #include <qfile.h>
 #include <qtimer.h>
 #include <qobjectdict.h>
-#include <qwidgetlist.h>
-#include <qwidget.h>
 
 #include "kapplication.h"
 #include "klibloader.h"
@@ -34,11 +32,6 @@
 
 #include "ltdl.h"
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#include <X11/Xlib.h> // schroder
-#include <X11/Xatom.h> // schroder
-#endif
-
 template class QAsciiDict<KLibrary>;
 
 #include <stdlib.h> //getenv
@@ -47,7 +40,7 @@ template class QAsciiDict<KLibrary>;
 #if HAVE_DLFCN_H
 #  include <dlfcn.h>
 #endif
- 
+
 #ifdef RTLD_GLOBAL
 #  define LT_GLOBAL             RTLD_GLOBAL
 #else
@@ -341,11 +334,9 @@ KLibLoader::~KLibLoader()
     d = 0L;
 }
 
-//static
-QString KLibLoader::findLibrary( const char * name, const KInstance * instance )
+static inline QCString makeLibName( const char* name )
 {
-    QCString libname( name );
-
+    QCString libname(name);
     // only append ".la" if there is no extension
     // this allows to load non-libtool libraries as well
     // (mhk, 20000228)
@@ -354,12 +345,19 @@ QString KLibLoader::findLibrary( const char * name, const KInstance * instance )
       pos = 0;
     if (libname.find('.', pos) < 0)
       libname += ".la";
+    return libname;
+}
+
+//static
+QString KLibLoader::findLibrary( const char * name, const KInstance * instance )
+{
+    QCString libname = makeLibName( name );
 
     // only look up the file if it is not an absolute filename
     // (mhk, 20000228)
     QString libfile;
     if (libname[0] == '/')
-      libfile = libname;
+      libfile = QFile::decodeName( libname );
     else
     {
       libfile = instance->dirs()->findResource( "module", libname );
@@ -371,15 +369,6 @@ QString KLibLoader::findLibrary( const char * name, const KInstance * instance )
           kdDebug(150) << "library " << libname << " not found under 'module' but under 'lib'" << endl;
 #endif
       }
-      if ( libfile.isEmpty() )
-      {
-#ifndef NDEBUG
-        kdDebug(150) << "library=" << libname << ": No file names " << libname.data() << " found in paths." << endl;
-#endif
-            self()->d->errorMessage = i18n("Library files for \"%1\" not found in paths").arg(libname); 
-      }
-      else
-            self()->d->errorMessage = QString::null;
     }
     return libfile;
 }
@@ -391,7 +380,7 @@ KLibrary *tmp;
 int olt_dlopen_flag = lt_dlopen_flag;
 
    lt_dlopen_flag |= LT_GLOBAL;
-   kdDebug(150) << "Loading the next library global with flag " 
+   kdDebug(150) << "Loading the next library global with flag "
                 << lt_dlopen_flag
                 << "." << endl;
    tmp = library(name);
@@ -431,7 +420,14 @@ KLibrary* KLibLoader::library( const char *name )
     } else {
       QString libfile = findLibrary( name );
       if ( libfile.isEmpty() )
+      {
+        const QCString libname = makeLibName( name );
+#ifndef NDEBUG
+        kdDebug(150) << "library=" << name << ": No file named " << libname << " found in paths." << endl;
+#endif
+        d->errorMessage = i18n("Library files for \"%1\" not found in paths.").arg(libname);
         return 0;
+      }
 
       lt_dlhandle handle = lt_dlopen( libfile.latin1() );
       if ( !handle )
@@ -550,8 +546,6 @@ void KLibLoader::close_pending(KLibWrapPrivate *wrap)
 
 //    kdDebug(150) << "try to dlclose " << wrap->name << ": yes, done." << endl;
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifndef Q_WS_QWS
     if ( !deleted_one ) {
       /* Only do the hack once in this loop.
          WABA: *HACK*
@@ -562,23 +556,15 @@ void KLibLoader::close_pending(KLibWrapPrivate *wrap)
 
       /* Well.. let's do something more subtle... convert the clipboard context
          to text. That should be safe as it only uses objects defined by Qt. */
-
-      QWidgetList *widgetlist = QApplication::topLevelWidgets();
-      QWidget *co = widgetlist->first();
-      while (co) {
-        if (qstrcmp(co->name(), "internal clipboard owner") == 0) {
-          if (XGetSelectionOwner(co->x11Display(), XA_PRIMARY) == co->winId())
-	    kapp->clipboard()->setText(kapp->clipboard()->text());
-
-          break;
-        }
-        co = widgetlist->next();
+      if( kapp->clipboard()->ownsSelection()) {
+	kapp->clipboard()->setText(
+            kapp->clipboard()->text( QClipboard::Selection ), QClipboard::Selection );
+      }
+      if( kapp->clipboard()->ownsClipboard()) {
+	kapp->clipboard()->setText(
+            kapp->clipboard()->text( QClipboard::Clipboard ), QClipboard::Clipboard );
       }
-      delete widgetlist;
     }
-#else
-    // FIXME(E): Implement in Qt Embedded
-#endif
 
     deleted_one = true;
     lt_dlclose(wrap->handle);
