@@ -51,11 +51,11 @@ class KLocalePrivate
 {
 public:
   int weekStartDay;
-  int plural_form;
   bool nounDeclension;
   bool dateMonthNamePossessive;
   QStringList languageList;
-  QValueList<KCatalogue> catalogues;
+  QStringList catalogNames; // list of all catalogs (regardless of language)
+  QValueList<KCatalogue> catalogues; // list of all loaded catalogs, contains one instance per catalog name and language
   QString encoding;
   QTextCodec * codecForEncoding;
   KConfig * config;
@@ -67,8 +67,8 @@ public:
 
   QString calendarType;
   KCalendarSystem * calendar;
-  QString first_language;
   bool utf8FileEncoding;
+  QString appName;
 };
 
 static KLocale *this_klocale = 0;
@@ -79,8 +79,8 @@ KLocale::KLocale( const QString & catalog, KConfig * config )
   d->config = config;
   d->languages = 0;
   d->calendar = 0;
+  d->formatInited = false;
 
-  initCatalogue(catalog);
   initEncoding(0);
   initFileNameEncoding(0);
 
@@ -89,9 +89,10 @@ KLocale::KLocale( const QString & catalog, KConfig * config )
   if (!cfg) cfg = KGlobal::instance()->config();
   this_klocale = 0;
   Q_ASSERT( cfg );
-
-  if (m_language.isEmpty())
-     initLanguage(cfg, config == 0);
+   
+  d->appName = catalog;
+  initLanguageList( cfg, config == 0);
+  initMainCatalogues(catalog);
 }
 
 QString KLocale::_initLanguage(KConfigBase *config)
@@ -99,13 +100,14 @@ QString KLocale::_initLanguage(KConfigBase *config)
   if (this_klocale)
   {
      // ### HPB Why this cast??
-     this_klocale->initLanguage((KConfig *) config, true);
+     this_klocale->initLanguageList((KConfig *) config, true);
+     // todo: adapt current catalog list: remove unused languages, insert main catalogs, if not already found
      return this_klocale->language();
   }
   return QString::null;
 }
 
-void KLocale::initCatalogue(const QString & catalog)
+void KLocale::initMainCatalogues(const QString & catalog)
 {
   // Use the first non-null string.
   QString mainCatalogue = catalog;
@@ -117,15 +119,16 @@ void KLocale::initCatalogue(const QString & catalog)
                  << "catalog! Give an argument or call setMainCatalogue "
                  << "before init" << endl;
   }
-  else
-    d->catalogues.append( KCatalogue(mainCatalogue ) );
-
-  // always include kdelibs's mo files
-  d->catalogues.append( KCatalogue( SYSTEM_MESSAGES ) );
-  d->catalogues.append( KCatalogue( "kio" ) );
+  else {
+    // do not use insertCatalogue here, that would already trigger updateCatalogs
+    d->catalogNames.append( mainCatalogue );   // application catalog
+    d->catalogNames.append( SYSTEM_MESSAGES ); // always include kdelibs.mo
+    d->catalogNames.append( "kio" );            // always include kio.mo
+    updateCatalogues(); // evaluate this for all languages
+  }
 }
 
-void KLocale::initLanguage(KConfig * config, bool useEnv)
+void KLocale::initLanguageList(KConfig * config, bool useEnv)
 {
   KConfigGroupSaver saver(config, "Locale");
 
@@ -150,7 +153,6 @@ void KLocale::initLanguage(KConfig * config, bool useEnv)
       langs << QFile::decodeName( ::getenv("LC_ALL") );
       langs << QFile::decodeName( ::getenv("LC_MESSAGES") );
       langs << QFile::decodeName( ::getenv("LANG") );
-      langs << QFile::decodeName( ::getenv("LC_CTYPE") );
 
       for ( QStringList::Iterator it = langs.begin();
 	    it != langs.end();
@@ -175,58 +177,77 @@ void KLocale::initLanguage(KConfig * config, bool useEnv)
   setLanguage( languageList );
 }
 
-void KLocale::doBindInit()
+void KLocale::initPluralTypes()
 {
   for ( QValueList<KCatalogue>::Iterator it = d->catalogues.begin();
-	it != d->catalogues.end();
-	++it )
-    initCatalogue( *it );
+    it != d->catalogues.end();
+    ++it )
+  {
+    QString language = (*it).language();
+    int pt = pluralType( language );
+    (*it).setPluralType( pt );
+  }
+}
 
-  if ( useDefaultLanguage() )
-    d->plural_form = -1;
-  else
-    {
-      QString pf = translate_priv
-	( I18N_NOOP("_: Dear translator, please do not translate this string "
-		    "in any form, but pick the _right_ value out of "
-		    "NoPlural/TwoForms/French... If not sure what to do mail "
-		    "thd@kde.org and coolo@kde.org, they will tell you. "
-		    "Better leave that out if unsure, the programs will "
-		    "crash!!\nDefinition of PluralForm - to be set by the "
-		    "translator of kdelibs.po"), 0);
-      if ( pf.isEmpty() ) {
-	kdWarning(173) << "found no definition of PluralForm for " << m_language << endl;
-	d->plural_form = -1;
-      } else if ( pf == "NoPlural" )
-	d->plural_form = 0;
-      else if ( pf == "TwoForms" )
-	d->plural_form = 1;
-      else if ( pf == "French" )
-	d->plural_form = 2;
-      else if ( pf == "OneTwoRest" || pf == "Gaeilge" ) // Gaelige is the old name
-	d->plural_form = 3;
-      else if ( pf == "Russian" )
-	d->plural_form = 4;
-      else if ( pf == "Polish" )
-	d->plural_form = 5;
-      else if ( pf == "Slovenian" )
-	d->plural_form = 6;
-      else if ( pf == "Lithuanian" )
-	d->plural_form = 7;
-      else if ( pf == "Czech" )
-	d->plural_form = 8;
-      else if ( pf == "Slovak" )
-	d->plural_form = 9;
-      else if ( pf == "Maltese" )
-	d->plural_form = 10;
-      else if ( pf == "Arabic" )
-	d->plural_form = 11;
-      else if ( pf == "Balcan" )
-	d->plural_form = 12;
-      else if ( pf == "Macedonian" )
-	d->plural_form = 13;
-      else {
-	kdWarning(173) << "Definition of PluralForm is none of "
+
+int KLocale::pluralType( const QString & language )
+{
+  for ( QValueList<KCatalogue>::ConstIterator it = d->catalogues.begin();
+    it != d->catalogues.end();
+    ++it )
+  {
+    if ( ((*it).name() == SYSTEM_MESSAGES ) && ((*it).language() == language )) {
+      return pluralType( *it );
+    }
+  }
+  // kdelibs.mo does not seem to exist for this language
+  return -1;
+}
+
+int KLocale::pluralType( const KCatalogue& catalog )
+{
+    const char* pluralFormString =
+    I18N_NOOP("_: Dear translator, please do not translate this string "
+      "in any form, but pick the _right_ value out of "
+      "NoPlural/TwoForms/French... If not sure what to do mail "
+      "thd@kde.org and coolo@kde.org, they will tell you. "
+      "Better leave that out if unsure, the programs will "
+      "crash!!\nDefinition of PluralForm - to be set by the "
+      "translator of kdelibs.po");
+    QString pf (catalog.translate( pluralFormString));
+    if ( pf.isEmpty() ) {
+      return -1;
+    }
+	else if ( pf == "NoPlural" )
+      return 0;
+    else if ( pf == "TwoForms" )
+      return 1;
+    else if ( pf == "French" )
+      return 2;
+    else if ( pf == "OneTwoRest" || pf == "Gaeilge" ) // Gaelige is the old name
+      return 3;
+    else if ( pf == "Russian" )
+      return 4;
+    else if ( pf == "Polish" )
+      return 5;
+    else if ( pf == "Slovenian" )
+      return 6;
+    else if ( pf == "Lithuanian" )
+      return 7;
+    else if ( pf == "Czech" )
+      return 8;
+    else if ( pf == "Slovak" )
+      return 9;
+    else if ( pf == "Maltese" )
+      return 10;
+    else if ( pf == "Arabic" )
+      return 11;
+    else if ( pf == "Balcan" )
+      return 12;
+    else if ( pf == "Macedonian" )
+      return 13;
+    else {
+      kdWarning(173) << "Definition of PluralForm is none of "
 		       << "NoPlural/"
 		       << "TwoForms/"
 		       << "French/"
@@ -241,11 +262,8 @@ void KLocale::doBindInit()
 		       << "Balcan/"
 		       << "Macedonian/"
 		       << "Maltese: " << pf << endl;
-	exit(1);
-      }
+      exit(1);
     }
-
-  d->formatInited = false;
 }
 
 void KLocale::doFormatInit() const
@@ -317,15 +335,11 @@ void KLocale::initFormat()
   readConfigNumEntry("NegativeMonetarySignPosition", (int)ParensAround,
 		     m_negativeMonetarySignPosition, SignPosition);
 
-  //Grammatical
-  readConfigBoolEntry("NounDeclension", false, d->nounDeclension);
 
   // Date and time
   readConfigEntry("TimeFormat", "%H:%M:%S", m_timeFormat);
   readConfigEntry("DateFormat", "%A %d %B %Y", m_dateFormat);
   readConfigEntry("DateFormatShort", "%Y-%m-%d", m_dateFormatShort);
-  readConfigBoolEntry("DateMonthNamePossessive", false,
-		      d->dateMonthNamePossessive);
   readConfigNumEntry("WeekStartDay", 1, d->weekStartDay, int);
 
   // other
@@ -336,6 +350,21 @@ void KLocale::initFormat()
   delete d->calendar;
   d->calendar = 0; // ### HPB Is this the correct place?
 
+  //Grammatical
+  //Precedence here is l10n / i18n / config file
+  KSimpleConfig language(locate("locale",
+			        QString::fromLatin1("%1/entry.desktop")
+                                .arg(m_language)), true);
+  language.setGroup("KCM Locale");
+#define read3ConfigBoolEntry(key, default, save) \
+  save = entry.readBoolEntry(key, default); \
+  save = language.readBoolEntry(key, save); \
+  save = config->readBoolEntry(key, save);
+
+  read3ConfigBoolEntry("NounDeclension", false, d->nounDeclension);
+  read3ConfigBoolEntry("DateMonthNamePossessive", false,
+		       d->dateMonthNamePossessive);
+
   // end of hack
   KGlobal::_locale = lsave;
 }
@@ -363,73 +392,104 @@ QString KLocale::catalogueFileName(const QString & language,
   return locate( "locale", path );
 }
 
-bool KLocale::isLanguageInstalled(const QString & language) const
-{
-  // Do not allow empty languages
-  if ( language.isEmpty() ) return false;
-
-  bool bRes = true;
-  if ( language != defaultLanguage() )
-    for ( QValueList<KCatalogue>::ConstIterator it = d->catalogues.begin();
-	  it != d->catalogues.end() && bRes;
-	  ++it )
-      {
-	bRes = !catalogueFileName( language, *it ).isNull();
-        if ( !bRes )
-	  kdDebug(173) << "message catalog not found: "
-		       << (*it).name() << endl;
-      }
-
-  return bRes;
-}
-
 bool KLocale::setLanguage(const QString & language)
 {
-  bool bRes = true;
+  if ( d->languageList.contains( language ) ) {
+ 	 d->languageList.remove( language );
+  }
+  d->languageList.prepend( language ); // let us consider this language to be the most important one
 
-  if (d->first_language.isNull() || language != d->first_language)
-    bRes = isLanguageInstalled( language );
+  m_language = language; // remember main language for shortcut evaluation
 
-  if ( bRes )
-    {
-      m_language = language;
+  // important when called from the outside and harmless when called before populating the
+  // catalog name list
+  updateCatalogues();
 
-      // remember our first time - it will be our true love
-      if (d->first_language.isNull())
-        d->first_language = language;
+  d->formatInited = false;
 
-      doBindInit();
-    }
-
-  return bRes;
+  return true; // Maybe the mo-files for this language are empty, but in principle we can speak all languages
 }
 
 bool KLocale::setLanguage(const QStringList & languages)
 {
-  QStringList languageList(languages);
-
-  // Remove duplicate entries in reverse so that we
-  // can keep user's language preference order intact. (DA)
+  QStringList languageList( languages );
+  // This list might contain 
+  // 1) some empty strings that we have to eliminate
+  // 2) duplicate entries like in de:fr:de, where we have to keep the first occurrance of a language in order 
+  //    to preserve the order of precenence of the user => iterate backwards
+  // 3) languages into which the application is not translated. For those languages we should not even load kdelibs.mo or kio.po.
+  //    these langugage have to be dropped. Otherwise we get strange side effects, e.g. with Hebrew:
+  //    the right/left switch for languages that write from 
+  //    right to left (like Hebrew or Arabic) is set in kdelibs.mo. If you only have kdelibs.mo
+  //    but nothing from appname.mo, you get a mostly English app with layout from right to left.
+  //    That was considered to be a bug by the Hebrew translators.
   for( QStringList::Iterator it = languageList.fromLast();
-         it != languageList.begin();
-         --it )
-    if ( languageList.contains(*it) > 1 || (*it).isEmpty() )
+    it != languageList.begin(); --it )
+  {
+    // kdDebug() << "checking " << (*it) << endl;
+    bool bIsTranslated = isApplicationTranslatedInto( *it );
+    if ( languageList.contains(*it) > 1 || (*it).isEmpty() || (!bIsTranslated) ) {
+      // kdDebug() << "removing " << (*it) << endl;
       it = languageList.remove( it );
+    }
+  }
+  // now this has left the first element of the list unchecked. 
+  // The question why this is the case is left as an exercise for the reader...
+  // Besides the list might have been empty all the way, so check that too.
+  if ( languageList.begin() != languageList.end() ) { 
+     QStringList::Iterator it = languageList.begin(); // now pointing to the first element
+     // kdDebug() << "checking " << (*it) << endl;
+     if( (*it).isEmpty() || !(isApplicationTranslatedInto( *it )) ) {
+        // kdDebug() << "removing " << (*it) << endl;
+     	languageList.remove( it ); // that's what the iterator was for...
+     }
+  }
 
-  bool bRes = false;
-  for ( QStringList::ConstIterator it = languageList.begin();
-	it != languageList.end();
-	++it )
-    if ( bRes = setLanguage( *it ) )
-      break;
+  if ( languageList.isEmpty() ) {
+	// user picked no language, so we assume he/she speaks English.
+	languageList.append( defaultLanguage() );
+  }
+  m_language = languageList.first(); // keep this for shortcut evaluations
 
-  if ( !bRes )
-    setLanguage(defaultLanguage());
-
-  d->languageList = languageList;
+  d->languageList = languageList; // keep this new list of languages to use
   d->langTwoAlpha.clear(); // Flush cache
 
-  return bRes;
+  // important when called from the outside and harmless when called before populating the
+  // catalog name list
+  updateCatalogues();
+
+  return true; // we found something. Maybe it's only English, but we found something
+}
+
+bool KLocale::isApplicationTranslatedInto( const QString & language)
+{
+  if ( language.isEmpty() ) {
+    return false;
+  }
+  
+  if ( language == defaultLanguage() ) {
+    // en_us is always "installed"
+    return true;
+  }
+  
+  QString appName = d->appName;
+  if (maincatalogue) {
+    appName = QString::fromLatin1(maincatalogue);
+  }
+  // sorry, catalogueFileName requires catalog object,k which we do not have here
+  // path finding was supposed to be moved completely to KCatalogue. The interface cannot
+  // be changed that far during deep freeze. So in order to fix the bug now, we have
+  // duplicated code for file path evaluation. Cleanup will follow later. We could have e.g.
+  // a static method in KCataloge that can translate between these file names.
+  // a stat
+  QString sFileName = QString::fromLatin1("%1/LC_MESSAGES/%2.mo")
+    .arg( language )
+    .arg( appName );
+  // kdDebug() << "isApplicationTranslatedInto: filename " << sFileName << endl;
+
+  QString sAbsFileName = locate( "locale", sFileName );
+  // kdDebug() << "isApplicationTranslatedInto: absname " << sAbsFileName << endl;
+  return ! sAbsFileName.isEmpty();
 }
 
 void KLocale::splitLocale(const QString & aStr,
@@ -553,62 +613,74 @@ QString KLocale::monthNamePossessive(int i, bool shortName) const
 
 QString KLocale::weekDayName (int i, bool shortName) const
 {
-  if ( shortName )
-    switch ( i )
-      {
-      case 1:  return translate("Monday", "Mon");
-      case 2:  return translate("Tuesday", "Tue");
-      case 3:  return translate("Wednesday", "Wed");
-      case 4:  return translate("Thursday", "Thu");
-      case 5:  return translate("Friday", "Fri");
-      case 6:  return translate("Saturday", "Sat");
-      case 7:  return translate("Sunday", "Sun");
-      }
-  else
-    switch ( i )
-      {
-      case 1:  return translate("Monday");
-      case 2:  return translate("Tuesday");
-      case 3:  return translate("Wednesday");
-      case 4:  return translate("Thursday");
-      case 5:  return translate("Friday");
-      case 6:  return translate("Saturday");
-      case 7:  return translate("Sunday");
-      }
-
-  return QString::null;
+  return calendar()->weekDayName(i, shortName);
 }
 
 void KLocale::insertCatalogue( const QString & catalog )
 {
-  KCatalogue cat( catalog );
-
-  initCatalogue( cat );
-
-  d->catalogues.append( cat );
+  if ( !d->catalogNames.contains( catalog) ) {
+    d->catalogNames.append( catalog );
+  }
+  updateCatalogues( ); // evaluate the changed list and generate the neccessary KCatalog objects
 }
 
+void KLocale::updateCatalogues( )
+{
+  // some changes have occured. Maybe we have learned or forgotten some languages.
+  // Maybe the language precedence has changed.
+  // Maybe we have learned or forgotten some catalog names.
+  // Now examine the list of KCatalogue objects and change it according to the new circumstances.
+
+  // this could be optimized: try to reuse old KCatalog objects, but remember that the order of
+  // catalogs might have changed: e.g. in this fashion
+  // 1) move all catalogs into a temporary list
+  // 2) iterate over all languages and catalog names
+  // 3.1) pick the catalog from the saved list, if it already exists
+  // 3.2) else create a new catalog.
+  // but we will do this later.
+
+  for ( QValueList<KCatalogue>::Iterator it = d->catalogues.begin();
+	it != d->catalogues.end(); )
+  {
+     it = d->catalogues.remove(it);
+  }
+
+  // now iterate over all languages and all wanted catalog names and append or create them in the right order
+  // the sequence must be e.g. nds/appname nds/kdelibs nds/kio de/appname de/kdelibs de/kio etc.
+  // and not nds/appname de/appname nds/kdelibs de/kdelibs etc. Otherwise we would be in trouble with a language
+  // sequende nds,en_US, de. In this case en_US must hide everything below in the language list.
+  for ( QStringList::ConstIterator itLangs =  d->languageList.begin();
+	  itLangs != d->languageList.end(); ++itLangs)
+  {
+    for ( QStringList::ConstIterator itNames =  d->catalogNames.begin();
+	itNames != d->catalogNames.end(); ++itNames)
+    {
+      KCatalogue cat( *itNames, *itLangs ); // create Catalog for this name and this language
+      d->catalogues.append( cat );
+	}
+  }
+  initPluralTypes();  // evaluate the plural type for all languages and remember this in each KCatalogue
+}
+
+
+
+
 void KLocale::removeCatalogue(const QString &catalog)
 {
-  for ( QValueList<KCatalogue>::Iterator it = d->catalogues.begin();
-	it != d->catalogues.end(); )
-    if ((*it).name() == catalog) {
-      it = d->catalogues.remove(it);
-      return;
-    } else
-      ++it;
+  if ( d->catalogNames.contains( catalog )) {
+    d->catalogNames.remove( catalog );
+    if (KGlobal::_instance)
+      updateCatalogues();  // walk through the KCatalogue instances and weed out everything we no longer need
+  }
 }
 
 void KLocale::setActiveCatalogue(const QString &catalog)
 {
-  for ( QValueList<KCatalogue>::Iterator it = d->catalogues.begin();
-	it != d->catalogues.end(); ++it)
-    if ((*it).name() == catalog) {
-      KCatalogue save = *it;
-      d->catalogues.remove(it);
-      d->catalogues.prepend(save);
-      return;
-    }
+  if ( d->catalogNames.contains( catalog ) ) {
+    d->catalogNames.remove( catalog );
+	d->catalogNames.prepend( catalog );
+	updateCatalogues();  // walk through the KCatalogue instances and adapt to the new order
+  }
 }
 
 KLocale::~KLocale()
@@ -621,8 +693,12 @@ KLocale::~KLocale()
 
 QString KLocale::translate_priv(const char *msgid,
 				const char *fallback,
-				const char **translated) const
+				const char **translated,
+				int* pluralType ) const
 {
+  if ( pluralType) {
+  	*pluralType = -1; // unless we find something more precise
+  }
   if (!msgid || !msgid[0])
     {
       kdWarning() << "KLocale: trying to look up \"\" in catalog. "
@@ -630,21 +706,32 @@ QString KLocale::translate_priv(const char *msgid,
       return QString::null;
     }
 
-  if ( useDefaultLanguage() )
+  if ( useDefaultLanguage() ) { // shortcut evaluation if en_US is main language: do not consult the catalogs
     return QString::fromUtf8( fallback );
+  }
 
   for ( QValueList<KCatalogue>::ConstIterator it = d->catalogues.begin();
 	it != d->catalogues.end();
 	++it )
     {
-      // kdDebug(173) << "translate " << msgid << " " << (*it).name() << " " << (!KGlobal::activeInstance() ? QCString("no instance") : KGlobal::activeInstance()->instanceName()) << endl;
+	  // shortcut evaluation: once we have arrived at en_US (default language) we cannot consult
+	  // the catalog as it will not have an assiciated mo-file. For this default language we can
+	  // immediately pick the fallback string.
+	  if ( (*it).language() == defaultLanguage() ) {
+	  	return QString::fromUtf8( fallback );
+	  }
+
       const char * text = (*it).translate( msgid );
 
       if ( text )
 	{
 	  // we found it
-	  if (translated)
+	  if (translated) {
 	    *translated = text;
+	  }
+	  if ( pluralType) {
+	  	*pluralType = (*it).pluralType(); // remember the plural type information from the catalog that was used
+	  }
 	  return QString::fromUtf8( text );
 	}
     }
@@ -707,17 +794,18 @@ QString KLocale::translate( const char *singular, const char *plural,
   char *newstring = new char[strlen(singular) + strlen(plural) + 6];
   sprintf(newstring, "_n: %s\n%s", singular, plural);
   // as copying QString is very fast, it looks slower as it is ;/
-  QString r = translate_priv(newstring, 0);
+  int pluralType = -1;
+  QString r = translate_priv(newstring, 0, 0, &pluralType);
   delete [] newstring;
 
-  if ( r.isEmpty() || useDefaultLanguage() || d->plural_form == -1) {
+  if ( r.isEmpty() || useDefaultLanguage() || pluralType == -1) {
     if ( n == 1 ) {
       return put_n_in( QString::fromUtf8( singular ),  n );
 	} else {
 	  QString tmp = QString::fromUtf8( plural );
 #ifndef NDEBUG
 	  if (tmp.find("%n") == -1) {
-			  kdWarning() << "the message for i18n should contain a '%n'! " << plural << endl;
+			  kdDebug() << "the message for i18n should contain a '%n'! " << plural << endl;
 	  }
 #endif
       return put_n_in( tmp,  n );
@@ -725,7 +813,7 @@ QString KLocale::translate( const char *singular, const char *plural,
   }
 
   QStringList forms = QStringList::split( "\n", r, false );
-  switch ( d->plural_form ) {
+  switch ( pluralType ) {
   case 0: // NoPlural
     EXPECT_LENGTH( 1 );
     return put_n_in( forms[0], n);
@@ -1367,7 +1455,7 @@ QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) con
   uint strpos = 0;
   uint fmtpos = 0;
 
-  int iLength; // Temperary variable used when reading input
+  int iLength; // Temporary variable used when reading input
 
   bool error = false;
 
@@ -1459,16 +1547,6 @@ QDate KLocale::readDate(const QString &intstr, const QString &fmt, bool* ok) con
 	  strpos += iLength;
 
 	  error = iLength <= 0;
-
-	  // ### HPB: This should be moved to the implemtnation classes of KCalendarSystem
-	  // Qt treats a year in the range 0-100 as 1900-1999.
-	  // It is nicer for the user if we treat 0-68 as 2000-2068
-	  //if (c == 'y' && year < 69)
-	    // eg. gregorian += 2000
-	  //  year += (calendar()->year(QDate::currentDate()) / 100) * 100;
-	  //else if (c == 'y' && year < 100)
-	    // eg. gregorian += 1900
-	  //  year += (calendar()->year(QDate::currentDate()) / 100) * 100 - 100;
 	  break;
       }
     }
@@ -1612,7 +1690,13 @@ QTime KLocale::readTime(const QString &intstr, ReadTimeFlags flags, bool *ok) co
   return QTime(-1, -1, -1); // return invalid date if it didn't work
 }
 
+//BIC: merge with below
 QString KLocale::formatTime(const QTime &pTime, bool includeSecs) const
+{
+  return formatTime( pTime, includeSecs, false );
+}
+
+QString KLocale::formatTime(const QTime &pTime, bool includeSecs, bool isDuration) const
 {
   const QString rst = timeFormat();
 
@@ -1644,7 +1728,10 @@ QString KLocale::formatTime(const QTime &pTime, bool includeSecs) const
 	      put_it_in( buffer, index, pTime.hour() );
 	      break;
 	    case 'I':
-	      put_it_in( buffer, index, ( pTime.hour() + 11) % 12 + 1 );
+	      if ( isDuration )
+	          put_it_in( buffer, index, pTime.hour() );
+	      else
+	          put_it_in( buffer, index, ( pTime.hour() + 11) % 12 + 1 );
 	      break;
 	    case 'M':
 	      put_it_in( buffer, index, pTime.minute() );
@@ -1665,20 +1752,21 @@ QString KLocale::formatTime(const QTime &pTime, bool includeSecs) const
 	    case 'l':
 	      // to share the code
 	      if ( rst.at( format_index ).unicode() == 'l' )
-		number = (pTime.hour() + 11) % 12 + 1;
+		number = isDuration ? pTime.hour() : (pTime.hour() + 11) % 12 + 1;
 	      if ( number / 10 )
 		buffer[index++] = number / 10 + '0';
 	      buffer[index++] = number % 10 + '0';
 	      break;
 	    case 'p':
+	      if ( !isDuration )
 	      {
 		QString s;
 		if ( pTime.hour() >= 12 )
 		  put_it_in( buffer, index, translate("pm") );
 		else
 		  put_it_in( buffer, index, translate("am") );
-		break;
 	      }
+	      break;
 	    default:
 	      buffer[index++] = rst.at( format_index );
 	      break;
@@ -1688,7 +1776,10 @@ QString KLocale::formatTime(const QTime &pTime, bool includeSecs) const
     }
   QString ret( buffer, index );
   delete [] buffer;
-  return ret;
+  if ( isDuration ) // eliminate trailing-space due to " %p"
+    return ret.stripWhiteSpace();
+  else
+    return ret;
 }
 
 bool KLocale::use12Clock() const
@@ -1839,11 +1930,6 @@ QString KLocale::decodeFileNameUTF8( const QCString & localFileName )
   return QString::fromUtf8(localFileName);
 }
 
-void KLocale::initCatalogue( KCatalogue & catalog )
-{
-  catalog.setFileName( catalogueFileName( language(), catalog ) );
-}
-
 void KLocale::setDateFormat(const QString & format)
 {
   doFormatInit();
@@ -2097,7 +2183,11 @@ QString KLocale::twoAlphaToLanguageName(const QString &code) const
   if (!d->languages)
     d->languages = new KConfig("all_languages", true, false, "locale");
 
-  d->languages->setGroup(code.lower());
+  QString groupName = code;
+  const int i = groupName.find('_');
+  groupName.replace(0, i, groupName.left(i).lower());
+
+  d->languages->setGroup(groupName);
   return d->languages->readEntry("Name");
 }
 
