@@ -1,6 +1,6 @@
 /*
 
-   $Id: kprocess.cpp,v 1.130.2.1 2004/01/19 13:01:23 waba Exp $
+   $Id: kprocess.cpp,v 1.131.4.1 2004/10/13 20:07:23 ossi Exp $
 
    This file is part of the KDE libraries
    Copyright (C) 1997 Christian Czezatke (e9025461@student.tuwien.ac.at)
@@ -739,7 +739,25 @@ void KProcess::slotSendData(int)
 void KProcess::setUseShell(bool useShell, const char *shell)
 {
   d->useShell = useShell;
-  d->shell = (shell && *shell) ? shell : "/bin/sh";
+  if (shell && *shell)
+    d->shell = shell;
+  else
+// #ifdef NON_FREE // ... as they ship non-POSIX /bin/sh
+#if !defined(__linux__) && !defined(__FreeBSD__) && !defined(__NetBSD__) && !defined(__OpenBSD__) && !defined(__GNU__)
+  // Solaris POSIX ...
+  if (!access( "/usr/xpg4/bin/sh", X_OK ))
+    d->shell = "/usr/xpg4/bin/sh";
+  else
+  // ... which links here anyway
+  if (!access( "/bin/ksh", X_OK ))
+    d->shell = "/bin/ksh";
+  else
+  // dunno, maybe superfluous?
+  if (!access( "/usr/ucb/sh", X_OK ))
+    d->shell = "/usr/ucb/sh";
+  else
+#endif
+    d->shell = "/bin/sh";
 }
 
 void KProcess::setUsePty(Communication usePty, bool addUtmp)
