@@ -31,7 +31,7 @@ class KRootPropPrivate;
 /**
 * Access KDE desktop resources stored on the root window.
 *
-* A companion to the @ref KConfig class.
+* A companion to the KConfig class.
 *
 * The KRootProp class is used for reading and writing configuration entries
 * to properties on the root window.
@@ -40,7 +40,7 @@ class KRootPropPrivate;
 *
 * @see  KConfig::KConfig
 * @author Mark Donohoe (donohe@kde.org)
-* @version $Id: krootprop.h,v 1.20 2002/09/19 20:05:11 tjansen Exp $
+* @version $Id: krootprop.h,v 1.24 2003/09/06 19:06:30 binner Exp $
 */
 class KRootProp
 {
@@ -70,7 +70,7 @@ public:
    * Sets the property in which keys will be searched.
    * @param rProp the property that will be searched
    **/	
-   void setProp(const QString& rProp="");
+   void setProp(const QString& rProp=QString());
    /**
     * Returns the name of the property under which keys are searched.
     * @return the property that will be searched
@@ -109,7 +109,7 @@ public:
  int readNumEntry( const QString& rKey, int nDefault = 0 ) const;
  
  /**
-  * Reads a @ref QFont value.
+  * Reads a QFont value.
   *
   * Reads the value of an entry specified by @p rKey in the current property
   * and interpret it as a font object.
@@ -122,7 +122,7 @@ public:
 		      const QFont* pDefault = 0 ) const;
  
  /**
-  * Reads a @ref QColor.
+  * Reads a QColor.
   *
   * Reads the value of an entry specified by @p rKey in the current property
   * and interprets it as a color.
@@ -140,14 +140,14 @@ public:
   * Writes a (key/value) pair.
   *
   * This is stored to the current property when destroying the
-  * config object or when calling @ref sync().
+  * config object or when calling sync().
   *
   * @param rKey		The key to write.
   * @param rValue		The value to write.
   * @return The old value for this key. If this key did not exist,
-  *	  a null string is returned.	
+  *	  a null string is returned.
   *
-  **/				
+  **/
  QString writeEntry( const QString& rKey, const QString& rValue );
 
  /**
@@ -156,7 +156,7 @@ public:
   * @param rKey The key to write.
   * @param nValue The value to write.
   * @return The old value for this key. If this key did not
-  * exist, a null string is returned.	
+  * exist, a null string is returned.
   **/
  QString writeEntry( const QString& rKey, int nValue );
 
@@ -164,22 +164,22 @@ public:
   * Writes the (key/value) pair.
   * Same as above, but writes a font.
   * @param rKey The key to write.
-  * @param rValue The value to write.
+  * @param rFont The font to write.
   * @return The old value for this key. If this key did not
-  * exist, a null string is returned.	
+  * exist, a null string is returned.
   **/
   QString writeEntry( const QString& rKey, const QFont& rFont );
- 
+
   /**
    * Writes the (key/value) pair.
    * Same as above, but writes a color.
    * @param rKey The key to write.
-   * @param rValue The value to write.
+   * @param rColor The color to write.
    * @return The old value for this key. If this key did not
-   *  exist, a null string is returned.	
+   *  exist, a null string is returned.
    **/
   QString writeEntry( const QString& rKey, const QColor& rColor );
-  
+
   /**
    * Removes an entry.
    * @param rKey The key to remove.
@@ -190,7 +190,7 @@ public:
 
   /**
    * Returns a list of all keys.
-   * @return A @ref QStringList containing all the keys.
+   * @return A QStringList containing all the keys.
    **/
   QStringList listEntries() const;
 
@@ -198,7 +198,7 @@ public:
    * Flushes the entry cache.
    * Writes back dirty configuration entries to the current property,
    * This is called automatically from the destructor.
-   **/	
+   **/
   void sync();
 };
 
