@@ -19,12 +19,14 @@
 
 #include <config.h>
 
+#include <stdlib.h>
 #include <sys/types.h>
 
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
 
+#include <sys/param.h>
 #include <unistd.h>
 #include <fcntl.h>
 
@@ -37,20 +39,28 @@
 
 #include "kapplication.h"
 #include "ksavefile.h"
+#include "kstandarddirs.h"
+
+static QString realFilePath(const QString &filename)
+{
+    char realpath_buffer[MAXPATHLEN + 1];
+    memset(realpath_buffer, 0, MAXPATHLEN + 1);
+
+    /* If the path contains symlinks, get the real name */
+    if (realpath( QFile::encodeName(filename).data(), realpath_buffer) != 0) {
+        // succes, use result from realpath
+        return QFile::decodeName(realpath_buffer);
+    }
+
+    return filename;
+}
+
 
 KSaveFile::KSaveFile(const QString &filename, int mode)
  : mTempFile(true)
 {
-
    // follow symbolic link, if any
-   QString real_filename = filename;
-
-   QFileInfo file_info(real_filename);
-   int c=0;
-   while(file_info.isSymLink() && ++c<6) {
-     real_filename = file_info.readLink();
-      file_info.setFile( real_filename );
-   }
+   QString real_filename = realFilePath(filename);
 
    // we only check here if the directory can be written to
    // the actual filename isn't written to, but replaced later
@@ -69,11 +79,23 @@ KSaveFile::KSaveFile(const QString &filename, int mode)
       // permissions are the same as existing file so the existing
       // file's permissions are preserved
       struct stat stat_buf;
-      if ((stat(QFile::encodeName(real_filename), &stat_buf)==0)
-          && (stat_buf.st_uid == getuid())
-          && (stat_buf.st_gid == getgid()))
+      if (stat(QFile::encodeName(real_filename), &stat_buf)==0)
       {
-         fchmod(mTempFile.handle() , stat_buf.st_mode);
+         // But only if we own the existing file
+         if (stat_buf.st_uid == getuid())
+         {
+            bool changePermission = true;
+            if (stat_buf.st_gid != getgid())
+            {
+               if (fchown(mTempFile.handle(), (uid_t) -1, stat_buf.st_gid) != 0)
+               {
+                  // Use standard permission if we can't set the group
+                  changePermission = false;
+               }
+            }
+            if (changePermission)
+               fchmod(mTempFile.handle(), stat_buf.st_mode);
+         }
       }
    }
    return;
@@ -103,6 +125,11 @@ KSaveFile::close()
 {
    if (mTempFile.name().isEmpty())
       return false; // Save was aborted already
+   if (!mTempFile.sync())
+   {
+      abort();
+      return false;
+   }
    if (mTempFile.close())
    {
       QDir dir;
