@@ -20,7 +20,7 @@
 
 /*
  * Author: Stephan Kulow <coolo@kde.org> and Sirtaj Singh Kang <taj@kde.org>
- * Version:	$Id: kstandarddirs.cpp,v 1.168.2.2 2004/05/21 11:07:18 waba Exp $
+ * Version:	$Id: kstandarddirs.cpp,v 1.182.2.4 2004/09/13 13:04:15 waba Exp $
  * Generated:	Thu Mar  5 16:05:28 EST 1998
  */
 
@@ -51,6 +51,7 @@
 #include "kinstance.h"
 #include "kshell.h"
 #include "ksimpleconfig.h"
+#include "kuser.h"
 #include <sys/param.h>
 #include <unistd.h>
 
@@ -161,7 +162,7 @@ void KStandardDirs::addPrefix( const QString& _dir )
 
 void KStandardDirs::addPrefix( const QString& _dir, bool priority )
 {
-    if (_dir.isNull())
+    if (_dir.isEmpty())
 	return;
 
     QString dir = _dir;
@@ -181,7 +182,7 @@ void KStandardDirs::addXdgConfigPrefix( const QString& _dir )
 
 void KStandardDirs::addXdgConfigPrefix( const QString& _dir, bool priority )
 {
-    if (_dir.isNull())
+    if (_dir.isEmpty())
 	return;
 
     QString dir = _dir;
@@ -201,7 +202,7 @@ void KStandardDirs::addXdgDataPrefix( const QString& _dir )
 
 void KStandardDirs::addXdgDataPrefix( const QString& _dir, bool priority )
 {
-    if (_dir.isNull())
+    if (_dir.isEmpty())
 	return;
 
     QString dir = _dir;
@@ -224,12 +225,11 @@ bool KStandardDirs::addResourceType( const char *type,
 {
     return addResourceType(type, relativename, true);
 }
-
 bool KStandardDirs::addResourceType( const char *type,
-                                     const QString& relativename,
-                                     bool priority )
+				     const QString& relativename,
+				     bool priority )
 {
-    if (relativename.isNull())
+    if (relativename.isEmpty())
        return false;
 
     QStringList *rels = relatives.find(type);
@@ -299,7 +299,7 @@ for (QStringList::ConstIterator pit = prefixes.begin();
 #endif
 
     QString dir = findResourceDir(type, filename);
-    if (dir.isNull())
+    if (dir.isEmpty())
 	return dir;
     else return dir + filename;
 }
@@ -498,7 +498,7 @@ static void lookupPrefix(const QString& prefix, const QString& relpath,
 			 QStringList& relList,
 			 bool recursive, bool unique)
 {
-    if (relpath.isNull()) {
+    if (relpath.isEmpty()) {
        lookupDirectory(prefix, relPart, regexp, list,
 		       relList, recursive, unique);
        return;
@@ -540,7 +540,7 @@ static void lookupPrefix(const QString& prefix, const QString& relpath,
 		if (fn == _dot || fn == _dotdot || fn.at(fn.length() - 1) == '~')
 		    continue;
 
-		if (pathExp.search(fn) == -1)
+		if ( !pathExp.exactMatch(fn) )
 		    continue; // No match
 		QString rfn = relPart+fn;
 		fn = prefix + fn;
@@ -650,7 +650,28 @@ void KStandardDirs::createSpecialResource(const char *type)
    char link[1024];
    link[1023] = 0;
    int result = readlink(QFile::encodeName(dir).data(), link, 1023);
-   if ((result == -1) && (errno == ENOENT))
+   bool relink = (result == -1) && (errno == ENOENT);
+   if ((result > 0) && (link[0] == '/'))
+   {
+      link[result] = 0;
+      struct stat stat_buf;
+      int res = lstat(link, &stat_buf);
+      if ((res == -1) && (errno == ENOENT))
+      {
+         relink = true;
+      }
+      else if ((res == -1) || (!S_ISDIR(stat_buf.st_mode)))
+      {
+         fprintf(stderr, "Error: \"%s\" is not a directory.\n", link);
+         relink = true;
+      }
+      else if (stat_buf.st_uid != getuid())
+      {
+         fprintf(stderr, "Error: \"%s\" is owned by uid %d instead of uid %d.\n", link, stat_buf.st_uid, getuid());
+         relink = true;
+      }
+   }
+   if (relink)
    {
       QString srv = findExe(QString::fromLatin1("lnusertemp"), KDEDIR+QString::fromLatin1("/bin"));
       if (srv.isEmpty())
@@ -764,7 +785,7 @@ QStringList KStandardDirs::systemPaths( const QString& pstr )
     QStringList tokens;
     QString p = pstr;
 
-    if( p.isNull() ) 
+    if( p.isNull() )
     {
 	p = getenv( "PATH" );
     }
@@ -929,11 +950,11 @@ QString KStandardDirs::kde_default(const char *type) {
     if (!strcmp(type, "exe"))
 	return "bin/";
     if (!strcmp(type, "lib"))
-	return "lib/";
+	return "lib" KDELIBSUFF "/";
     if (!strcmp(type, "module"))
-	return "lib/kde3/";
+	return "lib" KDELIBSUFF "/kde3/";
     if (!strcmp(type, "qtplugins"))
-        return "lib/kde3/plugins";
+        return "lib" KDELIBSUFF "/kde3/plugins";
     if (!strcmp(type, "xdgdata-apps"))
         return "applications/";
     if (!strcmp(type, "xdgdata-dirs"))
@@ -1072,6 +1093,33 @@ static QString readEnvPath(const char *env)
    return QFile::decodeName(c_path);
 }
 
+#ifdef __linux__
+static QString executablePrefix()
+{
+   char path_buffer[MAXPATHLEN + 1];
+   path_buffer[MAXPATHLEN] = 0;
+   int length = readlink ("/proc/self/exe", path_buffer, MAXPATHLEN);
+   if (length == -1)
+      return QString::null;
+
+   path_buffer[length] = '\0';
+
+   QString path = QFile::decodeName(path_buffer);
+
+   if(path.isEmpty())
+      return QString::null;
+
+   int pos = path.findRev('/'); // Skip filename
+   if(pos <= 0)
+      return QString::null;
+   pos = path.findRev('/', pos - 1); // Skip last directory
+   if(pos <= 0)
+      return QString::null;
+
+   return path.left(pos);
+}
+#endif
+
 void KStandardDirs::addKDEDefaults()
 {
     QStringList kdedirList;
@@ -1098,6 +1146,9 @@ void KStandardDirs::addKDEDefaults()
     if (execPrefix!="NONE")
        kdedirList.append(execPrefix);
 #endif
+#ifdef __linux__
+    kdedirList.append(executablePrefix());
+#endif
 
     // We treat root differently to prevent a "su" shell messing up the
     // file permissions in the user's home directory.
@@ -1240,6 +1291,9 @@ static QStringList lookupProfiles(const QString &mapFile)
     }
 
     QCString user = pw->pw_name;
+    
+    gid_t sup_gids[512];
+    int sup_gids_nr = getgroups(512, sup_gids);
 
     KSimpleConfig mapCfg(mapFile, true);
     mapCfg.setGroup("Users");
@@ -1261,15 +1315,22 @@ static QStringList lookupProfiles(const QString &mapFile)
         // Check if user is in this group
         struct group *grp_ent = getgrnam(grp);
         if (!grp_ent) continue;
-
-        char ** members = grp_ent->gr_mem;
-        for(char * member; (member = *members); ++members)
+        gid_t gid = grp_ent->gr_gid;
+        if (pw->pw_gid == gid)
         {
-            if (user == member)
+            // User is in this group --> add profiles
+            profiles += mapCfg.readListEntry(*it);
+        }
+        else
+        {
+            for(int i = 0; i < sup_gids_nr; i++)
             {
-                // User is in this group --> add profiles
-                profiles += mapCfg.readListEntry(*it);
-                break;
+                if (sup_gids[i] == gid)
+                {
+                    // User is in this group --> add profiles
+                    profiles += mapCfg.readListEntry(*it);
+                    break;
+                }
             }
         }
     }
@@ -1279,6 +1340,8 @@ static QStringList lookupProfiles(const QString &mapFile)
     return profiles;
 }
 
+extern bool kde_kiosk_admin;
+
 bool KStandardDirs::addCustomized(KConfig *config)
 {
     if (addedCustoms) // there are already customized entries
@@ -1295,9 +1358,41 @@ bool KStandardDirs::addCustomized(KConfig *config)
     QString oldGroup = config->group();
     QString group = QString::fromLatin1("Directories");
     config->setGroup(group);
-    QString userMapFile = config->readEntry("userProfileMapFile");
+    
+    QString kioskAdmin = config->readEntry("kioskAdmin");
+    if (!kioskAdmin.isEmpty() && !kde_kiosk_admin)
+    {
+        int i = kioskAdmin.find(':');
+        QString user = kioskAdmin.left(i);
+        QString host = kioskAdmin.mid(i+1);
 
-    QStringList profiles = lookupProfiles(userMapFile);
+        KUser thisUser;
+        char hostname[ 256 ];
+        hostname[ 0 ] = '\0';
+        if (!gethostname( hostname, 255 ))
+            hostname[sizeof(hostname)-1] = '\0';
+                       
+        if ((user == thisUser.loginName()) &&
+            (host.isEmpty() || (host == hostname)))
+        {
+            kde_kiosk_admin = true;
+        }
+    }
+    
+    bool readProfiles = true;
+    
+    if (kde_kiosk_admin && !QCString(getenv("KDE_KIOSK_NO_PROFILES")).isEmpty())
+        readProfiles = false;
+
+    QString userMapFile = config->readEntry("userProfileMapFile");
+    QString profileDirsPrefix = config->readEntry("profileDirsPrefix");
+    if (!profileDirsPrefix.isEmpty() && !profileDirsPrefix.endsWith("/"))
+        profileDirsPrefix.append('/');
+
+    QStringList profiles;
+    if (readProfiles)
+        profiles = lookupProfiles(userMapFile);
+    QString profile;
     
     bool priority = false;
     while(true)
@@ -1308,6 +1403,16 @@ bool KStandardDirs::addCustomized(KConfig *config)
         {
             addPrefix(*it, priority);
 	    addXdgConfigPrefix(*it+"/etc/xdg", priority);
+	    addXdgDataPrefix(*it+"/share", priority);
+	}
+	// If there are no prefixes defined, check if there is a directory
+	// for this profile under <profileDirsPrefix>
+	if (list.isEmpty() && !profile.isEmpty() && !profileDirsPrefix.isEmpty())
+	{
+	    QString dir = profileDirsPrefix + profile;
+	    addPrefix(dir, priority);
+	    addXdgConfigPrefix(dir+"/etc/xdg", priority);
+	    addXdgDataPrefix(dir+"/share", priority);
 	}
 
         // iterating over all entries in the group Directories
@@ -1330,23 +1435,27 @@ bool KStandardDirs::addCustomized(KConfig *config)
         }
         if (profiles.isEmpty())
            break;
-        group = QString::fromLatin1("Directories-%1").arg(profiles.back());
+        profile = profiles.back();
+        group = QString::fromLatin1("Directories-%1").arg(profile);
         profiles.pop_back();
         priority = true;
     }
 
     // Process KIOSK restrictions.
-    config->setGroup("KDE Resource Restrictions");
-    QMap<QString, QString> entries = config->entryMap("KDE Resource Restrictions");
-    for (QMap<QString, QString>::ConstIterator it2 = entries.begin(); 
-         it2 != entries.end(); it2++)
+    if (!kde_kiosk_admin || QCString(getenv("KDE_KIOSK_NO_RESTRICTIONS")).isEmpty())
     {
-	QString key = it2.key();
-        if (!config->readBoolEntry(key, true))
+        config->setGroup("KDE Resource Restrictions");
+        QMap<QString, QString> entries = config->entryMap("KDE Resource Restrictions");
+        for (QMap<QString, QString>::ConstIterator it2 = entries.begin(); 
+            it2 != entries.end(); it2++)
         {
-           d->restrictionsActive = true;
-           d->restrictions.insert(key.latin1(), &d->restrictionsActive); // Anything will do
-           dircache.remove(key.latin1());
+            QString key = it2.key();
+            if (!config->readBoolEntry(key, true))
+            {
+                d->restrictionsActive = true;
+                d->restrictions.insert(key.latin1(), &d->restrictionsActive); // Anything will do
+                dircache.remove(key.latin1());
+            }
         }
     }
 
@@ -1374,6 +1483,7 @@ QString KStandardDirs::localxdgconfdir() const
     return d->xdgconf_prefixes.first();
 }
 
+
 // just to make code more readable without macros
 QString locate( const char *type,
 		const QString& filename, const KInstance* inst )
