@@ -1,6 +1,6 @@
 /****************************************************************************
 
- $Id: kstartupinfo.h,v 1.28 2003/10/23 17:40:25 lunakl Exp $
+ $Id: kstartupinfo.h,v 1.30 2004/05/26 09:22:40 lunakl Exp $
 
  Copyright (C) 2001-2003 Lubos Lunak        <l.lunak@kde.org>
 
@@ -59,7 +59,7 @@ class KStartupInfoPrivate;
  * @see KStartupInfoData
  *
  * @author Lubos Lunak <l.lunak@kde.org>
- * @version $Id: kstartupinfo.h,v 1.28 2003/10/23 17:40:25 lunakl Exp $
+ * @version $Id: kstartupinfo.h,v 1.30 2004/05/26 09:22:40 lunakl Exp $
  */
 class KStartupInfo
     : public QObject
@@ -114,11 +114,21 @@ class KStartupInfo
          */
         static void silenceStartup( bool silence );
 
+        /**
+         * Creates and returns new startup id. The id includes properly setup
+         * user timestamp.
+         * @since 3.3
+         */
+        static QCString createNewStartupId();
+	/**
+	 *
+	 */
 	enum {
 	    CleanOnCantDetect		= 1 << 0,
 	    DisableKWinModule		= 1 << 1,
 	    AnnounceSilenceChanges	= 1 << 2
 	    };
+	
 	/**
 	 * Creates an instance that will receive the startup notifications.
 	 * The various flags passed may be
@@ -328,6 +338,9 @@ class KStartupInfo
 	 */
         void gotRemoveStartup( const KStartupInfoId& id, const KStartupInfoData& data );
     protected:
+	/**
+	 * 
+	 */ 
 	virtual void customEvent( QCustomEvent* e_P );
     private slots:
         void startups_cleanup();
@@ -374,7 +387,7 @@ class KStartupInfoIdPrivate;
  * @see KStartupInfoData
  *
  * @author Lubos Lunak <l.lunak@kde.org>
- * @version $Id: kstartupinfo.h,v 1.28 2003/10/23 17:40:25 lunakl Exp $
+ * @version $Id: kstartupinfo.h,v 1.30 2004/05/26 09:22:40 lunakl Exp $
  */
 class KStartupInfoId
     {
@@ -407,6 +420,12 @@ class KStartupInfoId
 	 * @return the identification string for the notification
 	 */
         const QCString& id() const;
+        /**
+         * Return the user timestamp for the startup notification, or 0 if no timestamp
+         * is set.
+         * @since 3.3
+         */
+        unsigned long timestamp() const;
 	/**
 	 * Sets the startup notification environment variable to this identification.
 	 * @return true if successful, false otherwise
@@ -442,7 +461,7 @@ class KStartupInfoDataPrivate;
  * @see KStartupInfoId
  *
  * @author Lubos Lunak <l.lunak@kde.org>
- * @version $Id: kstartupinfo.h,v 1.28 2003/10/23 17:40:25 lunakl Exp $
+ * @version $Id: kstartupinfo.h,v 1.30 2004/05/26 09:22:40 lunakl Exp $
  */
 class KStartupInfoData
     {
@@ -573,6 +592,9 @@ class KStartupInfoData
 	 */
         const QCString& hostname() const;
 	
+	/**
+	 *
+	 */
 	enum TriState { Yes, No, Unknown };
 	
 	/**
@@ -590,6 +612,7 @@ class KStartupInfoData
 	TriState silent() const;
         
         /**
+         * @obsolete Timestamp is already assigned in KStartupInfoId::initId().
          * Sets timestamp for the startup notification. The timestamp is expressed
          * as XServer time, and is used to prevent activation of the matching
          * window if user interaction took place after this timestamp.
@@ -599,6 +622,7 @@ class KStartupInfoData
         void setTimestamp( unsigned long time );
         
         /**
+         * @obsolete Use KStartupInfoId::timestamp().
          * Return the timestamp for the startup notification, or -1 if no timestamp
          * is set.
          */
