@@ -25,9 +25,25 @@
 
 #include <kglobal.h>
 
+/**
+ * Static deleters are used to manage static resources. They can register
+ * themselves with KGlobal. KGlobal will call destructObject() when
+ * KGlobal::deleteStaticDeleters() is called or when it the process
+ * finishes.
+ *
+ * @see KStaticDeleter
+ * @see KGlobal::registerStaticDeleter()
+ * @see KGlobal::unregisterStaticDeleter()
+ * @see KGlobal::deleteStaticDeleters()
+ */
 class KStaticDeleterBase {
 public:
     virtual ~KStaticDeleterBase() { }
+    /**
+     * Should destruct the resources managed by this KStaticDeleterBase.
+     * Usually you also want to call it in your destructor.
+     * @see KGlobal::deleteStaticDeleters()
+     */
     virtual void destructObject();
 };
 
@@ -36,27 +52,37 @@ public:
  * held as pointer.
  * When the library is unloaded, or the app terminated, all static deleters
  * are destroyed, which in turn destroys those static objects properly.
+ * There are some rules which you should accept in the KStaticDeleter managed
+ * class:
+ * @li Don't rely on the global reference variable in the destructor of the 
+ * object, it will be '0' at destruction time.
+ * @li Don't rely on other KStaticDeleter managed objects in the destructor 
+ * of the object, because it may be destroyed before your destructor get called.
+ * This one can be tricky, because you might not know that you actually use a
+ * KStaticDeleter managed class. So try to keep your destructor simple.
  *
  * A typical use is
- * <pre>
+ * \code
  * static KStaticDeleter<MyClass> sd;
  *
- * MyClass::self() {
+ * MyClass &MyClass::self() {
  *   if (!_self) { sd.setObject(_self, new MyClass()); }
+ *   return *_self;
  * }
- * </pre>
+ * \endcode
  */
 template<class type> class KStaticDeleter : public KStaticDeleterBase {
 public:
     KStaticDeleter() { deleteit = 0; globalReference = 0; array = false; }
     /**
-     * sets the object to delete and registers the object to be
-     * deleted to KGlobal. if the given object is 0, the former
-     * registration is unregistered
+     * Sets the object to delete and registers the object to be
+     * deleted to KGlobal. If the given object is 0, the former
+     * registration is unregistered.
+     * @param obj the object to delete
      * @param isArray tells the destructor to delete an array instead of an object
-     * @deprecated. See the other setObject variant.
+     * @deprecated See the other setObject variant.
      **/
-    type *setObject( type *obj, bool isArray = false) {
+    KDE_DEPRECATED type *setObject( type *obj, bool isArray = false) {
         deleteit = obj;
         globalReference = 0;
 	array = isArray;
@@ -67,11 +93,12 @@ public:
         return obj;
     }
     /**
-     * sets the object to delete and registers the object to be
-     * deleted to KGlobal. if the given object is 0, the former
-     * registration is unregistered
+     * Sets the object to delete and registers the object to be
+     * deleted to KGlobal. If the given object is 0, the former
+     * registration is unregistered.
      * @param globalRef the static pointer where this object is stored
      * This pointer will be reset to 0 after deletion of the object.
+     * @param obj the object to delete
      * @param isArray tells the destructor to delete an array instead of an object
      **/
     type *setObject( type* & globalRef, type *obj, bool isArray = false) {
@@ -85,14 +112,19 @@ public:
         globalRef = obj;
 	return obj;
     }
+
+    /**
+     * Destructs the object. This has the same effect as deleting
+     * the KStaticDeleter.
+     */
     virtual void destructObject() {
+        if (globalReference)
+           *globalReference = 0;
 	if (array)
 	   delete [] deleteit;
 	else
 	   delete deleteit;
     	deleteit = 0;
-        if (globalReference)
-           *globalReference = 0;
     }
     virtual ~KStaticDeleter() {
     	KGlobal::unregisterStaticDeleter(this);
