@@ -24,14 +24,25 @@
 #include "kstringhandler.h"
 #include "kglobal.h"
 
+static void parsePythonRange( const QCString &range, uint &start, uint &end )
+{
+    const int colon = range.find( ':' );
+    if ( colon == -1 ) {
+        start = range.toUInt();
+        end = start;
+    } else if ( colon == int( range.length() - 1 ) ) {
+        start = range.left( colon ).toUInt();
+    } else if ( colon == 0 ) {
+        end = range.mid( 1 ).toUInt();
+    } else {
+        start = range.left( colon ).toInt();
+        end = range.mid( colon + 1 ).toInt();
+    }
+}
+
 QString KStringHandler::word( const QString &text , uint pos )
 {
-    QStringList list = QStringList::split( " ", text , true );
-
-    if ( pos < list.count() )
-        return list[ pos ];
-
-    return "";
+    return text.section( ' ', pos, pos );
 }
 
 QString KStringHandler::word( const QString &text , const char *range )
@@ -48,40 +59,8 @@ QString KStringHandler::word( const QString &text , const char *range )
     if ( text.isEmpty() )
         return tmp;
 
-    // do stuff here
-    QRegExp reg;
-
-    int at = 0;
-    int pos = 0;
-    int cnt = 0;
-
-    if ( r.find(QRegExp("[0-9]+:[0-9]+")) != -1 )
-    {
-        at  = r.find(":");
-        pos = atoi( r.left(at).ascii() );
-        cnt = atoi( r.remove(0,at+1).ascii() );
-    }
-    else if ( r.find(QRegExp(":+[0-9]+")) != -1 )
-    {
-        at  = r.find(":");
-        pos = 0;
-        cnt = atoi( r.remove(0,at+1).ascii() );
-    }
-    else if ( r.find(QRegExp("[0-9]+:+")) != -1 )
-    {
-        at  = r.find(":");
-        pos = atoi( r.left(at).ascii() );
-        cnt = list.count(); // zero index
-    }
-    else if ( r.find(QRegExp("[0-9]+")) != -1 )
-    {
-        pos = atoi( r.ascii() );
-        cnt = pos;
-    }
-    else
-    {
-        return tmp; // not found/implemented
-    }
+    uint pos = 0, cnt = list.count();
+    parsePythonRange( range, pos, cnt );
 
     //
     // Extract words
@@ -158,40 +137,8 @@ QString KStringHandler::remrange( const QString &text , const char *range )
     if ( text.isEmpty() )
         return tmp;
 
-    // do stuff here
-    QRegExp reg;
-
-    int at = 0;
-    int pos = 0;
-    int cnt = 0;
-
-    if ( r.find(QRegExp("[0-9]+:[0-9]+")) != -1 )
-    {
-        at  = r.find(':');
-        pos = atoi( r.left(at).ascii() );
-        cnt = atoi( r.remove(0,at+1).ascii() );
-    }
-    else if ( r.find(QRegExp(":+[0-9]+")) != -1 )
-    {
-        at  = r.find(':');
-        pos = 0;
-        cnt = atoi( r.remove(0,at+1).ascii() );
-    }
-    else if ( r.find(QRegExp("[0-9]+:+")) != -1 )
-    {
-        at  = r.find(':');
-        pos = atoi( r.left(at).ascii() );
-        cnt = list.count(); // zero index
-    }
-    else if ( r.find(QRegExp("[0-9]+")) != -1 )
-    {
-        pos = atoi( r.ascii() );
-        cnt = pos;
-    }
-    else
-    {
-        return text; // not found/implemented
-    }
+    uint pos = 0, cnt = list.count();
+    parsePythonRange( range, pos, cnt );
 
     //
     // Remove that range of words
@@ -249,34 +196,24 @@ QString KStringHandler::remword( const QString &text , const QString &word )
 //
 QString KStringHandler::capwords( const QString &text )
 {
-    QString tmp = "";
+    if ( text.isEmpty() ) {
+        return text;
+    }
 
-    if ( text.isEmpty() )
-        return tmp;
+    const QString strippedText = text.stripWhiteSpace();
+    const QStringList words = capwords( QStringList::split( ' ', strippedText ) );
 
-    QStringList list = QStringList::split( " ", text, true );
-
-    return capwords( QStringList::split( " ", text, true )).join( " " );
+    QString result = text;
+    result.replace( strippedText, words.join( " " ) );
+    return result;
 }
 
 QStringList KStringHandler::capwords( const QStringList &list )
 {
-    QStringList tmp;
-    QString word;
-
-    if ( list.count() == 0 )
-        return tmp;
-
-    for ( QStringList::ConstIterator it= list.begin();
-          it != list.end();
-          it++)
-    {
-        word = *it;
-        word = word.left(1).upper() + word.remove(0,1);
-
-        tmp.append( word ); // blank list to start with
+    QStringList tmp = list;
+    for ( QStringList::Iterator it = tmp.begin(); it != tmp.end(); ++it ) {
+        *it = ( *it )[ 0 ].upper() + ( *it ).mid( 1 );
     }
-
     return tmp;
 }
 
@@ -317,58 +254,27 @@ QStringList KStringHandler::reverse( const QStringList &list )
 //
 QString KStringHandler::ljust( const QString &text , uint width )
 {
-    QString tmp = text;
-    tmp = tmp.stripWhiteSpace(); // remove leading/trailing spaces
-
-    if ( tmp.length() >= width )
-        return tmp;
-
-    for ( uint pos = tmp.length() ; pos < width ; pos++ )
-        tmp.append(" ");
-
-    return tmp;
+    return text.stripWhiteSpace().leftJustify( width );
 }
 
 QString KStringHandler::rjust( const QString &text , uint width )
 {
-    QString tmp = text;
-    tmp = tmp.stripWhiteSpace(); // remove leading/trailing spaces
-
-    if ( tmp.length() >= width )
-        return tmp;
-
-    for ( uint pos = tmp.length() ; pos < width ; pos++ )
-        tmp.prepend(" ");
-
-    return tmp;
+    return text.stripWhiteSpace().rightJustify( width );
 }
 
 QString KStringHandler::center( const QString &text , uint width )
 {
-    // Center is slightly different, in that it will add
-    // spaces to the RIGHT side (left-justified) before
-    // it adds a space to the LEFT side.
+    const QString s = text.stripWhiteSpace();
+    const unsigned int length = s.length();
+    if ( width <= length ) {
+        return s;
+     }
 
-    QString tmp = text;
-    tmp = tmp.stripWhiteSpace(); // remove leading/trailing spaces
+    QString result;
+    result.fill( ' ', ( width - length ) / 2 );
+    result += s;
 
-    if ( tmp.length() >= width )
-        return tmp;
-
-    bool left = false; // start at right side.
-
-    for ( uint pos = tmp.length() ; pos < width ; pos++ )
-    {
-        if ( left )
-            tmp.prepend(" ");
-        else
-            tmp.append(" ");
-
-        // Reverse bool
-        left = !left;
-    }
-
-    return tmp;
+    return result.leftJustify( width );
 }
 
 QString KStringHandler::lsqueeze( const QString & str, uint maxlen )
@@ -403,13 +309,6 @@ QString KStringHandler::lEmSqueeze(const QString &name, const QFontMetrics& font
   return lPixelSqueeze(name, fontMetrics, fontMetrics.maxWidth() * maxlen);
 }
 
-static inline int emSqueezeLimit(int delta, int min, int max)
-{
-  if (delta < min) return min;
-  if (delta > max) return max;
-  return delta;
-}
-
 QString KStringHandler::lPixelSqueeze(const QString& name, const QFontMetrics& fontMetrics, uint maxPixels)
 {
   uint nameWidth = fontMetrics.width(name);
@@ -423,7 +322,7 @@ QString KStringHandler::lPixelSqueeze(const QString& name, const QFontMetrics& f
     while (maxPixels < nameWidth && !tmp.isEmpty())
     {
       int delta = (nameWidth - maxPixels) / em;
-      delta = emSqueezeLimit(delta, 1, delta); // no max
+      delta = kClamp(delta, 1, delta); // no max
 
       tmp.remove(0, delta);
       nameWidth = fontMetrics.width(tmp);
@@ -440,30 +339,46 @@ QString KStringHandler::cEmSqueeze(const QString& name, const QFontMetrics& font
   return cPixelSqueeze(name, fontMetrics, fontMetrics.maxWidth() * maxlen);
 }
 
-QString KStringHandler::cPixelSqueeze(const QString& name, const QFontMetrics& fontMetrics, uint maxPixels)
+QString KStringHandler::cPixelSqueeze(const QString& s, const QFontMetrics& fm, uint width)
 {
-  uint nameWidth = fontMetrics.width(name);
-
-  if (maxPixels < nameWidth)
-  {
-    QString tmp = name;
-    const uint em = fontMetrics.maxWidth();
-    maxPixels -= fontMetrics.width("...");
-
-    while (maxPixels < nameWidth && !tmp.isEmpty())
-    {
-      int length = tmp.length();
-      int delta = (nameWidth - maxPixels) / em;
-      delta = emSqueezeLimit(delta, 1, length) ;
-
-      tmp.remove((length / 2) - (delta / 2), delta);
-      nameWidth = fontMetrics.width(tmp);
-    }
-
-    return tmp.insert((tmp.length() + 1) / 2, "...");
+  if ( s.isEmpty() || uint( fm.width( s ) ) <= width ) {
+    return s;
   }
 
-  return name;
+  const unsigned int length = s.length();
+  if ( length == 2 ) {
+    return s;
+  }
+
+  const int maxWidth = width - fm.width( '.' ) * 3;
+  if ( maxWidth <= 0 ) {
+    return "...";
+  }
+
+  unsigned int leftIdx = 0, rightIdx = length;
+  unsigned int leftWidth = fm.charWidth( s, leftIdx++ );
+  unsigned int rightWidth = fm.charWidth( s, --rightIdx );
+  while ( leftWidth + rightWidth < uint( maxWidth ) ) {
+    while ( leftWidth <= rightWidth && leftWidth + rightWidth < uint( maxWidth ) ) {
+      leftWidth += fm.charWidth( s, leftIdx++ );
+    }
+    while ( rightWidth <= leftWidth && leftWidth + rightWidth < uint( maxWidth ) ) {
+      rightWidth += fm.charWidth( s, --rightIdx );
+    }
+  }
+
+  if ( leftWidth > rightWidth ) {
+    --leftIdx;
+  } else {
+    ++rightIdx;
+  }
+
+  rightIdx = length - rightIdx;
+  if ( leftIdx == 0 && rightIdx == 1 || leftIdx == 1 && rightIdx == 0 ) {
+    return "...";
+  }
+
+  return s.left( leftIdx ) + "..." + s.right( rightIdx );
 }
 
 QString KStringHandler::rEmSqueeze(const QString& name, const QFontMetrics& fontMetrics, uint maxlen)
@@ -485,7 +400,7 @@ QString KStringHandler::rPixelSqueeze(const QString& name, const QFontMetrics& f
     {
       int length = tmp.length();
       int delta = (nameWidth - maxPixels) / em;
-      delta = emSqueezeLimit(delta, 1, length) ;
+      delta = kClamp(delta, 1, length) ;
 
       tmp.remove(length - delta, delta);
       nameWidth = fontMetrics.width(tmp);
@@ -619,7 +534,7 @@ KStringHandler::perlSplit(const QRegExp & sep, const QString & s, uint max)
  QString
 KStringHandler::tagURLs( const QString& text )
 {
-    /*static*/ QRegExp urlEx("(www\\.(?!\\.)|(f|ht)tp(|s)://)[\\d\\w\\./,:_~\\?=&;#@\\-\\+\\%]+[\\d\\w/]");
+    /*static*/ QRegExp urlEx("(www\\.(?!\\.)|(fish|(f|ht)tp(|s))://)[\\d\\w\\./,:_~\\?=&;#@\\-\\+\\%]+[\\d\\w/]");
 
     QString richText( text );
     int urlPos = 0, urlLen;
@@ -658,6 +573,9 @@ bool KStringHandler::isUtf8(const char *buf)
   int i, n;
   register unsigned char c;
   bool gotone = false;
+  
+  if (!buf)
+    return true; // whatever, just don't crash
 
 #define F 0   /* character never appears in text */
 #define T 1   /* character appears in plain ASCII text */
