@@ -3,7 +3,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 1999 Waldo Bastian <bastian@kde.org>
  *
- * $Id: ktempfile.cpp,v 1.28.2.2 2004/03/01 12:34:52 waba Exp $
+ * $Id: ktempfile.cpp,v 1.33 2004/07/15 16:21:42 waba Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -205,6 +205,46 @@ KTempFile::unlink()
    mTmpName = QString::null;
 }
 
+#if defined(_POSIX_SYNCHRONIZED_IO) && _POSIX_SYNCHRONIZED_IO > 0
+#define FDATASYNC fdatasync
+#else
+#define FDATASYNC fsync
+#endif
+
+bool
+KTempFile::sync()
+{
+   int result = 0;
+
+   if (mStream)
+   {
+      do {
+         result = fflush(mStream); // We need to flush first otherwise fsync may not have our data
+      }
+      while ((result == -1) && (errno == EINTR));
+      
+      if (result)
+      {
+         qWarning("KTempFile: Error trying to flush %s: %s", mTmpName.latin1(), strerror(errno));
+         mError = errno;
+      }
+   }
+
+   if (mFd >= 0)
+   {
+      result = FDATASYNC(mFd);
+      if (result)
+      {
+         qWarning("KTempFile: Error trying to sync %s: %s", mTmpName.latin1(), strerror(errno));
+         mError = errno;
+      }
+   }
+
+   return (mError == 0);
+}
+
+#undef FDATASYNC
+
 bool
 KTempFile::close()
 {
@@ -218,12 +258,12 @@ KTempFile::close()
       result = ferror(mStream);
       if (result)
          mError = ENOSPC; // Assume disk full.
-
+         
       result = fclose(mStream);
       mStream = 0;
       mFd = -1;
       if (result != 0) {
-         qWarning("KTempFile: Error trying to closing %s: %s", mTmpName.latin1(), strerror(errno));
+         qWarning("KTempFile: Error trying to close %s: %s", mTmpName.latin1(), strerror(errno));
          mError = errno;
       }
    }
@@ -234,7 +274,7 @@ KTempFile::close()
       result = ::close(mFd);
       mFd = -1;
       if (result != 0) {
-         qWarning("KTempFile: Error trying to closing %s: %s", mTmpName.latin1(), strerror(errno));
+         qWarning("KTempFile: Error trying to close %s: %s", mTmpName.latin1(), strerror(errno));
          mError = errno;
       }
    }
