@@ -1,4 +1,4 @@
-/* 
+/*
    This file is part of the KDE libraries
    Copyright (c) 1999 Waldo Bastian <bastian@kde.org>
    
@@ -47,7 +47,7 @@ class KTempFilePrivate;
  *
  * KTempFile does not create any missing directories, but locateLocal() does.
  *
- * See also @ref KStandardDirs
+ * See also KStandardDirs
  *
  * @author Waldo Bastian <bastian@kde.org>
  */
@@ -57,17 +57,18 @@ class KTempFile
 public:
    /**
     * Creates a temporary file with the name:
-    *  <filePrefix><six letters><fileExtension>
+    *  \<filePrefix>\<six letters>\<fileExtension>
     *
-    * The default @p filePrefix is "$KDEHOME/tmp-$HOST/appname"
+    * The default @p filePrefix is "$KDEHOME/tmp-$HOST/appname/"
     * The default @p fileExtension is ".tmp"
     * @param filePrefix the prefix of the file name, or QString::null
     *        for the default value
-    * @param the extension of the prefix, or QString::null for the 
+    * @param fileExtension the extension of the prefix, or QString::null for the
     *        default value
+    * @param mode the file permissions
     **/
-   KTempFile(QString filePrefix=QString::null, 
-             QString fileExtension=QString::null, 
+   KTempFile(QString filePrefix=QString::null,
+             QString fileExtension=QString::null,
              int mode = 0600 );
 
 
@@ -85,10 +86,10 @@ public:
    void setAutoDelete(bool autoDelete) { bAutoDelete = autoDelete; }
 
    /**
-    * Returns the status of the file based on errno. (see errno.h) 
+    * Returns the status of the file based on errno. (see errno.h)
     * 0 means OK.
     *
-    * You should check the status after object creation to check 
+    * You should check the status after object creation to check
     * whether a file could be created in the first place.
     *
     * You may check the status after closing the file to verify that
@@ -99,8 +100,23 @@ public:
 
    /**
     * Returns the full path and name of the file.
+    *
+    * Note that in most circumstances the file needs to be closed 
+    * before you use it by name. 
+    *
+    * In particular, if another process or software part needs to write data 
+    * to the file based on the filename, the file should be closed before doing 
+    * so. Otherwise the act of closing the file later on may cause the file to 
+    * get truncated to a zero-size, resulting in an unexpected loss of the data.
+    *
+    * In some cases there is only interest in the filename itself but where the
+    * actual presence of a file with such name is a problem. In that case the
+    * file should first be both closed and unlinked. Such usage is not recommended
+    * since it may lead to the kind of symlink vulnerabilities that the KTempFile 
+    * design attempts to prevent.
+    *
     * @return The name of the file, or QString::null if opening the
-    *         file has failed or the file has been unlinked
+    *         file has failed or the file has been unlinked already.
     **/
    QString name() const;
    
@@ -119,21 +135,21 @@ public:
    FILE *fstream();
 
    /**
-    * Returns the @ref QTextStream for writing.
+    * Returns the QTextStream for writing.
     * @return QTextStream open for writing to the file, or 0
     *         if opening the file failed
     **/
    QTextStream *textStream();
 
    /**
-    * Returns a @ref QDataStream for writing.
+    * Returns a QDataStream for writing.
     * @return QDataStream open for writing to the file, or 0 
     *         if opening the file failed
     **/
    QDataStream *dataStream();
 
    /**
-    * Returns a @ref QFile.
+    * Returns a QFile.
     * @return A QFile open for writing to the file, or 0 if 
     *         opening the file failed.
     **/
@@ -145,11 +161,22 @@ public:
     **/
    void unlink();   
 
+   /**
+    * Flushes file to disk (fsync).
+    *
+    * If you want to be as sure as possible that the file data has
+    * actually been physically stored on disk you need to call sync().
+    * 
+    * See status() for details about errors.
+    * @return true if successful, or false if an error has occurred.
+    **/
+   bool sync();
+
    /**
     * Closes the file.
     * 
-    * See @ref #status() for details about errors.
-    * @return true if successful, or false if an error has occured.
+    * See status() for details about errors.
+    * @return true if successful, or false if an error has occurred.
     **/
    bool close();
 
