@@ -1,7 +1,7 @@
 /* This file is part of the KDE libraries
     Copyright (c) 1999 Preston Brown <pbrown@kde.org>
 
-    $Id: kuniqueapplication.cpp,v 1.68 2004/01/07 12:13:50 lunakl Exp $
+    $Id: kuniqueapplication.cpp,v 1.74 2004/06/03 12:54:00 lunakl Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -39,8 +39,8 @@
 #include <kaboutdata.h>
 
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#include <kwin.h> // schroder
-#include <kstartupinfo.h> // schroder
+#include <kwin.h> 
+#include <kstartupinfo.h> 
 #endif
 
 #include <kconfig.h>
@@ -48,8 +48,8 @@
 #include "kuniqueapplication.h"
 
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#include <netwm.h> // schroder
-#include <X11/Xlib.h> // schroder
+#include <netwm.h> 
+#include <X11/Xlib.h> 
 #define DISPLAY "DISPLAY"
 #else
 #  ifdef Q_WS_QWS
@@ -62,6 +62,7 @@
 bool KUniqueApplication::s_nofork = false;
 bool KUniqueApplication::s_multipleInstances = false;
 bool KUniqueApplication::s_uniqueTestDone = false;
+bool KUniqueApplication::s_handleAutoStarted = false;
 
 static KCmdLineOptions kunique_options[] =
 {
@@ -109,7 +110,18 @@ KUniqueApplication::start()
         pid.setNum(getpid());
         appName = appName + "-" + pid;
      }
-     dcopClient()->registerAs(appName, false );
+
+     // Check to make sure that we're actually able to register with the DCOP
+     // server.
+
+     if(dcopClient()->registerAs(appName, false).isEmpty()) {
+        startKdeinit();
+        if(dcopClient()->registerAs(appName, false).isEmpty()) {
+           kdError() << "KUniqueApplication: Can't setup DCOP communication." << endl;
+           ::exit(255);
+        }           
+     }
+
      // We'll call newInstance in the constructor. Do nothing here.
      return true;
   }
@@ -311,6 +323,24 @@ KUniqueApplication::KUniqueApplication(bool allowStyles, bool GUIenabled, bool c
     QTimer::singleShot( 0, this, SLOT(newInstanceNoFork()) );
 }
 
+
+#ifdef Q_WS_X11
+KUniqueApplication::KUniqueApplication(Display *display, Qt::HANDLE visual,
+		Qt::HANDLE colormap, bool allowStyles, bool configUnique)
+  : KApplication( display, visual, colormap, allowStyles, initHack( configUnique )),
+    DCOPObject(KCmdLineArgs::about->appName())
+{
+  d = new KUniqueApplicationPrivate;
+  d->processingRequest = false;
+  d->firstInstance = true;
+
+  if (s_nofork)
+    // Can't call newInstance directly from the constructor since it's virtual...
+    QTimer::singleShot( 0, this, SLOT(newInstanceNoFork()) );
+}
+#endif
+
+
 KUniqueApplication::~KUniqueApplication()
 {
   delete d;
@@ -340,8 +370,17 @@ void KUniqueApplication::newInstanceNoFork()
     return;
   }
   
+  s_handleAutoStarted = false;
   newInstance();
-  KStartupInfo::handleAutoAppStartedSending(); // KDE4 remove?
+  d->firstInstance = false;
+  // KDE4 remove
+  // A hack to make startup notification stop for apps which override newInstance()
+  // and reuse an already existing window there, but use KWin::activateWindow()
+  // instead of KStartupInfo::setNewStartupId(). Therefore KWin::activateWindow()
+  // for now sets this flag. Automatically ending startup notification always
+  // would cause problem if the new window would show up with a small delay.
+  if( s_handleAutoStarted )
+      KStartupInfo::handleAutoAppStartedSending();
   // What to do with the return value ?
 }
 
@@ -395,8 +434,11 @@ KUniqueApplication::processDelayed()
            ds >> asn_id;
            setStartupId( asn_id );
        }
+       s_handleAutoStarted = false;
        int exitCode = newInstance();
-       KStartupInfo::handleAutoAppStartedSending(); // KDE4 remove?
+       d->firstInstance = false;
+       if( s_handleAutoStarted )
+           KStartupInfo::handleAutoAppStartedSending(); // KDE4 remove?
        QDataStream rs(replyData, IO_WriteOnly);
        rs << exitCode;
        replyType = "int";
@@ -408,15 +450,16 @@ KUniqueApplication::processDelayed()
   d->processingRequest = false;
 }
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifndef Q_WS_QWS // FIXME(E): Implement for Qt/Embedded
-extern Time qt_x_time;
-#endif
+bool KUniqueApplication::restoringSession()
+{
+  return d->firstInstance && isRestored();
+}
 
 int KUniqueApplication::newInstance()
 {
   if (!d->firstInstance)
   {
+    
 //#ifndef Q_WS_QWS // FIXME(E): Implement for Qt/Embedded
     if ( mainWidget() )
     {
@@ -429,10 +472,14 @@ int KUniqueApplication::newInstance()
 #endif
     }
   }
-  d->firstInstance = false;
   return 0; // do nothing in default implementation
 }
 
+void KUniqueApplication::setHandleAutoStarted()
+{
+    s_handleAutoStarted = false;
+}
+
 void KUniqueApplication::virtual_hook( int id, void* data )
 { KApplication::virtual_hook( id, data );
   DCOPObject::virtual_hook( id, data ); }
