@@ -212,7 +212,7 @@ static void decode( const QString& segment, QString &decoded, QString &encoded,
       // Uh oh
       textCodec = codecForHint( 106 ); // Fall back to utf-8
       csegment = textCodec->fromUnicode(segment);
-  } 
+  }
   old_length = csegment.length();
 
   int new_length = 0;
@@ -301,10 +301,10 @@ static QString decode(const QString &segment, int encoding_hint = 0)
 static QString cleanpath(const QString &_path, bool cleanDirSeparator, bool decodeDots)
 {
   if (_path.isEmpty()) return QString::null;
-  
+
   if (_path[0] != '/')
      return _path; // Don't mangle mailto-style URLs
-  
+
   QString path = _path;
 
   int len = path.length();
@@ -644,7 +644,7 @@ void KURL::parse( const QString& _url, int encoding_hint )
 	    m_iUriMode = uriModeForProtocol( m_strProtocol );
 	// Proceed to correct parse function.
 	switch ( m_iUriMode )
-  {
+	{
 	case RawURI:
 	    parseRawURI( _url );
 	    return;
@@ -682,14 +682,14 @@ void KURL::parseRawURI( const QString& _url, int encoding_hint )
     // Note that m_strProtocol is already set here, so we just skip over the protocol.
     if (pos < len && buf[pos] == ':' )
 	pos++;
-    else {
+    else { // can't happen, the caller checked all this already
 	reset();
-    m_strProtocol = _url;
+	m_strProtocol = _url;
 	m_iUriMode = Invalid;
 	return;
     }
 
-    if ( pos == len )
+    if ( pos == len ) // can't happen, the caller checked this already
 	m_strPath = QString::null;
     else
 	m_strPath = decode( QString( buf + pos, len - pos ), encoding_hint );
@@ -703,7 +703,7 @@ void KURL::parseMailto( const QString& _url, int encoding_hint )
 {
     parseURL( _url, encoding_hint);
     if ( m_bIsMalformed )
-    return;
+        return;
     QRegExp mailre("(.+@)(.+)");
     if ( mailre.exactMatch( m_strPath ) )
     {
@@ -1049,7 +1049,7 @@ bool KURL::operator<( const KURL& _u) const
   }
   if (!isValid())
      return true;
-  
+
   i = m_strProtocol.compare(_u.m_strProtocol);
   if (i) return (i < 0);
 
@@ -1069,11 +1069,11 @@ bool KURL::operator<( const KURL& _u) const
 
   i = m_strUser.compare(_u.m_strUser);
   if (i) return (i < 0);
-  
+
   i = m_strPass.compare(_u.m_strPass);
   if (i) return (i < 0);
 
-  return false;    
+  return false;
 }
 
 bool KURL::operator==( const KURL& _u ) const
@@ -1320,18 +1320,18 @@ bool KURL::isLocalFile() const
 {
   if ( (m_strProtocol != fileProt ) || hasSubURL() )
      return false;
-     
+
   if (m_strHost.isEmpty() || (m_strHost == "localhost"))
      return true;
-     
+
   char hostname[ 256 ];
   hostname[ 0 ] = '\0';
   if (!gethostname( hostname, 255 ))
      hostname[sizeof(hostname)-1] = '\0';
-     
+
   for(char *p = hostname; *p; p++)
      *p = tolower(*p);
-     
+
   return (m_strHost == hostname);
 }
 
@@ -1678,7 +1678,7 @@ void KURL::addPath( const QString& _txt )
      *this = join( lst );
      return;
   }
-  
+
   m_strPath_encoded = QString::null;
 
   if ( _txt.isEmpty() )
@@ -2166,7 +2166,7 @@ KURL KURL::fromPathOrURL( const QString& text )
 {
     if ( text.isEmpty() )
         return KURL();
-    
+
     KURL url;
     if ( text[0] == '/' )
         url.setPath( text );
@@ -2189,13 +2189,13 @@ static QString _relativePath(const QString &base_dir, const QString &path, bool
 
    QStringList list1 = QStringList::split('/', _base_dir);
    QStringList list2 = QStringList::split('/', _path);
-                                                                   
+
    // Find where they meet
    uint level = 0;
    uint maxLevel = QMIN(list1.count(), list2.count());
    while((level < maxLevel) && (list1[level] == list2[level])) level++;
-  
-   QString result;                                                                       
+
+   QString result;
    // Need to go down out of the first path to the common branch.
    for(uint i = level; i < list1.count(); i++)
       result.append("../");
@@ -2218,10 +2218,10 @@ QString KURL::relativePath(const QString &base_dir, const QString &path, bool *i
    QString result = _relativePath(base_dir, path, parent);
    if (parent)
       result.prepend("./");
-      
+
    if (isParent)
       *isParent = parent;
-   
+
    return result;
 }
 
@@ -2238,7 +2238,7 @@ QString KURL::relativeURL(const KURL &base_url, const KURL &url, int encoding_hi
    }
 
    QString relURL;
-   
+
    if ((base_url.path() != url.path()) || (base_url.query() != url.query()))
    {
       bool dummy;
