@@ -1,7 +1,7 @@
 /* This file is part of the KDE libraries
     Copyright (C) 1999 Matthias Ettrich (ettrich@kde.org)
 
-    $Id: kwin.cpp,v 1.97.2.1 2004/04/23 08:52:11 lunakl Exp $
+    $Id: kwin.cpp,v 1.103 2004/07/28 15:49:07 lunakl Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@
 #include <sysent.h>
 #endif
 
-#include <qapplication.h>
+#include <kuniqueapplication.h>
 #include <qbitmap.h>
 #include <qimage.h>
 #include <qwhatsthis.h>
@@ -44,15 +44,16 @@
 #include <kdatastream.h>
 #include <klocale.h>
 #include <dcopclient.h>
+#include <dcopref.h>
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#include <kstartupinfo.h> // schroder not needed at all ?
-#include <kxerrorhandler.h> // schroder
+#include <kstartupinfo.h> 
+#include <kxerrorhandler.h> 
 
-#include <X11/Xlib.h> // schroder
-#include <X11/Xatom.h> // schroder
-#include <X11/Xutil.h> // schroder
+#include <X11/Xlib.h> 
+#include <X11/Xatom.h> 
+#include <X11/Xutil.h> 
 
-#include "netwm.h" // schroder
+#include "netwm.h" 
 
 static bool atoms_created = false;
 extern Atom qt_wm_protocols;
@@ -200,6 +201,12 @@ void KWin::setSystemTrayWindowFor( WId trayWin, WId forWin )
     if ( !forWin )
 	forWin = qt_xrootwin();
     info.setKDESystemTrayWinFor( forWin );
+    NETRootInfo rootinfo( qt_xdisplay(), NET::Supported );
+    if( !rootinfo.isSupported( NET::WMKDESystemTrayWinFor )) {
+        DCOPRef ref( "kded", "kded" );
+        if( !ref.send( "loadModule", QCString( "kdetrayproxy" )))
+            kdWarning( 176 ) << "Loading of kdetrayproxy failed." << endl;
+    }
 #endif
 }
 
@@ -212,6 +219,7 @@ void KWin::activateWindow( WId win, long time )
     info.setActiveWindow( win, NET::FromApplication, time,
         kapp->activeWindow() ? kapp->activeWindow()->winId() : 0 );
 #endif // Q_WS_X11 ...
+    KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWin::forceActiveWindow( WId win, long time )
@@ -222,6 +230,7 @@ void KWin::forceActiveWindow( WId win, long time )
         time = qt_x_time;
     info.setActiveWindow( win, NET::FromTool, time, 0 );
 #endif // Q_WS_X11 ...
+    KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWin::setActiveWindow( WId win )
@@ -230,6 +239,7 @@ void KWin::setActiveWindow( WId win )
     NETRootInfo info( qt_xdisplay(), 0 );
     info.setActiveWindow( win, NET::FromUnknown, 0, 0 );
 #endif
+    KUniqueApplication::setHandleAutoStarted();
 }
 
 void KWin::demandAttention( WId win, bool set )
@@ -523,6 +533,29 @@ void KWin::setOnDesktop( WId win, int desktop )
 #endif
 }
 
+void KWin::setExtendedStrut( WId win, int left_width, int left_start, int left_end,
+    int right_width, int right_start, int right_end, int top_width, int top_start, int top_end,
+    int bottom_width, int bottom_start, int bottom_end )
+{
+#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+    NETWinInfo info( qt_xdisplay(), win, qt_xrootwin(), 0 );
+    NETExtendedStrut strut;
+    strut.left_width = left_width;
+    strut.right_width = right_width;
+    strut.top_width = top_width;
+    strut.bottom_width = bottom_width;
+    strut.left_start = left_start;
+    strut.left_end = left_end;
+    strut.right_start = right_start;
+    strut.right_end = right_end;
+    strut.top_start = top_start;
+    strut.top_end = top_end;
+    strut.bottom_start = bottom_start;
+    strut.bottom_end = bottom_end;
+    info.setExtendedStrut( strut );
+#endif
+}
+
 void KWin::setStrut( WId win, int left, int right, int top, int bottom )
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
@@ -671,6 +704,8 @@ KWin::WindowInfo::WindowInfo( WId win, unsigned long properties, unsigned long p
 	properties |= NET::WMIconName | NET::WMVisibleName; // force, in case it will be used as a fallback
     if( properties & NET::WMVisibleName )
 	properties |= NET::WMName; // force, in case it will be used as a fallback
+    if( properties2 & NET::WM2ExtendedStrut )
+        properties |= NET::WMStrut; // will be used as fallback
     properties |= NET::XAWMState; // force to get error detection for valid()
     unsigned long props[ 2 ] = { properties, properties2 };
     d->info = new NETWinInfo( qt_xdisplay(), win, qt_xrootwin(), props, 2 );
@@ -768,6 +803,44 @@ NET::MappingState KWin::WindowInfo::mappingState() const
 #endif
 }
 
+NETExtendedStrut KWin::WindowInfo::extendedStrut() const
+{
+#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+    kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2ExtendedStrut ) == 0, 176 )
+        << "Pass NET::WM2ExtendedStrut to second argument of KWin::windowInfo()" << endl;
+    NETExtendedStrut ext = d->info->extendedStrut();
+    NETStrut str = d->info->strut();
+    if( ext.left_width == 0 && ext.right_width == 0 && ext.top_width == 0 && ext.bottom_width == 0
+        && ( str.left != 0 || str.right != 0 || str.top != 0 || str.bottom != 0 )) {
+        // build extended from simple
+        if( str.left != 0 ) {
+            ext.left_width = str.left;
+            ext.left_start = 0;
+            ext.left_end = XDisplayHeight( qt_xdisplay(), DefaultScreen( qt_xdisplay()));
+        }
+        if( str.right != 0 ) {
+            ext.right_width = str.right;
+            ext.right_start = 0;
+            ext.right_end = XDisplayHeight( qt_xdisplay(), DefaultScreen( qt_xdisplay()));
+        }
+        if( str.top != 0 ) {
+            ext.top_width = str.top;
+            ext.top_start = 0;
+            ext.top_end = XDisplayWidth( qt_xdisplay(), DefaultScreen( qt_xdisplay()));
+        }
+        if( str.bottom != 0 ) {
+            ext.bottom_width = str.bottom;
+            ext.bottom_start = 0;
+            ext.bottom_end = XDisplayWidth( qt_xdisplay(), DefaultScreen( qt_xdisplay()));
+        }
+    }
+    return ext;
+#else
+    NETExtendedStrut n;
+    return n;
+#endif
+}
+
 NETStrut KWin::WindowInfo::strut() const
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
@@ -954,6 +1027,50 @@ WId KWin::WindowInfo::groupLeader() const
 #endif
 }
 
+QCString KWin::WindowInfo::windowClassClass() const
+{
+#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+    kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
+        << "Pass NET::WM2WindowClass to KWin::windowInfo()" << endl;
+    return d->info->windowClassClass();
+#else
+    return 0;
+#endif
+}
+
+QCString KWin::WindowInfo::windowClassName() const
+{
+#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+    kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowClass ) == 0, 176 )
+        << "Pass NET::WM2WindowClass to KWin::windowInfo()" << endl;
+    return d->info->windowClassName();
+#else
+    return 0;
+#endif
+}
+
+QCString KWin::WindowInfo::windowRole() const
+{
+#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+    kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2WindowRole ) == 0, 176 )
+        << "Pass NET::WM2WindowRole to KWin::windowInfo()" << endl;
+    return d->info->windowRole();
+#else
+    return 0;
+#endif
+}
+
+QCString KWin::WindowInfo::clientMachine() const
+{
+#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+    kdWarning(( d->info->passedProperties()[ NETWinInfo::PROTOCOLS2 ] & NET::WM2ClientMachine ) == 0, 176 )
+        << "Pass NET::WM2ClientMachine to KWin::windowInfo()" << endl;
+    return d->info->clientMachine();
+#else
+    return 0;
+#endif
+}
+
 bool KWin::WindowInfo::actionSupported( NET::Action action ) const
 {
 #if defined Q_WS_X11 && ! defined K_WS_QTONLY
