@@ -1,6 +1,7 @@
 /*
 
   Copyright (c) 2000 Troll Tech AS
+  Copyright (c) 2003 Lubos Lunak <l.lunak@kde.org>
 
   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
@@ -25,15 +26,14 @@
 #ifndef   __netwm_def_h
 #define   __netwm_def_h
 
-
 /**
-  Simple point class for @ref NET classes.
+  Simple point class for NET classes.
 
   This class is a convenience class defining a point x, y.  The existence of
   this class is to keep the implementation from being dependant on a
   separate framework/library.
 
-  NETPoint is only used by the @ref NET API. Usually @ref QPoint is the 
+  NETPoint is only used by the NET API. Usually QPoint is the 
   appropriate class for representing a point.
 
   @author Bradley T. Hughes <bhughes@trolltech.com>
@@ -54,13 +54,13 @@ struct NETPoint {
 
 
 /**
-  Simple size class for @ref NET classes.
+  Simple size class for NET classes.
 
   This class is a convenience class defining a size width by height.  The
   existence of this class is to keep the implementation from being dependant
   on a separate framework/library.
 
-  NETSize is only used by the @ref NET API. Usually @ref QSize is the 
+  NETSize is only used by the NET API. Usually QSize is the 
   appropriate class for representing a size.
 
   @author Bradley T. Hughes <bhughes@trolltech.com>
@@ -80,13 +80,13 @@ struct NETSize {
 };
 
 /**
-   Simple rectangle class for @ref NET classes.
+   Simple rectangle class for NET classes.
 
    This class is a convenience class defining a rectangle as a point x,y with a
    size width by height.  The existence of this class is to keep the implementation
    from being dependant on a separate framework/library;
 
-   NETRect is only used by the @ref NET API. Usually @ref QRect is the 
+   NETRect is only used by the NET API. Usually QRect is the 
    appropriate class for representing a rectangle.
 **/
 struct NETRect {
@@ -107,13 +107,13 @@ struct NETRect {
 
 
 /**
-   Simple icon class for @ref NET classes.
+   Simple icon class for NET classes.
 
    This class is a convenience class defining an icon of size width by height.
    The existence of this class is to keep the implementation from being
    dependant on a separate framework/library.
 
-   NETIcon is only used by the @ref NET API. Usually @ref QIcon is the 
+   NETIcon is only used by the NET API. Usually QIcon is the 
    appropriate class for representing an icon.
 **/
 
@@ -140,11 +140,54 @@ struct NETIcon {
 
 
 /**
-   Simple strut class for @ref NET classes.
+   Partial strut class for NET classes.
+
+   This class is a convenience class defining a strut with left, right, top and
+   bottom border values, and ranges for them.  The existence of this class is to
+   keep the implementation from being dependant on a separate framework/library.
+   See the _NET_WM_STRUT_PARTIAL property in the NETWM spec.
+**/
+
+struct NETExtendedStrut {
+    /**
+       Constructor to initialize this struct to 0,0,0,0
+    **/
+    NETExtendedStrut() : left_width(0), left_start(0), left_end(0),
+        right_width(0), right_start(0), right_end(0), top_width(0), top_start(0), top_end(0),
+        bottom_width(0), bottom_start(0), bottom_end(0) {}
+
+    /**
+       Left border of the strut, width and range.
+           **/
+    int left_width, left_start, left_end;
+
+    /**
+       Right border of the strut, width and range.
+    **/
+    int right_width, right_start, right_end;
+
+    /**
+       Top border of the strut, width and range.
+           **/
+    int top_width, top_start, top_end;
+
+    /**
+       Bottom border of the strut, width and range.
+           **/
+    int bottom_width, bottom_start, bottom_end;
+    
+};
+
+
+/**
+   @deprecated use NETExtendedStrut
+
+   Simple strut class for NET classes.
 
    This class is a convenience class defining a strut with left, right, top and
    bottom border values.  The existence of this class is to keep the implementation
-   from being dependant on a separate framework/library.
+   from being dependant on a separate framework/library. See the _NET_WM_STRUT
+   property in the NETWM spec.
 **/
 
 struct NETStrut {
@@ -244,8 +287,37 @@ public:
 	Dialog   = 5,
 	Override = 6, // NON STANDARD
         TopMenu  = 7, // NON STANDARD
-	Tool     = Toolbar // This will go away soon, COMPAT
+	Tool     = Toolbar, // This will go away soon, COMPAT (How soon? :)
+	Utility  = 8,	///< @since 3.2
+	Splash   = 9	///< @since 3.2
     };
+    
+    /**
+        Values for WindowType when they should be OR'ed together, e.g.
+        for the properties argument of the NETRootInfo constructor.
+        @since 3.2
+    **/
+    enum WindowTypeMask {
+	NormalMask   = 1<<0,
+	DesktopMask  = 1<<1,
+	DockMask     = 1<<2,
+	ToolbarMask  = 1<<3,
+	MenuMask     = 1<<4,
+	DialogMask   = 1<<5,
+	OverrideMask = 1<<6,
+        TopMenuMask  = 1<<7,
+	UtilityMask  = 1<<8,
+	SplashMask   = 1<<9
+    };
+
+    // KDE4 move to WindowTypeMask
+    enum { AllTypesMask = -1LU };
+
+    /**
+     * Returns true if the given window type matches the mask given
+     * using WindowTypeMask flags.
+     */    
+    static bool typeMatchesMask( WindowType type, unsigned long mask );
 
     /**
        Window state.
@@ -255,7 +327,8 @@ public:
        the root window if the dialog is a modal for its window group.
 
        @li Sticky indicates that the Window Manager SHOULD keep the window's position
-       fixed on the screen, even when the virtual desktop scrolls.
+       fixed on the screen, even when the virtual desktop scrolls. Note that this is
+       different from being kept on all desktops.
 
        @li Max{Vert,Horiz} indicates that the window is {vertically,horizontally}
        maximized.
@@ -266,9 +339,25 @@ public:
 
        @li SkipTaskbar indicates that a window should not be included on a taskbar.
 
-       @li StaysOnTop indicate that a window should be kept on top of other windows.
-
        @li SkipPager indicates that a window should not be included on a pager.
+
+       @li Hidden indicates that a window should not be visible on the screen (e.g. when minimised).
+           Only the window manager is allowed to change it.
+
+       @li FullScreen indicates that a window should fill the entire screen and have no window decorations.
+
+       @li KeepAbove indicates that a window should on top of most windows (but below fullscreen windows).
+
+       @li KeepBelow indicates that a window should be below most windows (but above any desktop windows).
+
+       @li StaysOnTop is an obsolete name for KeepAbove.
+       
+       @li DemandsAttention there was an attempt to activate this window, but the window manager prevented
+           this. E.g. taskbar should mark such window specially to bring user's attention to this window.
+           Only the window manager is allowed to change it.
+
+       Note that KeepAbove (StaysOnTop) and KeepBelow are meant as user preference and applications
+       should avoid setting these states themselves.
     **/
 
     enum State {
@@ -279,8 +368,13 @@ public:
 	Max = MaxVert | MaxHoriz,
 	Shaded       = 1<<4,
 	SkipTaskbar  = 1<<5,
-	StaysOnTop   = 1<<6,
-	SkipPager    = 1<<7
+	KeepAbove    = 1<<6,	///< @since 3.2
+	StaysOnTop   = KeepAbove,	// NOT STANDARD
+	SkipPager    = 1<<7,
+	Hidden       = 1<<8,	///< @since 3.2
+	FullScreen   = 1<<9,	///< @since 3.2
+	KeepBelow    = 1<<10,	///< @since 3.2
+        DemandsAttention = 1<<11  ///< @since 3.2
     };
 
     /**
@@ -298,6 +392,8 @@ public:
        @li BottomLeft
        @li Left
        @li Move (for movement only)
+       @li KeyboardSize (resizing via keyboard)
+       @li KeyboardMove (movement via keyboard)
     **/
 
     enum Direction {
@@ -309,7 +405,15 @@ public:
 	Bottom       = 5,
 	BottomLeft   = 6,
 	Left         = 7,
-	Move         = 8  // movement only
+	Move         = 8,  // movement only
+    /**
+       @since 3.2
+    **/
+	KeyboardSize = 9,  // size via keyboard
+    /**
+       @since 3.2
+    **/
+	KeyboardMove = 10  // move via keyboard
     };
 
     /**
@@ -322,14 +426,35 @@ public:
        @li Withdrawn indicates that neither the client window nor its icon is visible.
 
        @li Iconic indicates that the client window is not visible, but its icon is.
+           This can be when the window is minimized or when it's on a different
+           virtual desktop. See also NET::Hidden.
     **/
 
+    // KDE4 aaarghl, this doesn't map correctly to Xlib #defines
     enum MappingState {
 	Visible, // ie. NormalState
 	Withdrawn,
 	Iconic
     };
 
+    /**
+      Actions that can be done with a window (_NET_WM_ALLOWED_ACTIONS).
+      @since 3.2
+    **/
+    enum Action {
+        ActionMove           = 1<<0,
+        ActionResize         = 1<<1,
+        ActionMinimize       = 1<<2,
+        ActionShade          = 1<<3,
+        ActionStick          = 1<<4,
+        ActionMaxVert        = 1<<5,
+        ActionMaxHoriz       = 1<<6,
+        ActionMax            = ActionMaxVert | ActionMaxHoriz,
+        ActionFullScreen     = 1<<7,
+        ActionChangeDesktop  = 1<<8,
+        ActionClose          = 1<<9
+    };
+    
     /**
        Supported properties.  Clients and Window Managers must define which
        properties/protocols it wants to support.
@@ -358,10 +483,12 @@ public:
        @li WMDesktop
        @li WMWindowType
        @li WMState
-       @li WMStrut
+       @li WMStrut  (obsoleted by WM2ExtendedStrut)
        @li WMIconGeometry
        @li WMIcon
        @li WMPid
+       @li WMVisibleIconName
+       @li WMIconName
 
        ICCCM properties (provided for convenience):
 
@@ -413,6 +540,64 @@ public:
 	WMVisibleIconName     = 1<<30,
 	WMGeometry	      = 1<<31
     };
+    
+    /**
+        Supported properties. This enum is an extension to NET::Property,
+        because them enum is limited only to 32 bits.
+
+        Client window properties and protocols:
+
+        @li WM2UserTime
+        @li WM2StartupId
+        @li WM2TransientFor mainwindow for the window (WM_TRANSIENT_FOR)
+        @li WM2GroupLeader  group leader (window_group in WM_HINTS)
+        @li WM2AllowedActions
+        @li WM2RestackWindow
+        @li WM2MoveResizeWindow
+        @li WM2ExtendedStrut
+        @li WM2TemporaryRules internal, for kstart
+        @li WM2WindowClass  WM_CLASS
+        @li WM2WindowRole   WM_WINDOW_ROLE
+        @li WM2ClientMachine WM_CLIENT_MACHINE
+        
+        @since 3.2
+
+    **/
+    enum Property2 {
+        WM2UserTime            = 1<<0,
+        WM2StartupId           = 1<<1,
+        WM2TransientFor        = 1<<2,
+        WM2GroupLeader         = 1<<3,
+        WM2AllowedActions      = 1<<4,
+        WM2RestackWindow       = 1<<5,
+        WM2MoveResizeWindow    = 1<<6,
+        WM2ExtendedStrut       = 1<<7,
+        WM2TakeActivity        = 1<<8,
+        WM2KDETemporaryRules   = 1<<9,  // NOT STANDARD
+        WM2WindowClass         = 1<<10, ///< @since 3.3
+        WM2WindowRole          = 1<<11, ///< @since 3.3
+        WM2ClientMachine       = 1<<12  ///< @since 3.3
+    };
+
+    /**
+       Sentinel value to indicate that the client wishes to be visible on
+       all desktops.
+       @since 3.2
+     **/ 
+    enum { OnAllDesktops = -1 };
+    
+    /**
+       Source of the request.
+       @li FromApplication the request comes from a normal application
+       @li FromTool the request comes from pager or similar tool
+       @since 3.2
+    **/
+    // must match the values for data.l[0] field in _NET_ACTIVE_WINDOW message
+    enum RequestSource {
+        FromUnknown, // internal
+        FromApplication,
+        FromTool
+    };
 };
 
 
