@@ -370,6 +370,8 @@ bool KBuildSycoca::build()
      g_changed = false;
 
      g_vfolder = new VFolderMenu;
+     if (!m_trackId.isEmpty())
+        g_vfolder->setTrackId(m_trackId);
 
      connect(g_vfolder, SIGNAL(newService(const QString &, KService **)),
              this, SLOT(slotCreateEntry(const QString &, KService **)));
@@ -445,7 +447,6 @@ void KBuildSycoca::createMenu(QString caption, QString name, VFolderMenu::SubMen
      }
      else
      {
-        // TODO: Check if problematic if same sevice is added twice
         g_bsf->addEntry( it.current(), g_resource );
         g_bsgf->addNewEntryTo(name, it.current());
      }
@@ -681,16 +682,17 @@ QStringList KBuildSycoca::existingResourceDirs()
 }
 
 static KCmdLineOptions options[] = {
-   { "nosignal", I18N_NOOP("Do not signal applications to update."), 0 },
-   { "noincremental", I18N_NOOP("Disable incremental update, re-read everything."), 0 },
-   { "checkstamps", I18N_NOOP("Check file timestamps."), 0 },
-   { "global", I18N_NOOP("Create global database."), 0 },
-   { "menutest", I18N_NOOP("Perform menu generation test run only."), 0 },
+   { "nosignal", I18N_NOOP("Do not signal applications to update"), 0 },
+   { "noincremental", I18N_NOOP("Disable incremental update, re-read everything"), 0 },
+   { "checkstamps", I18N_NOOP("Check file timestamps"), 0 },
+   { "global", I18N_NOOP("Create global database"), 0 },
+   { "menutest", I18N_NOOP("Perform menu generation test run only"), 0 },
+   { "track <menu-id>", I18N_NOOP("Track menu id for debug purposes"), 0 },
    KCmdLineLastOption
 };
 
-static const char *appName = "kbuildsycoca";
-static const char *appVersion = "1.1";
+static const char appName[] = "kbuildsycoca";
+static const char appVersion[] = "1.1";
 
 class WaitForSignal : public QObject
 {
@@ -866,7 +868,19 @@ qWarning("Reusing existing ksycoca");
       cSycocaPath = 0;
 
       KBuildSycoca *sycoca= new KBuildSycoca; // Build data base
+      if (args->isSet("track"))
+         sycoca->setTrackId(QString::fromLocal8Bit(args->getOption("track")));
       sycoca->recreate();
+
+      if (bGlobalDatabase)
+      {
+        // These directories may have been created with 0700 permission
+        // better delete them if they are empty
+        QString applnkDir = KGlobal::dirs()->saveLocation("apps", QString::null, false);
+        ::rmdir(QFile::encodeName(applnkDir));
+        QString servicetypesDir = KGlobal::dirs()->saveLocation("servicetypes", QString::null, false);
+        ::rmdir(QFile::encodeName(servicetypesDir));
+      }
    }
 
    if (args->isSet("signal"))
