@@ -76,7 +76,7 @@ static void runBuildSycoca(QObject *callBackObj=0, const char *callBackSlot=0)
 
 static void runKonfUpdate()
 {
-   KApplication::kdeinitExecWait( "kconf_update");
+   KApplication::kdeinitExecWait( "kconf_update", QStringList(), 0, 0, "0" /*no startup notification*/ );
 }
 
 static void runDontChangeHostname(const QCString &oldName, const QCString &newName)
@@ -142,6 +142,7 @@ void Kded::initModules()
 {
      m_dontLoad.clear();
      KConfig *config = kapp->config();
+     bool kde_running = !( getenv( "KDE_FULL_SESSION" ) == NULL || getenv( "KDE_FULL_SESSION" )[ 0 ] == '\0' );
 
      // Preload kded modules.
      KService::List kdedModules = KServiceType::offers("KDEDModule");
@@ -151,7 +152,7 @@ void Kded::initModules()
          bool autoload = service->property("X-KDE-Kded-autoload").toBool();
          config->setGroup(QString("Module-%1").arg(service->desktopEntryName()));
          autoload = config->readBoolEntry("autoload", autoload);
-         if (autoload)
+         if (autoload && kde_running)
             loadModule(service, false);
 
          bool dontLoad = false;
@@ -351,7 +352,8 @@ void Kded::updateResourceList()
 void Kded::crashHandler(int)
 {
    DCOPClient::emergencyClose();
-   system("kded");
+   if (_self) // Don't restart if we were closing down
+      system("kded");
 qWarning("Last DCOP call before KDED crash was from application '%s'\n"
          "to object '%s', function '%s'.",
          DCOPClient::postMortemSender(),
@@ -747,8 +749,8 @@ public:
 extern "C" int kdemain(int argc, char *argv[])
 {
      KAboutData aboutData( "kded", I18N_NOOP("KDE Daemon"),
-        "$Id: kded.cpp,v 1.88 2003/11/18 16:38:41 waba Exp $",
-        I18N_NOOP("KDE Daemon - triggers Sycoca database updates when needed."));
+        "$Id: kded.cpp,v 1.94 2004/07/15 13:28:55 lunakl Exp $",
+        I18N_NOOP("KDE Daemon - triggers Sycoca database updates when needed"));
 
      KApplication::installSigpipeHandler();
 
