@@ -1,5 +1,5 @@
 /*
- * $Id: kstyle.h,v 1.11 2002/10/26 08:59:39 gallium Exp $
+ * $Id: kstyle.h,v 1.15 2003/10/07 22:40:42 mueller Exp $
  * 
  * KStyle
  * Copyright (C) 2001-2002 Karol Szwed <gallium@kde.org>
@@ -34,7 +34,6 @@
 
 #include <qcommonstyle.h>
 
-class TransparencyHandler;
 class KPixmap;
 
 class KStylePrivate;
@@ -48,10 +47,10 @@ class KStylePrivate;
  * the PopupMenuItems, ScrollBars and Sliders by providing extra "primitive
  * elements" which are simple to implement by the style writer.
  *
- * @author Karol Szwed (gallium@kde.org)
  * @see QStyle::QStyle
  * @see QCommonStyle::QCommonStyle
- * @version $Id: kstyle.h,v 1.11 2002/10/26 08:59:39 gallium Exp $
+ * @author Karol Szwed (gallium@kde.org)
+ * @version $Id: kstyle.h,v 1.15 2003/10/07 22:40:42 mueller Exp $
  */
 class KStyle: public QCommonStyle
 {
@@ -77,9 +76,9 @@ class KStyle: public QCommonStyle
 		 */
 		typedef uint KStyleFlags;
 		enum KStyleOption {
-			Default 			  =		0x00000000,		// All options disabled.
-			AllowMenuTransparency =		0x00000001,
-			FilledFrameWorkaround = 	0x00000002
+			Default 	      =		0x00000000, //!< All options disabled
+			AllowMenuTransparency =		0x00000001, //!< Internal transparency enabled
+			FilledFrameWorkaround = 	0x00000002  //!< Filled frames enabled
 		};
 
 		/**
@@ -92,22 +91,24 @@ class KStyle: public QCommonStyle
 		 * @li WindowsStyleScrollBar - Two button scrollbar with the previous
 		 * button at the top/left, and the next button at the bottom/right.
 		 *
-		 * @li PlatinumStyleSrollBar - Two button scrollbar with both the 
+		 * @li PlatinumStyleScrollBar - Two button scrollbar with both the 
 		 * previous and next buttons at the bottom/right.
 		 *
-		 * @li ThreeButtonScrollBar - KDE style three button scrollbar with
+		 * @li ThreeButtonScrollBar - %KDE style three button scrollbar with
 		 * two previous buttons, and one next button. The next button is always
 		 * at the bottom/right, whilst the two previous buttons are on either 
 		 * end of the scrollbar.
 		 *
 		 * @li NextStyleScrollBar - Similar to the PlatinumStyle scroll bar, but
 		 * with the buttons grouped on the opposite end of the scrollbar.
+		 *
+		 * @see KStyle::KStyle()
 		 */
 		enum KStyleScrollBarType {
-			WindowsStyleScrollBar  = 	0x00000000,
-			PlatinumStyleScrollBar = 	0x00000001,
-			ThreeButtonScrollBar   = 	0x00000002,
-			NextStyleScrollBar     = 	0x00000004
+			WindowsStyleScrollBar  = 	0x00000000, //!< two button, windows style
+			PlatinumStyleScrollBar = 	0x00000001, //!< two button, platinum style
+			ThreeButtonScrollBar   = 	0x00000002, //!< three buttons, %KDE style
+			NextStyleScrollBar     = 	0x00000004  //!< two button, NeXT style
 		};
 
 		/** 
@@ -123,12 +124,14 @@ class KStyle: public QCommonStyle
 		 * style as a foundation for any new KStyle, so the limited number of
 		 * drawing fallbacks should not prove problematic.
 		 *
+		 * @param flags the style to be applied
+		 * @param sbtype the scroll bar type
 		 * @see KStyle::KStyleFlags
 		 * @see KStyle::KStyleScrollBarType
 		 * @author Karol Szwed (gallium@kde.org)
 		 */
 		KStyle( KStyleFlags flags = KStyle::Default, 
-				KStyleScrollBarType sbtype = KStyle::WindowsStyleScrollBar );
+			KStyleScrollBarType sbtype = KStyle::WindowsStyleScrollBar );
 
 		/** 
 		 * Destructs the KStyle object.
@@ -148,11 +151,13 @@ class KStyle: public QCommonStyle
 		 * style after performing some processing in your style's constructor.
 		 * In most situations however, setting the scrollbar type via the KStyle
 		 * constructor should suffice.
+		 * @param sbtype the scroll bar type
+		 * @see KStyle::KStyleScrollBarType
 		 */
 		void setScrollBarType(KStyleScrollBarType sbtype);
 
 		/**
-		 * Returns the KStyle flags used to initialise the style.
+		 * Returns the KStyle flags used to initialize the style.
 		 *
 		 * This is used solely for the kcmstyle module, and hence is internal.
 		 */
@@ -172,7 +177,7 @@ class KStyle: public QCommonStyle
 		 * the user in KDE's style control module.
 		 */
 		virtual void renderMenuBlendPixmap( KPixmap& pix, const QColorGroup& cg, 
-											const QPopupMenu* popup ) const;
+						    const QPopupMenu* popup ) const;
 
 		/**
 		 * KStyle Primitive Elements:
@@ -194,7 +199,7 @@ class KStyle: public QCommonStyle
 		 * handle.
 		 *
 		 * @li KPE_ToolBarHandle - This primitive must be reimplemented. It currently
-		 * only paints a filled rectangle as default behaviour. This primitive is used
+		 * only paints a filled rectangle as default behavior. This primitive is used
 		 * to render QToolBar handles.
 		 *
 		 * @li KPE_GeneralHandle - This primitive must be reimplemented. It is used
@@ -249,14 +254,13 @@ class KStyle: public QCommonStyle
 
 		enum KStylePixelMetric {
 			KPM_MenuItemSeparatorHeight		= 0x00000001,
-			KPM_MenuItemHMargin				= 0x00000002,
-			KPM_MenuItemVMargin				= 0x00000004,
-			KPM_MenuItemHFrame				= 0x00000008,
-			KPM_MenuItemVFrame				= 0x00000010,
-			KPM_MenuItemCheckMarkHMargin	= 0x00000020,
+			KPM_MenuItemHMargin			= 0x00000002,
+			KPM_MenuItemVMargin			= 0x00000004,
+			KPM_MenuItemHFrame			= 0x00000008,
+			KPM_MenuItemVFrame			= 0x00000010,
+			KPM_MenuItemCheckMarkHMargin	        = 0x00000020,
 			KPM_MenuItemArrowHMargin		= 0x00000040,
 			KPM_MenuItemTabSpacing			= 0x00000080,
-
 			KPM_ListViewBranchThickness		= 0x00000100
 		};
 
