@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,12 +22,12 @@
 #include <qfile.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 static KCmdLineOptions options[] =
 {
 	{ "+[file]", I18N_NOOP("Configuration file to load"), 0},
-	{ 0, 0, 0}
+	KCmdLineLastOption
 };
 
 int main(int argc, char *argv[])
