@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -36,7 +36,7 @@ CupsdNetworkPage::CupsdNetworkPage(QWidget *parent, const char *name)
 	: CupsdPage(parent, name)
 {
 	setPageLabel(i18n("Network"));
-	setHeader(i18n("Network settings"));
+	setHeader(i18n("Network Settings"));
 	setPixmap("network");
 
 	keepalive_ = new QCheckBox(i18n("Keep alive"), this);
