@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kmcupsjobmanager.cpp,v 1.37.2.2 2003/05/20 06:10:41 staikos Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -38,7 +36,7 @@
 #include <kdebug.h>
 #include <kurl.h>
 
-KMCupsJobManager::KMCupsJobManager(QObject *parent, const char *name)
+KMCupsJobManager::KMCupsJobManager(QObject *parent, const char *name, const QStringList & /*args*/)
 : KMJobManager(parent,name)
 {
 }
