@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -32,6 +32,7 @@
 #include <klocale.h>
 #include <klistview.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 KMWOther::KMWOther(QWidget *parent, const char *name)
 : KMWizardPage(parent,name)
@@ -65,7 +66,7 @@ KMWOther::KMWOther(QWidget *parent, const char *name)
 
 void KMWOther::initPrinter(KMPrinter *p)
 {
-	m_uri->setText(p->device().url());
+	m_uri->setText(p->device());
 
 	if ( m_uriview->childCount() == 0 )
 	{
@@ -74,7 +75,7 @@ void KMWOther::initPrinter(KMPrinter *p)
 			return;
 
 		QListViewItem *item = 0, *lastparent = 0, *root;
-		root = new QListViewItem( m_uriview, i18n( "CUPS server" ) + QString( " %1:%2" ).arg( CupsInfos::self()->host() ).arg( CupsInfos::self()->port() ) );
+		root = new QListViewItem( m_uriview, i18n( "CUPS Server %1:%2" ).arg( CupsInfos::self()->host() ).arg( CupsInfos::self()->port() ) );
 		root->setPixmap( 0, SmallIcon( "gear" ) );
 		root->setOpen( true );
 		QDict<QListViewItem> parents, last;
@@ -112,8 +113,7 @@ void KMWOther::initPrinter(KMPrinter *p)
 
 void KMWOther::updatePrinter(KMPrinter *p)
 {
-	QString	dev = m_uri->text();
-	p->setDevice(KURL(dev));
+	p->setDevice( m_uri->text() );
 }
 
 void KMWOther::slotPressed( QListViewItem *item )
