@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kmdbentry.h,v 1.7 2002/05/13 16:44:04 goffioul Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -38,8 +36,8 @@ struct KMDBEntry
 	QString	pnpmodel;
 	// short driver description (if any)
 	QString	description;
-	// tell whether this is the recommanded driver
-	bool recommanded;
+	// tell whether this is the recommended driver
+	bool recommended;
 	QString	drivercomment;
 
 	KMDBEntry();
