@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kmfactory.cpp,v 1.33.2.1 2003/04/07 13:52:59 goffioul Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -44,15 +42,17 @@
 #include <kstaticdeleter.h>
 #include <kapplication.h>
 #include <dcopclient.h>
+#include <dcopref.h>
+#include <kio/authinfo.h>
 
 #include <unistd.h>
 
 #define	UNLOAD_OBJECT(x) if (x != 0) { delete x; x = 0; }
 
-void qt_generate_epsf( bool b );
+extern void qt_generate_epsf( bool b );
 
 KMFactory* KMFactory::m_self = 0;
-KStaticDeleter<KMFactory> s_kmfactorysd;
+static KStaticDeleter<KMFactory> s_kmfactorysd;
 
 KMFactory* KMFactory::self()
 {
@@ -95,8 +95,8 @@ KMFactory::KMFactory()
 	m_factory = 0;
 	m_printconfig = 0;
 #if QT_VERSION >= 230
-	// Qt's default behaviour, to generate EPS in some cases and not in others, sucks.
-	// This is fixed in Qt 3.0, but for Qt 2.x we need to disable it explicitely.
+	// Qt's default behavior, to generate EPS in some cases and not in others, sucks.
+	// This is fixed in Qt 3.0, but for Qt 2.x we need to disable it explicitly.
 	// If this is a problem for anyone, we can add a public method to set this flag.
 	// (David Faure, doing as advised by Lars Knoll)
 	qt_generate_epsf( false );
@@ -110,6 +110,7 @@ KMFactory::KMFactory()
 		settings.writeEntry( "/qt/embedFonts", true );
 
 	KGlobal::iconLoader()->addAppDir("kdeprint");
+        KGlobal::locale()->insertCatalogue("kdeprint");
 
 	// create DCOP signal connection
 	connectDCOPSignal(0, 0, "pluginChanged(pid_t)", "slot_pluginChanged(pid_t)", false);
@@ -235,7 +236,7 @@ QString KMFactory::printSystem()
 {
 	KConfig	*conf = printConfig();
 	conf->setGroup("General");
-	QString	sys = conf->readEntry("PrintSystem",QString::null);
+	QString	sys = conf->readEntry("PrintSystem");
 	if (sys.isEmpty())
 	{
 		// perform auto-detection (will at least return "lpdunix")
@@ -407,4 +408,42 @@ void KMFactory::saveConfig()
 	// need to reload the config file.
 }
 
+QPair<QString,QString> KMFactory::requestPassword( int& seqNbr, const QString& user, const QString& host, int port )
+{
+	DCOPRef kdeprintd( "kded", "kdeprintd" );
+	/**
+	 * We do not use an internal event loop for 2 potential problems:
+	 *  - the MessageWindow modality (appearing afterwards, it pops up on top
+	 *    of the password dialog)
+	 *  - KMTimer should be stopped, but it's unavailable from this object
+	 */
+	DCOPReply reply = kdeprintd.call( "requestPassword", user, host, port, seqNbr );
+	if ( reply.isValid() )
+	{
+		QString replyString = reply;
+		if ( replyString != "::" )
+		{
+			QStringList l = QStringList::split( ':', replyString, true );
+			if ( l.count() == 3 )
+			{
+				seqNbr = l[ 2 ].toInt();
+				return QPair<QString,QString>( l[ 0 ], l[ 1 ] );
+			}
+		}
+	}
+	return QPair<QString,QString>( QString::null, QString::null );
+}
+
+void KMFactory::initPassword( const QString& user, const QString& password, const QString& host, int port )
+{
+	DCOPRef kdeprintd( "kded", "kdeprintd" );
+	/**
+	 * We do not use an internal event loop for 2 potential problems:
+	 *  - the MessageWindow modality (appearing afterwards, it pops up on top
+	 *    of the password dialog)
+	 *  - KMTimer should be stopped, but it's unavailable from this object
+	 */
+	kdeprintd.call( "initPassword", user, password, host, port );
+}
+
 #include "kmfactory.moc"
