@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kpgeneralpage.cpp,v 1.17 2002/09/30 14:42:09 goffioul Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -33,6 +31,7 @@
 #include <kcursor.h>
 #include <klocale.h>
 #include <kiconloader.h>
+#include <kdialog.h>
 
 // Some ID's
 #define ORIENT_PORTRAIT_ID	0
@@ -48,15 +47,7 @@
 #define NUP_2_ID	1
 #define NUP_4_ID	2
 
-void radioCursor(QButtonGroup *bg)
-{
-	QButton	*btn;
-	int	index(0);
-	while ((btn=bg->find(index++)) != 0)
-		btn->setCursor(KCursor::handCursor());
-}
-
-void initCombo(QComboBox *cb, DrListOption *opt)
+static void initCombo(QComboBox *cb, DrListOption *opt)
 {
 	cb->clear();
 	QPtrListIterator<DrBase>	it(*(opt->choices()));
@@ -68,7 +59,7 @@ void initCombo(QComboBox *cb, DrListOption *opt)
 	}
 }
 
-void setComboItem(QComboBox *cb, const QString& txt)
+static void setComboItem(QComboBox *cb, const QString& txt)
 {
 	for (int i=0;i<cb->count();i++)
 		if (cb->text(i) == txt)
@@ -78,7 +69,7 @@ void setComboItem(QComboBox *cb, const QString& txt)
 		}
 }
 
-int findOption(const char *strs[], int n, const QString& txt)
+static int findOption(const char *strs[], int n, const QString& txt)
 {
 	for (int i=0;i<n;i+=2)
 		if (txt == strs[i]) return (i/2);
@@ -88,17 +79,25 @@ int findOption(const char *strs[], int n, const QString& txt)
 //*************************************************************************************************
 
 // default values in case of NULL driver
-#define	DEFAULT_SIZE	16
 static const char*	default_size[] = {
 	"A4", I18N_NOOP("ISO A4"),
 	"Letter", I18N_NOOP("US Letter"),
 	"Legal", I18N_NOOP("US Legal"),
 	"Ledger", I18N_NOOP("Ledger"),
-	"Tabloid", I18N_NOOP("Tabloid"),
 	"Folio", I18N_NOOP("Folio"),
 	"Comm10", I18N_NOOP("US #10 Envelope"),
-	"DL", I18N_NOOP("ISO DL Envelope")
+	"DL", I18N_NOOP("ISO DL Envelope"),
+	"Tabloid", I18N_NOOP("Tabloid"),
+	"A3", I18N_NOOP( "ISO A3" ),
+	"A2", I18N_NOOP( "ISO A2" ),
+	"A1", I18N_NOOP( "ISO A1" ),
+	"A0", I18N_NOOP( "ISO A0" )
 };
+#define SMALLSIZE_BEGIN   0
+#define MEDIUMSIZE_BEGIN 14
+#define HIGHSIZE_BEGIN   20
+#define DEFAULT_SIZE     24
+
 #define	DEFAULT_SOURCE	8
 static const char*	default_source[] = {
 	"Upper", I18N_NOOP("Upper Tray"),
@@ -163,13 +162,14 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent, const c
 	m_endbannerlabel->setBuddy(m_endbanner);
 
 	// layout creation
-	QVBoxLayout	*lay0 = new QVBoxLayout(this, 0, 10);
-	QGridLayout	*lay1 = new QGridLayout(0, 3, 2, 0, 10);
-	QGridLayout	*lay2 = new QGridLayout(0, 2, 2, 0, 10);
+	QVBoxLayout	*lay0 = new QVBoxLayout(this, 0, KDialog::spacingHint());
+	QGridLayout	*lay1 = new QGridLayout(0, 3, 2, 0, KDialog::spacingHint());
+	QGridLayout	*lay2 = new QGridLayout(0, 2, 2, 0, KDialog::spacingHint());
 	lay0->addStretch(1);
 	lay0->addLayout(lay1);
 	lay0->addStretch(1);
 	lay0->addLayout(lay2);
+	lay0->addStretch(2);
 	lay1->addWidget(m_pagesizelabel, 0, 0);
 	lay1->addWidget(m_papertypelabel, 1, 0);
 	lay1->addWidget(m_inputslotlabel, 2, 0);
@@ -182,24 +182,28 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent, const c
 	lay2->addWidget(m_nupbox, 1, 1);
 	lay2->setColStretch(0, 1);
 	lay2->setColStretch(1, 1);
-	QGridLayout	*lay3 = new QGridLayout(m_orientbox->layout(), 4, 2, 5);
+	QGridLayout	*lay3 = new QGridLayout(m_orientbox->layout(), 4, 2,
+		KDialog::spacingHint());
 	lay3->addWidget(m_portrait, 0, 0);
 	lay3->addWidget(m_landscape, 1, 0);
 	lay3->addWidget(m_revland, 2, 0);
 	lay3->addWidget(m_revport, 3, 0);
 	lay3->addMultiCellWidget(m_orientpix, 0, 3, 1, 1);
-	QGridLayout	*lay4 = new QGridLayout(m_duplexbox->layout(), 3, 2, 5);
+	QGridLayout	*lay4 = new QGridLayout(m_duplexbox->layout(), 3, 2,
+		KDialog::spacingHint());
 	lay4->addWidget(m_dupnone, 0, 0);
 	lay4->addWidget(m_duplong, 1, 0);
 	lay4->addWidget(m_dupshort, 2, 0);
 	lay4->addMultiCellWidget(m_duplexpix, 0, 2, 1, 1);
 	lay4->setRowStretch( 0, 1 );
-	QGridLayout	*lay5 = new QGridLayout(m_nupbox->layout(), 3, 2, 5);
+	QGridLayout	*lay5 = new QGridLayout(m_nupbox->layout(), 3, 2,
+		KDialog::spacingHint());
 	lay5->addWidget(m_nup1, 0, 0);
 	lay5->addWidget(m_nup2, 1, 0);
 	lay5->addWidget(m_nup4, 2, 0);
 	lay5->addMultiCellWidget(m_nuppix, 0, 2, 1, 1);
-	QGridLayout	*lay6 = new QGridLayout(m_bannerbox->layout(), 2, 2, 5);
+	QGridLayout	*lay6 = new QGridLayout(m_bannerbox->layout(), 2, 2,
+		KDialog::spacingHint());
 	lay6->addWidget(m_startbannerlabel, 0, 0);
 	lay6->addWidget(m_endbannerlabel, 1, 0);
 	lay6->addWidget(m_startbanner, 0, 1);
@@ -210,9 +214,6 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent, const c
 	connect(m_orientbox,SIGNAL(clicked(int)),SLOT(slotOrientationChanged(int)));
 	connect(m_nupbox,SIGNAL(clicked(int)),SLOT(slotNupChanged(int)));
 	connect(m_duplexbox,SIGNAL(clicked(int)),SLOT(slotDuplexChanged(int)));
-	radioCursor(m_orientbox);
-	radioCursor(m_nupbox);
-	radioCursor(m_duplexbox);
 
 	// init
 	initialize();
@@ -265,8 +266,14 @@ void KPGeneralPage::initialize()
 	else
 	{
 		// PageSize
-		for (int i=1;i<DEFAULT_SIZE;i+=2)
+		for (int i=SMALLSIZE_BEGIN+1;i<MEDIUMSIZE_BEGIN;i+=2)
 			m_pagesize->insertItem(i18n(default_size[i]));
+		if ( printer()->printerCap() & KMPrinter::CapMedium )
+			for ( int i=MEDIUMSIZE_BEGIN+1; i<HIGHSIZE_BEGIN; i+=2 )
+				m_pagesize->insertItem(i18n(default_size[i]));
+		if ( printer()->printerCap() & KMPrinter::CapLarge )
+			for ( int i=HIGHSIZE_BEGIN+1; i<DEFAULT_SIZE; i+=2 )
+				m_pagesize->insertItem(i18n(default_size[i]));
 		// set default page size using locale settings
 		QString	psname = pageSizeToPageName((KPrinter::PageSize)(KGlobal::locale()->pageSize()));
 		int index = findOption(default_size, DEFAULT_SIZE, psname);
@@ -278,6 +285,9 @@ void KPGeneralPage::initialize()
 		// PageSize
 		for (int i=1;i<DEFAULT_SOURCE;i+=2)
 			m_inputslot->insertItem(i18n(default_source[i]));
+
+		// Enable duplex setting if supported
+		m_duplexbox->setEnabled( printer()->printerCap() & KMPrinter::CapDuplex );
 	}
 
 	// Banners
