@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kprintdialog.h,v 1.24 2002/08/19 09:27:02 goffioul Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,6 +20,10 @@
 #ifndef KPRINTDIALOG_H
 #define KPRINTDIALOG_H
 
+#if !defined( _KDEPRINT_COMPILE ) && defined( __GNUC__ )
+#warning internal header, do not use except if you are a KDEPrint developer
+#endif
+
 #include <kdialog.h>
 #include <qptrlist.h>
 #include <kdeprint/kpreloadobject.h>
@@ -29,6 +31,13 @@
 class KPrinter;
 class KPrintDialogPage;
 
+/**
+ * @internal
+ * This class is internal to KDEPrint and is not intended to be
+ * used outside it. Please do not make use of this header, except
+ * if you're a KDEPrint developer. The API might change in the
+ * future and binary compatibility might be broken.
+ */
 class KPrintDialog : public KDialog, public KPReloadObject
 {
 	Q_OBJECT
