@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kprinter.cpp,v 1.59.2.5 2003/06/29 21:43:00 deller Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -28,6 +26,7 @@
 #include "kmfactory.h"
 #include "kmuimanager.h"
 #include "kmmanager.h"
+#include "driver.h"
 
 #include <qpaintdevicemetrics.h>
 #include <qfile.h>
@@ -46,8 +45,8 @@
 #include <klibloader.h>
 #include <kmessagebox.h>
 
-void dumpOptions(const QMap<QString,QString>& opts);
-void reportError(KPrinter*);
+static void dumpOptions(const QMap<QString,QString>& opts);
+static void reportError(KPrinter*);
 
 //**************************************************************************************
 // KPrinterWrapper class
@@ -109,12 +108,12 @@ public:
 	QString			m_tmpbuffer;
 	QString			m_printername;
 	QString			m_searchname;
-	QSize			m_margins;
-	QSize			m_pagesize;
 	QString			m_errormsg;
 	bool			m_ready;
 	int		m_pagenumber;
-	QRect m_drawablearea;
+	DrPageSize *m_pagesize;
+	bool m_useprinterres;
+	int m_defaultres;
 };
 
 //**************************************************************************************
@@ -136,7 +135,8 @@ KPrinter::~KPrinter()
 	if (d->m_restore)
 		saveSettings();
 
-	// delete private data
+	// delete private data (along any data allocated internally)
+	delete d->m_pagesize;
 	delete d;
 }
 
@@ -148,6 +148,7 @@ void KPrinter::init(bool restore, QPrinter::PrinterMode m)
 	d->m_restore = restore;
 	d->m_previewonly = false;
 	d->m_parentId = 0;
+	d->m_pagesize = 0;
 
 	// initialize QPrinter wrapper
 	d->m_wrapper = new KPrinterWrapper(this, m);
@@ -155,6 +156,8 @@ void KPrinter::init(bool restore, QPrinter::PrinterMode m)
 	// other initialization
 	d->m_tmpbuffer = d->m_impl->tempFile();
 	d->m_ready = false;
+	d->m_defaultres = d->m_wrapper->resolution();
+	d->m_useprinterres = false;
 
 	// reload options from implementation (static object)
 	if (d->m_restore)
@@ -200,17 +203,17 @@ void KPrinter::saveSettings()
 	conf->setGroup("KPrinter Settings");
 	conf->writeEntry("Printer",searchName());
 	// latest used print command
-	conf->writeEntry("PrintCommand",option("kde-printcommand"));
+	conf->writePathEntry("PrintCommand",option("kde-printcommand"));
 
 	// latest used document directory
 	if ( d->m_docdirectory.isEmpty() )
 	{
 		KURL url( outputFileName() );
 		if ( url.isValid() )
-			conf->writeEntry( "DocDirectory", url.directory() );
+			conf->writePathEntry( "DocDirectory", url.directory() );
 	}
 	else
-		conf->writeEntry( "DocDirectory", d->m_docdirectory );
+		conf->writePathEntry( "DocDirectory", d->m_docdirectory );
 }
 
 bool KPrinter::setup(QWidget *parent, const QString& caption, bool forceExpand)
@@ -220,7 +223,7 @@ bool KPrinter::setup(QWidget *parent, const QString& caption, bool forceExpand)
 		autoConfigure(QString::null, parent);
 		return true; // Just print it
 	}
-		
+
 	if (parent)
 		d->m_parentId = parent->winId();
 
@@ -304,25 +307,36 @@ void KPrinter::translateQtOptions()
 	d->m_wrapper->setOutputToFile(true);
 	d->m_wrapper->setOutputFileName(d->m_tmpbuffer);
 	d->m_wrapper->setNumCopies(option("kde-qtcopies").isEmpty() ? 1 : option("kde-qtcopies").toInt());
-#ifdef KDEPRINT_USE_MARGINS
 	if (!option("kde-margin-top").isEmpty())
-		d->m_wrapper->setMargins(option("kde-margin-top").toInt(), option("kde-margin-left").toInt(), option("kde-margin-bottom").toInt(), option("kde-margin-right").toInt());
-	else if ( d->m_drawablearea.isValid() && d->m_pagesize.isValid() )
 	{
-		QRect r = d->m_drawablearea;
-		QSize ps = d->m_pagesize;
+		/**
+		 * Scale margings as the margin widget always stores values
+		 * in dot units ( 1/72th in ), to be resolution independent
+		 * when specified by the user ( who usually specifies margins
+		 * in metric units ).
+		 */
 		int res = resolution();
-		d->m_wrapper->setMargins( ( r.top() * res + 71 ) / 72,
-				( r.left() * res + 71 ) / 72, 
-				( ( ps.height() - r.bottom() - 1 ) * res + 71 ) / 72,
-				( ( ps.width() - r.right() - 1 ) * res + 71 ) / 72 );
+		d->m_wrapper->setMargins(
+				( int )( ( option("kde-margin-top").toFloat() * res + 71 ) / 72 ),
+				( int )( ( option("kde-margin-left").toFloat() * res + 71 ) / 72 ),
+				( int )( ( option("kde-margin-bottom").toFloat() * res + 71 ) / 72 ),
+				( int )( ( option("kde-margin-right").toFloat() * res + 71 ) / 72 ) );
+	}
+	else if ( d->m_pagesize != NULL )
+	{
+		int res = resolution();
+		DrPageSize *ps = d->m_pagesize;
+		d->m_wrapper->setMargins(
+				( int )( ( ps->topMargin() * res + 71 ) / 72 ),
+				( int )( ( ps->leftMargin() * res + 71 ) / 72 ),
+				( int )( ( ps->bottomMargin() * res + 71 ) / 72 ),
+				( int )( ( ps->rightMargin() * res + 71 ) / 72 ) );
 	}
 	/*else
 	{
 		int res = d->m_wrapper->resolution();
 		d->m_wrapper->setMargins( res/3, res/2, res/3, res/2 );
 	}*/
-#endif
 	// for special printers, copies are handled by Qt
 	if (option("kde-isspecial") == "1")
 		d->m_wrapper->setNumCopies(numCopies());
@@ -376,7 +390,7 @@ bool KPrinter::printFiles(const QStringList& l, bool flag, bool startviewer)
 			}
 			else
 			{
-				if (!outputToFile() && startviewer)
+				if (/* !outputToFile() && */ startviewer)
 				{
 					QStringList args;
 					args << "-d";
@@ -387,7 +401,7 @@ bool KPrinter::printFiles(const QStringList& l, bool flag, bool startviewer)
 			}
 		}
 		else if (flag)
-		// situation: only one file, it has been previewed and printing has been cancelled, then
+		// situation: only one file, it has been previewed and printing has been canceled, then
 		//            we should remove the file ourself
 		{
 			QFile::remove(files[0]);
@@ -413,14 +427,19 @@ void KPrinter::preparePrinting()
 	setErrorMessage(QString::null);
 
 	// re-initialize margins and page size (by default, use Qt mechanism)
-	setMargins(QSize(-1,-1));
-	setRealPageSize(QSize(-1,-1));
-	setRealDrawableArea( QRect() );
+	setRealPageSize(NULL);
 
 	// print-system-specific setup, only if not printing to file
 	if (option("kde-isspecial") != "1")
 		d->m_impl->preparePrinting(this);
 
+	// set the correct resolution, if needed (or reset it)
+	int res = option( "kde-resolution" ).toInt();
+	if ( d->m_useprinterres && res > 0 )
+		d->m_wrapper->setResolution( res );
+	else
+		d->m_wrapper->setResolution( d->m_defaultres );
+
 	// standard Qt settings
 	translateQtOptions();
 
@@ -524,27 +543,17 @@ int KPrinter::numCopies() const
 
 QSize KPrinter::margins() const
 {
-	/*if (d->m_margins.isValid())
-		if (orientation() == KPrinter::Landscape) return QSize(d->m_margins.height(),d->m_margins.width());
-		else return d->m_margins;
-	else return d->m_wrapper->margins();*/
 	return d->m_wrapper->margins();
 }
 
 void KPrinter::margins( uint *top, uint *left, uint *bottom, uint *right ) const
 {
-#ifdef KDEPRINT_USE_MARGINS
 	d->m_wrapper->margins( top, left, bottom, right );
-#else
-	QSize mg = d->m_wrapper->margins();
-	*top = *bottom = mg.height();
-	*left = *right = mg.width();
-#endif
 }
 
 int KPrinter::metric(int m) const
 {
-	if (!d->m_pagesize.isValid() || !option( "kde-printsize" ).isEmpty())
+	if (d->m_pagesize == NULL || !option( "kde-printsize" ).isEmpty())
 		return d->m_wrapper->qprinterMetric(m);
 
 	int	val(0);
@@ -554,14 +563,14 @@ int KPrinter::metric(int m) const
 	switch ( m )
 	{
 		case QPaintDeviceMetrics::PdmWidth:
-			val = (land ? d->m_pagesize.height() : d->m_pagesize.width());
+			val = (land ? ( int )d->m_pagesize->pageHeight() : ( int )d->m_pagesize->pageWidth());
 			if ( res != 72 )
 				val = (val * res + 36) / 72;
 			if ( !fullPage() )
 				val -= ( left + right );
 			break;
 		case QPaintDeviceMetrics::PdmHeight:
-			val = (land ? d->m_pagesize.width() : d->m_pagesize.height());
+			val = (land ? ( int )d->m_pagesize->pageWidth() : ( int )d->m_pagesize->pageHeight());
 			if ( res != 72 )
 				val = (val * res + 36) / 72;
 			if ( !fullPage() )
@@ -590,11 +599,17 @@ void KPrinter::setOrientation(Orientation o)
 	d->m_impl->broadcastOption( "kde-orientation-fixed", "1" );
 }
 
+void KPrinter::setOption( const QString& key, const QString& value, bool broadcast )
+{
+	setOption( key, value );
+	if ( broadcast )
+		d->m_impl->broadcastOption( key, value );
+}
+
 void KPrinter::setPageSize(PageSize s)
 {
 	KMFactory::self()->settings()->pageSize = s;
-	setOption("kde-pagesize",QString::number((int)s));
-	d->m_impl->broadcastOption("kde-pagesize",option("kde-pagesize"));
+	setOption("kde-pagesize",QString::number((int)s),true);
 	d->m_impl->broadcastOption( "kde-pagesize-fixed", "1" );
 }
 
@@ -614,6 +629,8 @@ void KPrinter::setOptions(const QMap<QString,QString>& opts)
 	tmpset.remove("kde-margin-left");
 	tmpset.remove("kde-margin-bottom");
 	tmpset.remove("kde-margin-right");
+	tmpset.remove( "kde-resolution" );
+	tmpset.remove( "kde-fonts" );
 	for (QMap<QString,QString>::ConstIterator it=tmpset.begin();it!=tmpset.end();++it)
 		if (it.key().left(4) == "kde-" && !(d->m_options.contains(it.key())))
 			d->m_options[it.key()] = it.data();
@@ -664,7 +681,7 @@ bool KPrinter::autoConfigure(const QString& prname, QWidget *parent)
 
 void reportError(KPrinter *p)
 {
-	if (!KNotifyClient::event("printerror",i18n("<p><nobr>A print error occured. Error message received from system:</nobr></p><br>%1").arg(p->errorMessage())))
+	if (!KNotifyClient::event("printerror",i18n("<p><nobr>A print error occurred. Error message received from system:</nobr></p><br>%1").arg(p->errorMessage())))
 		kdDebug(500) << "could not send notify event" << endl;
 }
 
@@ -742,28 +759,14 @@ const char* pageSizeToPageName(KPrinter::PageSize s)
 	}
 }
 
-QSize rangeToSize(const QString& s)
+// FIXME: remove for 4.0
+QSize rangeToSize( const QString& )
 {
-	QString	range = s;
-	int	p(-1);
-	int	from, to;
-
-	if ((p=range.find(',')) != -1)
-		range.truncate(p);
-	if ((p=range.find('-')) != -1)
-	{
-		from = range.left(p).toInt();
-		to = range.right(range.length()-p-1).toInt();
-	}
-	else if (!range.isEmpty())
-		from = to = range.toInt();
-	else
-		from = to = 0;
-
-	return QSize(from,to);
+	kdWarning( 500 ) << "rangeToSize(QString) is obsolete, do not use (no effect)" << endl;
+	return QSize();
 }
 
-void dumpOptions(const QMap<QString,QString>& opts)
+static void dumpOptions(const QMap<QString,QString>& opts)
 {
 	kdDebug(500) << "********************" << endl;
 	for (QMap<QString,QString>::ConstIterator it=opts.begin(); it!=opts.end(); ++it)
@@ -870,10 +873,11 @@ void KPrinter::setPrintProgram(const QString& prg)
 	}
 	else
 	{
-		setOption("kde-isspecial", "1");
 		QString	s(prg);
 		if (s.find("%in") == -1)
 			s.append(" %in");
+		setOutputToFile( s.find( "%out" ) != -1 );
+		setOption("kde-isspecial", "1");
 		setOption("kde-special-command", s);
 	}
 }
@@ -926,13 +930,73 @@ bool KPrinter::aborted() const
 { return d->m_wrapper->aborted(); }
 
 void KPrinter::setMargins(QSize m)
-{ d->m_margins = m; }
+{
+	setMargins( m.height(), m.width(), m.height(), m.width() );
+}
 
+void KPrinter::setMargins( uint top, uint left, uint bottom, uint right )
+{
+	d->m_wrapper->setMargins( top, left, bottom, right );
+	setOption( "kde-margin-top", QString::number( top ), true );
+	setOption( "kde-margin-left", QString::number( left ), true );
+	setOption( "kde-margin-bottom", QString::number( bottom ), true );
+	setOption( "kde-margin-right", QString::number( right ), true );
+}
+
+// FIXME: remove for 4.0
 QSize KPrinter::realPageSize() const
-{ return d->m_pagesize; }
+{
+	kdWarning( 500 ) << "KPrinter::realPageSize() is obsolete, do not use" << endl;
+	if ( d->m_pagesize )
+		return d->m_pagesize->pageSize();
+	else
+		return QSize();
+}
 
-void KPrinter::setRealPageSize(QSize p)
-{ d->m_pagesize = p; }
+void KPrinter::setRealPageSize(DrPageSize *p)
+{
+	if ( p )
+	{
+		kdDebug( 500 ) << "Page size:  width =" << p->pageWidth() << endl;
+		kdDebug( 500 ) << "Page size: height =" << p->pageHeight() << endl;
+		kdDebug( 500 ) << "Page size:   left =" << p->leftMargin() << endl;
+		kdDebug( 500 ) << "Page size:    top =" << p->topMargin() << endl;
+		kdDebug( 500 ) << "Page size:  right =" << p->rightMargin() << endl;
+		kdDebug( 500 ) << "Page size: bottom =" << p->bottomMargin() << endl;
+	}
+	else
+		kdDebug( 500 ) << "Resetting page size" << endl;
+
+	/* we copy the page size structure internally
+	 * as the original object is owned by the driver
+	 * that control its destrution */
+	delete d->m_pagesize;
+	d->m_pagesize = 0;
+	if ( p )
+		d->m_pagesize = new DrPageSize( *p );
+}
+
+// FIXME: remove for 4.0
+void KPrinter::setRealPageSize( QSize )
+{
+	kdWarning( 500 ) << "KPrinter::setRealPageSize(QSize) is obsolete, do not use (no effect)" << endl;
+}
+
+// FIXME: remove for 4.0
+void KPrinter::setRealDrawableArea( const QRect& )
+{
+	kdWarning( 500 ) << "KPrinter::setRealDrawableArea(QRect) is obsolete, do not use (no effect)" << endl;
+}
+
+// FIXME: remove for 4.0
+QRect KPrinter::realDrawableArea() const
+{
+	kdWarning( 500 ) << "KPrinter::realDrawableArea() is obsolete, do not use" << endl;
+	if ( d->m_pagesize )
+		return d->m_pagesize->pageRect();
+	else
+		return QRect();
+}
 
 QString KPrinter::errorMessage() const
 { return d->m_errormsg; }
@@ -963,13 +1027,13 @@ QString KPrinter::docDirectory() const
 { return ( d->m_docdirectory.isEmpty() ? QDir::homeDirPath() : d->m_docdirectory ); }
 
 void KPrinter::setResolution(int dpi)
-{ d->m_wrapper->setResolution(dpi); }
+{
+	d->m_wrapper->setResolution(dpi);
+	d->m_defaultres = dpi;
+}
 
 int KPrinter::resolution() const
 { return d->m_wrapper->resolution(); }
 
-void KPrinter::setRealDrawableArea( const QRect& r )
-{ d->m_drawablearea = r; }
-
-QRect KPrinter::realDrawableArea() const
-{ return d->m_drawablearea; }
+void KPrinter::setUsePrinterResolution( bool on )
+{ d->m_useprinterres = on; }
