@@ -352,8 +352,7 @@ int KPrinterImpl::doFilterFiles(KPrinter *printer, QStringList& files, const QSt
 		KXmlCommand	*filter = KXmlCommandManager::self()->loadCommand(flist[i]);
 		if (!filter)
 		{
-			// TODO: better error message
-			printer->setErrorMessage(i18n("<p>Error while reading filter description for <b>%1</b>. Empty command line received.</p>").arg(flist[i]));
+			printer->setErrorMessage(i18n("<p>Could not load filter description for <b>%1</b>.</p>").arg(flist[i]));
 			return -1; // Error
 		}
 		if (i == 0)
@@ -481,7 +480,18 @@ int KPrinterImpl::autoConvertFiles(KPrinter *printer, QStringList& files, bool f
 	for (QStringList::Iterator it=files.begin(); it!=files.end(); )
 	{
 		QString	mime = KMimeMagic::self()->findFileType(*it)->mimeType();
-		if (mimeTypes.findIndex(mime) == -1)
+		if ( mime == "application/x-zerosize" )
+		{
+			// special case of empty file
+			KMessageBox::information( NULL,
+					i18n( "<qt>The print file is empty and will be ignored:<p>%1</p></qt>" ).arg( *it ),
+					QString::null, "emptyFileNotPrinted" );
+			if ( flag )
+				QFile::remove( *it );
+			it = files.remove( it );
+			continue;
+		}
+		else if (mimeTypes.findIndex(mime) == -1)
 		{
 			if ((result=KMessageBox::warningYesNoCancel(NULL,
 					       i18n("The file format %1 is not directly supported by the current print system. "
