@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@
 #include <kprocess.h>
 #include <stdlib.h>
 
-QString execute(const QString& cmd)
+static QString execute(const QString& cmd)
 {
 	KPipeProcess	proc;
 	QString		output;
@@ -202,7 +202,7 @@ int LpcHelper::parseStateChangeLPR(const QString& result, const QString& printer
 		return 1;
 }
 
-QString lprngAnswer(const QString& result, const QString& printer)
+static QString lprngAnswer(const QString& result, const QString& printer)
 {
 	int	p, q;
 
@@ -232,7 +232,7 @@ bool LpcHelper::changeState(const QString& printer, const QString& op, QString&
 {
 	if (m_exepath.isEmpty())
 	{
-		msg = i18n("Unable to locate executable %1 in your PATH.").arg("lpc");
+		msg = i18n("The executable %1 couldn't be found in your PATH.").arg("lpc");
 		return false;
 	}
 	QString	result = execute(m_exepath + " " + op + " " + KProcess::quote(printer));
@@ -253,7 +253,7 @@ bool LpcHelper::changeState(const QString& printer, const QString& op, QString&
 		case 0:
 			break;
 		case -1:
-			msg = i18n("Permission denied");
+			msg = i18n("Permission denied.");
 			break;
 		case -2:
 			msg = i18n("Printer %1 does not exist.").arg(printer);
@@ -270,7 +270,7 @@ bool LpcHelper::removeJob(KMJob *job, QString& msg)
 {
 	if (m_lprmpath.isEmpty())
 	{
-		msg = i18n("The executable %1 couldn't be find in your PATH.").arg("lprm");
+		msg = i18n("The executable %1 couldn't be found in your PATH.").arg("lprm");
 		return false;
 	}
 	QString	result = execute(m_lprmpath + " -P " + KProcess::quote(job->printer()) + " " + QString::number(job->id()));
@@ -288,7 +288,7 @@ bool LpcHelper::changeJobState(KMJob *job, int state, QString& msg)
 {
 	if (m_lprmpath.isEmpty())
 	{
-		msg = i18n("The executable %1 couldn't be find in your PATH.").arg("lpc");
+		msg = i18n("The executable %1 couldn't be found in your PATH.").arg("lpc");
 		return false;
 	}
 	QString	result = execute(m_exepath + (state == KMJob::Held ? " hold " : " release ") + KProcess::quote(job->printer()) + " " + QString::number(job->id()));
@@ -311,7 +311,7 @@ bool LpcHelper::restart(QString& msg)
 		s = "checkpc";
 	if (!s.isEmpty())
 	{
-		msg = i18n("The executable %1 couldn't be find in your PATH.").arg(s);
+		msg = i18n("The executable %1 couldn't be found in your PATH.").arg(s);
 		return false;
 	}
 	::system(QFile::encodeName(m_exepath + " reread"));
