@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -45,10 +45,8 @@ protected:
 	QString driverDirInternal();
 
 private:
-	MaticBlock* loadMaticData(const QString&);
-	DrMain* loadMaticDriver(const QString&);
-	KURL parsePostpipe(const QString&);
-	QString createPostpipe(const KURL&);
+	QString parsePostpipe(const QString&);
+	QString createPostpipe(const QString&);
 	bool savePpdFile(DrMain*, const QString&);
 
 private:
