@@ -8,10 +8,10 @@ static KCmdLineOptions options[] =
 {
 	{ "kdeconfig", I18N_NOOP("Configure KDE Print"), 0 },
 	{ "serverconfig", I18N_NOOP("Configure print server"), 0 },
-	{0, 0, 0}
+	KCmdLineLastOption
 };
 
-int main(int argc, char *argv[])
+extern "C" int kdemain(int argc, char *argv[])
 {
 	KCmdLineArgs::init(argc, argv, "kaddprinterwizard",
 			I18N_NOOP("Start the add printer wizard"),
