@@ -1,6 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -23,7 +23,7 @@
 #include "kmconfigpage.h"
 
 class KListBox;
-class QPushButton;
+class QToolButton;
 class QLineEdit;
 
 class KMConfigFilter : public KMConfigPage
@@ -45,7 +45,7 @@ protected:
 
 private:
 	KListBox	*m_list1, *m_list2;
-	QPushButton	*m_add, *m_remove;
+	QToolButton	*m_add, *m_remove;
 	QLineEdit	*m_locationre;
 };
 
